@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -25,7 +24,9 @@ const char Exception::DEFAULT_MSG[] = "No detailed information provided";
 ///\brief       Default constructor.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-Exception::Exception() : detail_message(""), func_name("") {}
+Exception::Exception()
+{
+}
 
 //--------------------------------------------------------------------------
 // Function:    Exception overloaded constructor
@@ -35,7 +36,10 @@ Exception::Exception() : detail_message(""), func_name("") {}
 ///\param       message   - IN: Message on the failure
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-Exception::Exception(const H5std_string& func, const H5std_string& message) : detail_message(message), func_name(func) {}
+Exception::Exception(const H5std_string &func, const H5std_string &message)
+    : detail_message(message), func_name(func)
+{
+}
 
 //--------------------------------------------------------------------------
 // Function:    Exception copy constructor
@@ -43,7 +47,9 @@ Exception::Exception(const H5std_string& func, const H5std_string& message) : de
 ///\param       orig - IN: Exception instance to copy
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-Exception::Exception(const Exception& orig) : detail_message(orig.detail_message), func_name(orig.func_name) {}
+Exception::Exception(const Exception &orig) : detail_message(orig.detail_message), func_name(orig.func_name)
+{
+}
 
 //--------------------------------------------------------------------------
 // Function:    Exception::getMajorString
@@ -56,32 +62,30 @@ Exception::Exception(const Exception& orig) : detail_message(orig.detail_message
 ///             will be returned.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-H5std_string Exception::getMajorString(hid_t err_major) const
+H5std_string
+Exception::getMajorString(hid_t err_major) const
 {
     // Preliminary call to H5Eget_msg() to get the length of the message
     ssize_t mesg_size = H5Eget_msg(err_major, NULL, NULL, 0);
 
     // If H5Eget_msg() returns a negative value, raise an exception,
     if (mesg_size < 0)
-        throw IdComponentException("Exception::getMajorString",
-            "H5Eget_msg failed");
+        throw IdComponentException("Exception::getMajorString", "H5Eget_msg failed");
 
     // Call H5Eget_msg again to get the actual message
-    char* mesg_C = new char[mesg_size+1];  // temporary C-string for C API
-    mesg_size = H5Eget_msg(err_major, NULL, mesg_C, mesg_size+1);
+    char *mesg_C = new char[mesg_size + 1]; // temporary C-string for C API
+    mesg_size    = H5Eget_msg(err_major, NULL, mesg_C, mesg_size + 1);
 
     // Check for failure again
-    if (mesg_size < 0)
-    {
-        delete []mesg_C;
-        throw IdComponentException("Exception::getMajorString",
-            "H5Eget_msg failed");
+    if (mesg_size < 0) {
+        delete[] mesg_C;
+        throw IdComponentException("Exception::getMajorString", "H5Eget_msg failed");
     }
 
     // Convert the C error description and return
     H5std_string major_str(mesg_C);
-    delete []mesg_C;
-    return(major_str);
+    delete[] mesg_C;
+    return (major_str);
 }
 
 //--------------------------------------------------------------------------
@@ -95,32 +99,30 @@ H5std_string Exception::getMajorString(hid_t err_major) const
 ///             will be returned.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-H5std_string Exception::getMinorString(hid_t err_minor) const
+H5std_string
+Exception::getMinorString(hid_t err_minor) const
 {
     // Preliminary call to H5Eget_msg() to get the length of the message
     ssize_t mesg_size = H5Eget_msg(err_minor, NULL, NULL, 0);
 
     // If H5Eget_msg() returns a negative value, raise an exception,
     if (mesg_size < 0)
-        throw IdComponentException("Exception::getMinorString",
-            "H5Eget_msg failed");
+        throw IdComponentException("Exception::getMinorString", "H5Eget_msg failed");
 
     // Call H5Eget_msg again to get the actual message
-    char* mesg_C = new char[mesg_size+1];  // temporary C-string for C API
-    mesg_size = H5Eget_msg(err_minor, NULL, mesg_C, mesg_size+1);
+    char *mesg_C = new char[mesg_size + 1]; // temporary C-string for C API
+    mesg_size    = H5Eget_msg(err_minor, NULL, mesg_C, mesg_size + 1);
 
     // Check for failure again
-    if (mesg_size < 0)
-    {
-        delete []mesg_C;
-        throw IdComponentException("Exception::getMinorString",
-            "H5Eget_msg failed");
+    if (mesg_size < 0) {
+        delete[] mesg_C;
+        throw IdComponentException("Exception::getMinorString", "H5Eget_msg failed");
     }
 
     // Convert the C error description and return
     H5std_string minor_str(mesg_C);
-    delete []mesg_C;
-    return(minor_str);
+    delete[] mesg_C;
+    return (minor_str);
 }
 
 //--------------------------------------------------------------------------
@@ -139,7 +141,8 @@ H5std_string Exception::getMinorString(hid_t err_minor) const
 ///             handlers
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void Exception::setAutoPrint(H5E_auto2_t& func, void* client_data)
+void
+Exception::setAutoPrint(H5E_auto2_t &func, void *client_data)
 {
     // calls the C API routine H5Eset_auto to set the auto printing to
     // the specified function.
@@ -153,7 +156,8 @@ void Exception::setAutoPrint(H5E_auto2_t& func, void* client_data)
 ///\brief       Turns off the automatic error printing from the C library.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void Exception::dontPrint()
+void
+Exception::dontPrint()
 {
     // calls the C API routine H5Eset_auto with NULL parameters to turn
     // off the automatic error printing.
@@ -172,7 +176,8 @@ void Exception::dontPrint()
 ///                                the error function
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void Exception::getAutoPrint(H5E_auto2_t& func, void** client_data)
+void
+Exception::getAutoPrint(H5E_auto2_t &func, void **client_data)
 {
     // calls the C API routine H5Eget_auto to get the current setting of
     // the automatic error printing
@@ -189,7 +194,8 @@ void Exception::getAutoPrint(H5E_auto2_t& func, void** client_data)
 ///             called, with certain exceptions (for instance, \c H5Eprint).
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void Exception::clearErrorStack()
+void
+Exception::clearErrorStack()
 {
     // calls the C API routine H5Eclear to clear the error stack
     herr_t ret_value = H5Eclear2(H5E_DEFAULT);
@@ -238,7 +244,8 @@ void Exception::clearErrorStack()
 ///\endcode
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void Exception::walkErrorStack(H5E_direction_t direction, H5E_walk2_t func, void* client_data)
+void
+Exception::walkErrorStack(H5E_direction_t direction, H5E_walk2_t func, void *client_data)
 {
     // calls the C API routine H5Ewalk to walk the error stack
     herr_t ret_value = H5Ewalk2(H5E_DEFAULT, direction, func, client_data);
@@ -253,9 +260,10 @@ void Exception::walkErrorStack(H5E_direction_t direction, H5E_walk2_t func, void
 ///\return      Text message - \c H5std_string
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-H5std_string Exception::getDetailMsg() const
+H5std_string
+Exception::getDetailMsg() const
 {
-    return(detail_message);
+    return (detail_message);
 }
 
 //--------------------------------------------------------------------------
@@ -265,9 +273,10 @@ H5std_string Exception::getDetailMsg() const
 ///\return      Text message - \c char pointer
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-const char* Exception::getCDetailMsg() const
+const char *
+Exception::getCDetailMsg() const
 {
-    return(detail_message.c_str());
+    return (detail_message.c_str());
 }
 
 //--------------------------------------------------------------------------
@@ -276,9 +285,10 @@ const char* Exception::getCDetailMsg() const
 ///\return      Text message - \c H5std_string
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-H5std_string Exception::getFuncName() const
+H5std_string
+Exception::getFuncName() const
 {
-    return(func_name);
+    return (func_name);
 }
 
 //--------------------------------------------------------------------------
@@ -287,9 +297,10 @@ H5std_string Exception::getFuncName() const
 ///\return      Text message - \c char pointer
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-const char* Exception::getCFuncName() const
+const char *
+Exception::getCFuncName() const
 {
-    return(func_name.c_str());
+    return (func_name.c_str());
 }
 
 //--------------------------------------------------------------------------
@@ -299,7 +310,8 @@ const char* Exception::getCFuncName() const
 ///\param       err_stack - IN: Error stack ID, default to H5E_DEFAULT(0)
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void Exception::printErrorStack(FILE* stream, hid_t err_stack)
+void
+Exception::printErrorStack(FILE *stream, hid_t err_stack)
 {
     herr_t ret_value = H5Eprint2(err_stack, stream);
     if (ret_value < 0)
@@ -319,7 +331,7 @@ void Exception::printErrorStack(FILE* stream, hid_t err_stack)
 //              Removed from documentation. -BMR, 2016/03/23
 //              Removed from code. -BMR, 2017/08/11 1.8.20 and 1.10.2
 //--------------------------------------------------------------------------
-//void Exception::printError(FILE* stream) const
+// void Exception::printError(FILE* stream) const
 //{
 //    Exception::printErrorStack(stream, H5E_DEFAULT);
 //}
@@ -329,7 +341,9 @@ void Exception::printErrorStack(FILE* stream, hid_t err_stack)
 ///\brief       Noop destructor
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-Exception::~Exception() throw() {}
+Exception::~Exception() throw()
+{
+}
 
 //--------------------------------------------------------------------------
 // Subclass:    FileIException
@@ -339,7 +353,9 @@ Exception::~Exception() throw() {}
 // Function:    FileIException default constructor
 ///\brief       Default constructor.
 //--------------------------------------------------------------------------
-FileIException::FileIException():Exception(){}
+FileIException::FileIException() : Exception()
+{
+}
 //--------------------------------------------------------------------------
 // Function:    FileIException overloaded constructor
 ///\brief       Creates a FileIException with the name of the function,
@@ -347,12 +363,17 @@ FileIException::FileIException():Exception(){}
 ///\param       func - IN: Name of the function where failure occurs
 ///\param       message   - IN: Message on the failure
 //--------------------------------------------------------------------------
-FileIException::FileIException(const H5std_string& func, const H5std_string& message) : Exception(func, message) {}
+FileIException::FileIException(const H5std_string &func, const H5std_string &message)
+    : Exception(func, message)
+{
+}
 //--------------------------------------------------------------------------
 // Function:    FileIException destructor
 ///\brief       Noop destructor.
 //--------------------------------------------------------------------------
-FileIException::~FileIException() throw() {}
+FileIException::~FileIException() throw()
+{
+}
 
 //--------------------------------------------------------------------------
 // Subclass:    GroupIException
@@ -362,7 +383,9 @@ FileIException::~FileIException() throw() {}
 // Function:    GroupIException default constructor
 ///\brief       Default constructor.
 //--------------------------------------------------------------------------
-GroupIException::GroupIException():Exception(){}
+GroupIException::GroupIException() : Exception()
+{
+}
 //--------------------------------------------------------------------------
 // Function:    GroupIException overloaded constructor
 ///\brief       Creates a GroupIException with the name of the function,
@@ -370,12 +393,17 @@ GroupIException::GroupIException():Exception(){}
 ///\param       func - IN: Name of the function where failure occurs
 ///\param       message   - IN: Message on the failure
 //--------------------------------------------------------------------------
-GroupIException::GroupIException(const H5std_string& func, const H5std_string& message) : Exception(func, message) {}
+GroupIException::GroupIException(const H5std_string &func, const H5std_string &message)
+    : Exception(func, message)
+{
+}
 //--------------------------------------------------------------------------
 // Function:    GroupIException destructor
 ///\brief       Noop destructor.
 //--------------------------------------------------------------------------
-GroupIException::~GroupIException() throw() {}
+GroupIException::~GroupIException() throw()
+{
+}
 
 //--------------------------------------------------------------------------
 // Subclass:    DataSpaceIException
@@ -385,7 +413,9 @@ GroupIException::~GroupIException() throw() {}
 // Function:    DataSpaceIException default constructor
 ///\brief       Default constructor.
 //--------------------------------------------------------------------------
-DataSpaceIException::DataSpaceIException():Exception(){}
+DataSpaceIException::DataSpaceIException() : Exception()
+{
+}
 //--------------------------------------------------------------------------
 // Function:    DataSpaceIException overloaded constructor
 ///\brief       Creates a DataSpaceIException with the name of the function,
@@ -393,12 +423,17 @@ DataSpaceIException::DataSpaceIException():Exception(){}
 ///\param       func - IN: Name of the function where failure occurs
 ///\param       message   - IN: Message on the failure
 //--------------------------------------------------------------------------
-DataSpaceIException::DataSpaceIException(const H5std_string& func, const H5std_string& message) : Exception(func, message) {}
+DataSpaceIException::DataSpaceIException(const H5std_string &func, const H5std_string &message)
+    : Exception(func, message)
+{
+}
 //--------------------------------------------------------------------------
 // Function:    DataSpaceIException destructor
 ///\brief       Noop destructor.
 //--------------------------------------------------------------------------
-DataSpaceIException::~DataSpaceIException() throw() {}
+DataSpaceIException::~DataSpaceIException() throw()
+{
+}
 
 //--------------------------------------------------------------------------
 // Subclass:    DataTypeIException
@@ -408,7 +443,9 @@ DataSpaceIException::~DataSpaceIException() throw() {}
 // Function:    DataTypeIException default constructor
 ///\brief       Default constructor.
 //--------------------------------------------------------------------------
-DataTypeIException::DataTypeIException():Exception(){}
+DataTypeIException::DataTypeIException() : Exception()
+{
+}
 //--------------------------------------------------------------------------
 // Function:    DataTypeIException overloaded constructor
 ///\brief       Creates a DataTypeIException with the name of the function,
@@ -416,12 +453,17 @@ DataTypeIException::DataTypeIException():Exception(){}
 ///\param       func - IN: Name of the function where failure occurs
 ///\param       message   - IN: Message on the failure
 //--------------------------------------------------------------------------
-DataTypeIException::DataTypeIException(const H5std_string& func, const H5std_string& message) : Exception(func, message) {}
+DataTypeIException::DataTypeIException(const H5std_string &func, const H5std_string &message)
+    : Exception(func, message)
+{
+}
 //--------------------------------------------------------------------------
 // Function:    DataTypeIException destructor
 ///\brief       Noop destructor.
 //--------------------------------------------------------------------------
-DataTypeIException::~DataTypeIException() throw() {}
+DataTypeIException::~DataTypeIException() throw()
+{
+}
 
 //--------------------------------------------------------------------------
 // Subclass:    ObjHeaderIException
@@ -431,7 +473,9 @@ DataTypeIException::~DataTypeIException() throw() {}
 // Function:    ObjHeaderIException default constructor
 ///\brief       Default constructor.
 //--------------------------------------------------------------------------
-ObjHeaderIException::ObjHeaderIException():Exception(){}
+ObjHeaderIException::ObjHeaderIException() : Exception()
+{
+}
 //--------------------------------------------------------------------------
 // Function:    ObjHeaderIException overloaded constructor
 ///\brief       Creates an ObjHeaderIException with the name of the function,
@@ -439,12 +483,17 @@ ObjHeaderIException::ObjHeaderIException():Exception(){}
 ///\param       func - IN: Name of the function where failure occurs
 ///\param       message   - IN: Message on the failure
 //--------------------------------------------------------------------------
-ObjHeaderIException::ObjHeaderIException(const H5std_string& func, const H5std_string& message) : Exception(func, message) {}
+ObjHeaderIException::ObjHeaderIException(const H5std_string &func, const H5std_string &message)
+    : Exception(func, message)
+{
+}
 //--------------------------------------------------------------------------
 // Function:    ObjHeaderIException destructor
 ///\brief       Noop destructor.
 //--------------------------------------------------------------------------
-ObjHeaderIException::~ObjHeaderIException() throw() {}
+ObjHeaderIException::~ObjHeaderIException() throw()
+{
+}
 
 //--------------------------------------------------------------------------
 // Subclass:    PropListIException
@@ -454,7 +503,9 @@ ObjHeaderIException::~ObjHeaderIException() throw() {}
 // Function:    PropListIException default constructor
 ///\brief       Default constructor.
 //--------------------------------------------------------------------------
-PropListIException::PropListIException():Exception(){}
+PropListIException::PropListIException() : Exception()
+{
+}
 //--------------------------------------------------------------------------
 // Function:    PropListIException overloaded constructor
 ///\brief       Creates a PropListIException with the name of the function,
@@ -462,12 +513,17 @@ PropListIException::PropListIException():Exception(){}
 ///\param       func - IN: Name of the function where failure occurs
 ///\param       message   - IN: Message on the failure
 //--------------------------------------------------------------------------
-PropListIException::PropListIException(const H5std_string& func, const H5std_string& message) : Exception(func, message) {}
+PropListIException::PropListIException(const H5std_string &func, const H5std_string &message)
+    : Exception(func, message)
+{
+}
 //--------------------------------------------------------------------------
 // Function:    PropListIException destructor
 ///\brief       Noop destructor.
 //--------------------------------------------------------------------------
-PropListIException::~PropListIException() throw() {}
+PropListIException::~PropListIException() throw()
+{
+}
 
 //--------------------------------------------------------------------------
 // Subclass:    DataSetIException
@@ -477,7 +533,9 @@ PropListIException::~PropListIException() throw() {}
 // Function:    DataSetIException default constructor
 ///\brief       Default constructor.
 //--------------------------------------------------------------------------
-DataSetIException::DataSetIException():Exception(){}
+DataSetIException::DataSetIException() : Exception()
+{
+}
 //--------------------------------------------------------------------------
 // Function:    DataSetIException overloaded constructor
 ///\brief       Creates a DataSetIException with the name of the function,
@@ -485,12 +543,17 @@ DataSetIException::DataSetIException():Exception(){}
 ///\param       func - IN: Name of the function where failure occurs
 ///\param       message   - IN: Message on the failure
 //--------------------------------------------------------------------------
-DataSetIException::DataSetIException(const H5std_string& func, const H5std_string& message) : Exception(func, message) {}
+DataSetIException::DataSetIException(const H5std_string &func, const H5std_string &message)
+    : Exception(func, message)
+{
+}
 //--------------------------------------------------------------------------
 // Function:    DataSetIException destructor
 ///\brief       Noop destructor.
 //--------------------------------------------------------------------------
-DataSetIException::~DataSetIException() throw() {}
+DataSetIException::~DataSetIException() throw()
+{
+}
 
 //--------------------------------------------------------------------------
 // Subclass:    AttributeIException
@@ -500,7 +563,9 @@ DataSetIException::~DataSetIException() throw() {}
 // Function:    AttributeIException default constructor
 ///\brief       Default constructor.
 //--------------------------------------------------------------------------
-AttributeIException::AttributeIException():Exception(){}
+AttributeIException::AttributeIException() : Exception()
+{
+}
 //--------------------------------------------------------------------------
 // Function:    AttributeIException overloaded constructor
 ///\brief       Creates an AttributeIException with the name of the function,
@@ -508,12 +573,17 @@ AttributeIException::AttributeIException():Exception(){}
 ///\param       func - IN: Name of the function where failure occurs
 ///\param       message   - IN: Message on the failure
 //--------------------------------------------------------------------------
-AttributeIException::AttributeIException(const H5std_string& func, const H5std_string& message) : Exception(func, message) {}
+AttributeIException::AttributeIException(const H5std_string &func, const H5std_string &message)
+    : Exception(func, message)
+{
+}
 //--------------------------------------------------------------------------
 // Function:    AttributeIException destructor
 ///\brief       Noop destructor.
 //--------------------------------------------------------------------------
-AttributeIException::~AttributeIException() throw() {}
+AttributeIException::~AttributeIException() throw()
+{
+}
 
 //--------------------------------------------------------------------------
 // Subclass:    ReferenceException
@@ -523,7 +593,9 @@ AttributeIException::~AttributeIException() throw() {}
 // Function:    ReferenceException default constructor
 ///\brief       Default constructor.
 //--------------------------------------------------------------------------
-ReferenceException::ReferenceException():Exception(){}
+ReferenceException::ReferenceException() : Exception()
+{
+}
 //--------------------------------------------------------------------------
 // Function:    ReferenceException overloaded constructor
 ///\brief       Creates a ReferenceException with the name of the function,
@@ -531,12 +603,17 @@ ReferenceException::ReferenceException():Exception(){}
 ///\param       func - IN: Name of the function where failure occurs
 ///\param       message   - IN: Message on the failure
 //--------------------------------------------------------------------------
-ReferenceException::ReferenceException(const H5std_string& func, const H5std_string& message) : Exception(func, message) {}
+ReferenceException::ReferenceException(const H5std_string &func, const H5std_string &message)
+    : Exception(func, message)
+{
+}
 //--------------------------------------------------------------------------
 // Function:    ReferenceException destructor
 ///\brief       Noop destructor.
 //--------------------------------------------------------------------------
-ReferenceException::~ReferenceException() throw() {}
+ReferenceException::~ReferenceException() throw()
+{
+}
 
 //--------------------------------------------------------------------------
 // Subclass:    LibraryIException
@@ -546,7 +623,9 @@ ReferenceException::~ReferenceException() throw() {}
 // Function:    LibraryIException default constructor
 ///\brief       Default constructor.
 //--------------------------------------------------------------------------
-LibraryIException::LibraryIException():Exception(){}
+LibraryIException::LibraryIException() : Exception()
+{
+}
 //--------------------------------------------------------------------------
 // Function:    LibraryIException overloaded constructor
 ///\brief       Creates a LibraryIException with the name of the function,
@@ -554,12 +633,17 @@ LibraryIException::LibraryIException():Exception(){}
 ///\param       func - IN: Name of the function where failure occurs
 ///\param       message   - IN: Message on the failure
 //--------------------------------------------------------------------------
-LibraryIException::LibraryIException(const H5std_string& func, const H5std_string& message) : Exception(func, message) {}
+LibraryIException::LibraryIException(const H5std_string &func, const H5std_string &message)
+    : Exception(func, message)
+{
+}
 //--------------------------------------------------------------------------
 // Function:    LibraryIException destructor
 ///\brief       Noop destructor.
 //--------------------------------------------------------------------------
-LibraryIException::~LibraryIException() throw() {}
+LibraryIException::~LibraryIException() throw()
+{
+}
 
 //--------------------------------------------------------------------------
 // Subclass:    LocationException
@@ -569,7 +653,9 @@ LibraryIException::~LibraryIException() throw() {}
 // Function:    LocationException default constructor
 ///\brief       Default constructor.
 //--------------------------------------------------------------------------
-LocationException::LocationException():Exception(){}
+LocationException::LocationException() : Exception()
+{
+}
 //--------------------------------------------------------------------------
 // Function:    LocationException overloaded constructor
 ///\brief       Creates a LocationException with the name of the function,
@@ -577,12 +663,17 @@ LocationException::LocationException():Exception(){}
 ///\param       func - IN: Name of the function where failure occurs
 ///\param       message   - IN: Message on the failure
 //--------------------------------------------------------------------------
-LocationException::LocationException(const H5std_string& func, const H5std_string& message) : Exception(func, message) {}
+LocationException::LocationException(const H5std_string &func, const H5std_string &message)
+    : Exception(func, message)
+{
+}
 //--------------------------------------------------------------------------
 // Function:    LocationException destructor
 ///\brief       Noop destructor.
 //--------------------------------------------------------------------------
-LocationException::~LocationException() throw() {}
+LocationException::~LocationException() throw()
+{
+}
 
 //--------------------------------------------------------------------------
 // Subclass:    IdComponentException
@@ -592,7 +683,9 @@ LocationException::~LocationException() throw() {}
 // Function:    IdComponentException default constructor
 ///\brief       Default constructor.
 //--------------------------------------------------------------------------
-IdComponentException::IdComponentException(): Exception() {}
+IdComponentException::IdComponentException() : Exception()
+{
+}
 //--------------------------------------------------------------------------
 // Function:    IdComponentException overloaded constructor
 ///\brief       Creates a IdComponentException with the name of the function,
@@ -600,11 +693,16 @@ IdComponentException::IdComponentException(): Exception() {}
 ///\param       func - IN: Name of the function where failure occurs
 ///\param       message   - IN: Message on the failure
 //--------------------------------------------------------------------------
-IdComponentException::IdComponentException(const H5std_string& func, const H5std_string& message) : Exception(func, message) {}
+IdComponentException::IdComponentException(const H5std_string &func, const H5std_string &message)
+    : Exception(func, message)
+{
+}
 //--------------------------------------------------------------------------
 // Function:    IdComponentException destructor
 ///\brief       Noop destructor.
 //--------------------------------------------------------------------------
-IdComponentException::~IdComponentException() throw() {}
+IdComponentException::~IdComponentException() throw()
+{
+}
 
-} // end namespace
+} // namespace H5
