@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -19,31 +18,32 @@
 #include "hdf5.h"
 #define FILE "dset.h5"
 
-int main() {
+int
+main()
+{
 
-   hid_t       file_id, dataset_id, dataspace_id;  /* identifiers */
-   hsize_t     dims[2];
-   herr_t      status;
+    hid_t   file_id, dataset_id, dataspace_id; /* identifiers */
+    hsize_t dims[2];
+    herr_t  status;
 
-   /* Create a new file using default properties. */
-   file_id = H5Fcreate(FILE, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    /* Create a new file using default properties. */
+    file_id = H5Fcreate(FILE, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
 
-   /* Create the data space for the dataset. */
-   dims[0] = 4;
-   dims[1] = 6;
-   dataspace_id = H5Screate_simple(2, dims, NULL);
+    /* Create the data space for the dataset. */
+    dims[0]      = 4;
+    dims[1]      = 6;
+    dataspace_id = H5Screate_simple(2, dims, NULL);
 
-   /* Create the dataset. */
-   dataset_id = H5Dcreate2(file_id, "/dset", H5T_STD_I32BE, dataspace_id,
-                          H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
+    /* Create the dataset. */
+    dataset_id =
+        H5Dcreate2(file_id, "/dset", H5T_STD_I32BE, dataspace_id, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
 
-   /* End access to the dataset and release resources used by it. */
-   status = H5Dclose(dataset_id);
+    /* End access to the dataset and release resources used by it. */
+    status = H5Dclose(dataset_id);
 
-   /* Terminate access to the data space. */
-   status = H5Sclose(dataspace_id);
+    /* Terminate access to the data space. */
+    status = H5Sclose(dataspace_id);
 
-   /* Close the file. */
-   status = H5Fclose(file_id);
+    /* Close the file. */
+    status = H5Fclose(file_id);
 }
-
