@@ -1,18 +1,17 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-#ifndef _H5DSprivate_H
-#define _H5DSprivate_H
+#ifndef H5DSprivate_H
+#define H5DSprivate_H
 
 /* High-level library internal header file */
 #include "H5HLprivate2.h"
@@ -20,21 +19,15 @@
 /* public LT prototypes			*/
 #include "H5DSpublic.h"
 
-
-
-
 /* attribute type of a DS dataset */
 typedef struct ds_list_t {
- hobj_ref_t ref;     /* object reference  */
- unsigned int dim_idx; /* dimension index of the dataset */
+    hobj_ref_t   ref;     /* object reference  */
+    unsigned int dim_idx; /* dimension index of the dataset */
 } ds_list_t;
 
-
 /*-------------------------------------------------------------------------
  * private functions
  *-------------------------------------------------------------------------
  */
 
-
 #endif
-
