@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -32,47 +31,48 @@ import hdf.hdf5lib.H5;
 import hdf.hdf5lib.HDF5Constants;
 
 public class H5Ex_D_UnlimitedGzip {
-    private static String FILENAME = "H5Ex_D_UnlimitedGzip.h5";
+    private static String FILENAME    = "H5Ex_D_UnlimitedGzip.h5";
     private static String DATASETNAME = "DS1";
-    private static final int DIM_X = 4;
-    private static final int DIM_Y = 7;
-    private static final int EDIM_X = 6;
-    private static final int EDIM_Y = 10;
-    private static final int CHUNK_X = 4;
-    private static final int CHUNK_Y = 4;
-    private static final int RANK = 2;
-    private static final int NDIMS = 2;
+    private static final int DIM_X    = 4;
+    private static final int DIM_Y    = 7;
+    private static final int EDIM_X   = 6;
+    private static final int EDIM_Y   = 10;
+    private static final int CHUNK_X  = 4;
+    private static final int CHUNK_Y  = 4;
+    private static final int RANK     = 2;
+    private static final int NDIMS    = 2;
 
     // Values for the status of space allocation
     enum H5Z_filter {
-        H5Z_FILTER_ERROR(HDF5Constants.H5Z_FILTER_ERROR), H5Z_FILTER_NONE(HDF5Constants.H5Z_FILTER_NONE), H5Z_FILTER_DEFLATE(
-                HDF5Constants.H5Z_FILTER_DEFLATE), H5Z_FILTER_SHUFFLE(HDF5Constants.H5Z_FILTER_SHUFFLE), H5Z_FILTER_FLETCHER32(
-                HDF5Constants.H5Z_FILTER_FLETCHER32), H5Z_FILTER_SZIP(HDF5Constants.H5Z_FILTER_SZIP), H5Z_FILTER_NBIT(
-                HDF5Constants.H5Z_FILTER_NBIT), H5Z_FILTER_SCALEOFFSET(HDF5Constants.H5Z_FILTER_SCALEOFFSET), H5Z_FILTER_RESERVED(
-                HDF5Constants.H5Z_FILTER_RESERVED), H5Z_FILTER_MAX(HDF5Constants.H5Z_FILTER_MAX);
+        H5Z_FILTER_ERROR(HDF5Constants.H5Z_FILTER_ERROR),
+        H5Z_FILTER_NONE(HDF5Constants.H5Z_FILTER_NONE),
+        H5Z_FILTER_DEFLATE(HDF5Constants.H5Z_FILTER_DEFLATE),
+        H5Z_FILTER_SHUFFLE(HDF5Constants.H5Z_FILTER_SHUFFLE),
+        H5Z_FILTER_FLETCHER32(HDF5Constants.H5Z_FILTER_FLETCHER32),
+        H5Z_FILTER_SZIP(HDF5Constants.H5Z_FILTER_SZIP),
+        H5Z_FILTER_NBIT(HDF5Constants.H5Z_FILTER_NBIT),
+        H5Z_FILTER_SCALEOFFSET(HDF5Constants.H5Z_FILTER_SCALEOFFSET),
+        H5Z_FILTER_RESERVED(HDF5Constants.H5Z_FILTER_RESERVED),
+        H5Z_FILTER_MAX(HDF5Constants.H5Z_FILTER_MAX);
         private static final Map<Integer, H5Z_filter> lookup = new HashMap<Integer, H5Z_filter>();
 
-        static {
+        static
+        {
             for (H5Z_filter s : EnumSet.allOf(H5Z_filter.class))
                 lookup.put(s.getCode(), s);
         }
 
         private int code;
 
-        H5Z_filter(int layout_type) {
-            this.code = layout_type;
-        }
+        H5Z_filter(int layout_type) { this.code = layout_type; }
 
-        public int getCode() {
-            return this.code;
-        }
+        public int getCode() { return this.code; }
 
-        public static H5Z_filter get(int code) {
-            return lookup.get(code);
-        }
+        public static H5Z_filter get(int code) { return lookup.get(code); }
     }
 
-    private static boolean checkGzipFilter() {
+    private static boolean checkGzipFilter()
+    {
         try {
             int available = H5.H5Zfilter_avail(HDF5Constants.H5Z_FILTER_DEFLATE);
             if (available == 0) {
@@ -86,8 +86,8 @@ public class H5Ex_D_UnlimitedGzip {
 
         try {
             int filter_info = H5.H5Zget_filter_info(HDF5Constants.H5Z_FILTER_DEFLATE);
-            if (((filter_info & HDF5Constants.H5Z_FILTER_CONFIG_ENCODE_ENABLED) == 0)
-                    || ((filter_info & HDF5Constants.H5Z_FILTER_CONFIG_DECODE_ENABLED) == 0)) {
+            if (((filter_info & HDF5Constants.H5Z_FILTER_CONFIG_ENCODE_ENABLED) == 0) ||
+                ((filter_info & HDF5Constants.H5Z_FILTER_CONFIG_DECODE_ENABLED) == 0)) {
                 System.out.println("gzip filter not available for encoding and decoding.");
                 return false;
             }
@@ -98,14 +98,15 @@ public class H5Ex_D_UnlimitedGzip {
         return true;
     }
 
-    private static void writeUnlimited() {
-        long file_id = -1;
-        long dcpl_id = -1;
-        long dataspace_id = -1;
-        long dataset_id = -1;
-        long[] dims = { DIM_X, DIM_Y };
-        long[] chunk_dims = { CHUNK_X, CHUNK_Y };
-        long[] maxdims = { HDF5Constants.H5S_UNLIMITED, HDF5Constants.H5S_UNLIMITED };
+    private static void writeUnlimited()
+    {
+        long file_id      = HDF5Constants.H5I_INVALID_HID;
+        long dcpl_id      = HDF5Constants.H5I_INVALID_HID;
+        long dataspace_id = HDF5Constants.H5I_INVALID_HID;
+        long dataset_id   = HDF5Constants.H5I_INVALID_HID;
+        long[] dims       = {DIM_X, DIM_Y};
+        long[] chunk_dims = {CHUNK_X, CHUNK_Y};
+        long[] maxdims    = {HDF5Constants.H5S_UNLIMITED, HDF5Constants.H5S_UNLIMITED};
         int[][] dset_data = new int[DIM_X][DIM_Y];
 
         // Initialize the dataset.
@@ -116,7 +117,7 @@ public class H5Ex_D_UnlimitedGzip {
         // Create a new file using default properties.
         try {
             file_id = H5.H5Fcreate(FILENAME, HDF5Constants.H5F_ACC_TRUNC, HDF5Constants.H5P_DEFAULT,
-                    HDF5Constants.H5P_DEFAULT);
+                                   HDF5Constants.H5P_DEFAULT);
         }
         catch (Exception e) {
             e.printStackTrace();
@@ -148,7 +149,7 @@ public class H5Ex_D_UnlimitedGzip {
         try {
             if ((file_id >= 0) && (dataspace_id >= 0) && (dcpl_id >= 0))
                 dataset_id = H5.H5Dcreate(file_id, DATASETNAME, HDF5Constants.H5T_STD_I32LE, dataspace_id,
-                        HDF5Constants.H5P_DEFAULT, dcpl_id, HDF5Constants.H5P_DEFAULT);
+                                          HDF5Constants.H5P_DEFAULT, dcpl_id, HDF5Constants.H5P_DEFAULT);
         }
         catch (Exception e) {
             e.printStackTrace();
@@ -157,8 +158,8 @@ public class H5Ex_D_UnlimitedGzip {
         // Write the data to the dataset.
         try {
             if (dataset_id >= 0)
-                H5.H5Dwrite(dataset_id, HDF5Constants.H5T_NATIVE_INT, HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL,
-                        HDF5Constants.H5P_DEFAULT, dset_data);
+                H5.H5Dwrite(dataset_id, HDF5Constants.H5T_NATIVE_INT, HDF5Constants.H5S_ALL,
+                            HDF5Constants.H5S_ALL, HDF5Constants.H5P_DEFAULT, dset_data);
         }
         catch (Exception e) {
             e.printStackTrace();
@@ -199,14 +200,15 @@ public class H5Ex_D_UnlimitedGzip {
         }
     }
 
-    private static void extendUnlimited() {
-        long file_id = -1;
-        long dataspace_id = -1;
-        long dataset_id = -1;
-        long[] dims = { DIM_X, DIM_Y };
-        long[] extdims = { EDIM_X, EDIM_Y };
-        long[] start = { 0, 0 };
-        long[] count = new long[2];
+    private static void extendUnlimited()
+    {
+        long file_id      = HDF5Constants.H5I_INVALID_HID;
+        long dataspace_id = HDF5Constants.H5I_INVALID_HID;
+        long dataset_id   = HDF5Constants.H5I_INVALID_HID;
+        long[] dims       = {DIM_X, DIM_Y};
+        long[] extdims    = {EDIM_X, EDIM_Y};
+        long[] start      = {0, 0};
+        long[] count      = new long[2];
         int[][] dset_data;
         int[][] extend_dset_data = new int[EDIM_X][EDIM_Y];
 
@@ -247,13 +249,13 @@ public class H5Ex_D_UnlimitedGzip {
         }
 
         // Allocate array of pointers to rows.
-        dset_data = new int[(int) dims[0]][(int) dims[1]];
+        dset_data = new int[(int)dims[0]][(int)dims[1]];
 
         // Read the data using the default properties.
         try {
             if (dataset_id >= 0)
-                H5.H5Dread(dataset_id, HDF5Constants.H5T_NATIVE_INT, HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL,
-                        HDF5Constants.H5P_DEFAULT, dset_data);
+                H5.H5Dread(dataset_id, HDF5Constants.H5T_NATIVE_INT, HDF5Constants.H5S_ALL,
+                           HDF5Constants.H5S_ALL, HDF5Constants.H5P_DEFAULT, dset_data);
         }
         catch (Exception e) {
             e.printStackTrace();
@@ -315,7 +317,7 @@ public class H5Ex_D_UnlimitedGzip {
                 // Write the data to the selected portion of the dataset.
                 if (dataset_id >= 0)
                     H5.H5Dwrite(dataset_id, HDF5Constants.H5T_NATIVE_INT, HDF5Constants.H5S_ALL, dataspace_id,
-                            HDF5Constants.H5P_DEFAULT, extend_dset_data);
+                                HDF5Constants.H5P_DEFAULT, extend_dset_data);
             }
         }
         catch (Exception e) {
@@ -349,12 +351,13 @@ public class H5Ex_D_UnlimitedGzip {
         }
     }
 
-    private static void readUnlimited() {
-        long file_id = -1;
-        long dataspace_id = -1;
-        long dataset_id = -1;
-        long dcpl_id = -1;
-        long[] dims = { DIM_X, DIM_Y };
+    private static void readUnlimited()
+    {
+        long file_id      = HDF5Constants.H5I_INVALID_HID;
+        long dataspace_id = HDF5Constants.H5I_INVALID_HID;
+        long dataset_id   = HDF5Constants.H5I_INVALID_HID;
+        long dcpl_id      = HDF5Constants.H5I_INVALID_HID;
+        long[] dims       = {DIM_X, DIM_Y};
         int[][] dset_data;
 
         // Open an existing file.
@@ -388,14 +391,14 @@ public class H5Ex_D_UnlimitedGzip {
         try {
             if (dcpl_id >= 0) {
                 // Java lib requires a valid filter_name object and cd_values
-                int[] flags = { 0 };
-                long[] cd_nelmts = { 1 };
-                int[] cd_values = { 0 };
-                String[] filter_name = { "" };
-                int[] filter_config = { 0 };
-                int filter_type = -1;
-                filter_type = H5
-                        .H5Pget_filter(dcpl_id, 0, flags, cd_nelmts, cd_values, 120, filter_name, filter_config);
+                int[] flags          = {0};
+                long[] cd_nelmts     = {1};
+                int[] cd_values      = {0};
+                String[] filter_name = {""};
+                int[] filter_config  = {0};
+                int filter_type      = -1;
+                filter_type = H5.H5Pget_filter(dcpl_id, 0, flags, cd_nelmts, cd_values, 120, filter_name,
+                                               filter_config);
                 System.out.print("Filter type is: ");
                 switch (H5Z_filter.get(filter_type)) {
                 case H5Z_FILTER_DEFLATE:
@@ -437,13 +440,13 @@ public class H5Ex_D_UnlimitedGzip {
             e.printStackTrace();
         }
         // Allocate array of pointers to rows.
-        dset_data = new int[(int) dims[0]][(int) dims[1]];
+        dset_data = new int[(int)dims[0]][(int)dims[1]];
 
         // Read the data using the default properties.
         try {
             if (dataset_id >= 0)
-                H5.H5Dread(dataset_id, HDF5Constants.H5T_NATIVE_INT, HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL,
-                        HDF5Constants.H5P_DEFAULT, dset_data);
+                H5.H5Dread(dataset_id, HDF5Constants.H5T_NATIVE_INT, HDF5Constants.H5S_ALL,
+                           HDF5Constants.H5S_ALL, HDF5Constants.H5P_DEFAULT, dset_data);
         }
         catch (Exception e) {
             e.printStackTrace();
@@ -486,7 +489,8 @@ public class H5Ex_D_UnlimitedGzip {
         }
     }
 
-    public static void main(String[] args) {
+    public static void main(String[] args)
+    {
         // Check if gzip compression is available and can be used for both
         // compression and decompression. Normally we do not perform error
         // checking in these examples for the sake of clarity, but in this
@@ -498,5 +502,4 @@ public class H5Ex_D_UnlimitedGzip {
             H5Ex_D_UnlimitedGzip.readUnlimited();
         }
     }
-
 }
