@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -46,8 +45,7 @@ extern "C" {
  * Signature: ()I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5open
-    (JNIEnv *env, jclass clss)
+Java_hdf_hdf5lib_H5_H5open(JNIEnv *env, jclass clss)
 {
     herr_t retVal = FAIL;
 
@@ -66,8 +64,7 @@ done:
  * Signature: ()I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5close
-    (JNIEnv *env, jclass clss)
+Java_hdf_hdf5lib_H5_H5close(JNIEnv *env, jclass clss)
 {
     herr_t retVal = FAIL;
 
@@ -86,8 +83,7 @@ done:
  * Signature: ()I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5dont_1atexit
-    (JNIEnv *env, jclass clss)
+Java_hdf_hdf5lib_H5_H5dont_1atexit(JNIEnv *env, jclass clss)
 {
     herr_t retVal = FAIL;
 
@@ -106,21 +102,22 @@ done:
  * Signature: ([I)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5get_1libversion
-    (JNIEnv *env, jclass clss, jintArray libversion)
+Java_hdf_hdf5lib_H5_H5get_1libversion(JNIEnv *env, jclass clss, jintArray libversion)
 {
-    jboolean  libversionArrayIsCopy;
-    int      *libversionArray = NULL;
-    herr_t    status = FAIL;
+    jboolean libversionArrayIsCopy;
+    int     *libversionArray = NULL;
+    herr_t   status          = FAIL;
 
     UNUSED(clss);
 
     if (libversion == NULL)
         H5_NULL_ARGUMENT_ERROR(ENVONLY, "H5get_libversion: libversion is NULL");
 
-    PIN_INT_ARRAY(ENVONLY, libversion, libversionArray, &libversionArrayIsCopy, "H5get_libversion: libversion input not pinned");
+    PIN_INT_ARRAY(ENVONLY, libversion, libversionArray, &libversionArrayIsCopy,
+                  "H5get_libversion: libversion input not pinned");
 
-    if ((status = H5get_libversion((unsigned *) &(libversionArray[0]), (unsigned *) &(libversionArray[1]), (unsigned *) &(libversionArray[2]))) < 0)
+    if ((status = H5get_libversion((unsigned *)&(libversionArray[0]), (unsigned *)&(libversionArray[1]),
+                                   (unsigned *)&(libversionArray[2]))) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
 done:
@@ -136,8 +133,7 @@ done:
  * Signature: (III)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5check_1version
-    (JNIEnv *env, jclass clss, jint majnum, jint minnum, jint relnum)
+Java_hdf_hdf5lib_H5_H5check_1version(JNIEnv *env, jclass clss, jint majnum, jint minnum, jint relnum)
 {
     UNUSED(env);
     UNUSED(clss);
@@ -152,8 +148,7 @@ Java_hdf_hdf5lib_H5_H5check_1version
  *
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5garbage_1collect
-    (JNIEnv *env, jclass clss)
+Java_hdf_hdf5lib_H5_H5garbage_1collect(JNIEnv *env, jclass clss)
 {
     herr_t retVal = FAIL;
 
@@ -172,16 +167,16 @@ done:
  * Signature: (IIIIII)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5set_1free_1list_1limits
-    (JNIEnv *env, jclass clss, jint reg_global_lim, jint reg_list_lim,
-        jint arr_global_lim, jint arr_list_lim, jint blk_global_lim, jint blk_list_lim )
+Java_hdf_hdf5lib_H5_H5set_1free_1list_1limits(JNIEnv *env, jclass clss, jint reg_global_lim,
+                                              jint reg_list_lim, jint arr_global_lim, jint arr_list_lim,
+                                              jint blk_global_lim, jint blk_list_lim)
 {
     herr_t retVal = FAIL;
 
     UNUSED(clss);
 
-    if ((retVal = H5set_free_list_limits((int)reg_global_lim, (int)reg_list_lim,
-            (int)arr_global_lim, (int)arr_list_lim, (int)blk_global_lim, (int)blk_list_lim)) < 0)
+    if ((retVal = H5set_free_list_limits((int)reg_global_lim, (int)reg_list_lim, (int)arr_global_lim,
+                                         (int)arr_list_lim, (int)blk_global_lim, (int)blk_list_lim)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
 done:
@@ -194,8 +189,7 @@ done:
  * Signature: ()Z
  */
 JNIEXPORT jboolean JNICALL
-Java_hdf_hdf5lib_H5_H5is_1library_1threadsafe
-    (JNIEnv *env, jclass clss)
+Java_hdf_hdf5lib_H5_H5is_1library_1threadsafe(JNIEnv *env, jclass clss)
 {
     hbool_t is_ts = false;
 
@@ -208,7 +202,6 @@ done:
     return (jboolean)is_ts;
 } /* end Java_hdf_hdf5lib_H5_H5is_1library_1threadsafe */
 
-
 #ifdef __cplusplus
 } /* end extern "C" */
 #endif /* __cplusplus */
