@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -48,11 +47,10 @@ static herr_t H5O_iterate_cb(hid_t g_id, const char *name, const H5O_info_t *inf
  * Signature: (JLjava/lang/String;J)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5__1H5Oopen
-    (JNIEnv *env, jclass clss, jlong loc_id, jstring name, jlong access_plist_id)
+Java_hdf_hdf5lib_H5__1H5Oopen(JNIEnv *env, jclass clss, jlong loc_id, jstring name, jlong access_plist_id)
 {
     const char *objName = NULL;
-    hid_t       status = H5I_INVALID_HID;
+    hid_t       status  = H5I_INVALID_HID;
 
     UNUSED(clss);
 
@@ -77,8 +75,7 @@ done:
  * Signature: (J)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5__1H5Oclose
-    (JNIEnv *env, jclass clss, jlong object_id)
+Java_hdf_hdf5lib_H5__1H5Oclose(JNIEnv *env, jclass clss, jlong object_id)
 {
     herr_t retVal = FAIL;
 
@@ -97,13 +94,12 @@ done:
  * Signature: (JLjava/lang/String;JLjava/lang/String;JJ)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Ocopy
-    (JNIEnv *env, jclass clss, jlong cur_loc_id, jstring cur_name,
-        jlong dst_loc_id, jstring dst_name, jlong create_id, jlong access_id)
+Java_hdf_hdf5lib_H5_H5Ocopy(JNIEnv *env, jclass clss, jlong cur_loc_id, jstring cur_name, jlong dst_loc_id,
+                            jstring dst_name, jlong create_id, jlong access_id)
 {
     const char *lCurName = NULL;
     const char *lDstName = NULL;
-    herr_t      status = FAIL;
+    herr_t      status   = FAIL;
 
     UNUSED(clss);
 
@@ -115,7 +111,8 @@ Java_hdf_hdf5lib_H5_H5Ocopy
     PIN_JAVA_STRING(ENVONLY, cur_name, lCurName, NULL, "H5Ocopy: src name not pinned");
     PIN_JAVA_STRING(ENVONLY, dst_name, lDstName, NULL, "H5Ocopy: dest name not pinned");
 
-    if ((status = H5Ocopy((hid_t)cur_loc_id, lCurName, (hid_t)dst_loc_id, lDstName, (hid_t)create_id, (hid_t)access_id)) < 0)
+    if ((status = H5Ocopy((hid_t)cur_loc_id, lCurName, (hid_t)dst_loc_id, lDstName, (hid_t)create_id,
+                          (hid_t)access_id)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
 done:
@@ -131,15 +128,14 @@ done:
  * Signature: (JI)Lhdf/hdf5lib/structs/H5O_info_t;
  */
 JNIEXPORT jobject JNICALL
-Java_hdf_hdf5lib_H5_H5Oget_1info
-    (JNIEnv *env, jclass clss, jlong loc_id, jint fields)
+Java_hdf_hdf5lib_H5_H5Oget_1info(JNIEnv *env, jclass clss, jlong loc_id, jint fields)
 {
     H5O_info_t infobuf;
     jobject    hdrinfobuf;
     jobject    ihinfobuf1;
     jobject    ihinfobuf2;
     jvalue     args[12];
-    herr_t     status = FAIL;
+    herr_t     status  = FAIL;
     jobject    ret_obj = NULL;
 
     UNUSED(clss);
@@ -173,20 +169,23 @@ Java_hdf_hdf5lib_H5_H5Oget_1info
     CALL_CONSTRUCTOR(ENVONLY, "hdf/hdf5lib/structs/H5_ih_info_t", "(JJ)V", args, ret_obj);
     ihinfobuf2 = ret_obj;
 
-    args[0].j = (jlong)infobuf.fileno;
-    args[1].j = (jlong)infobuf.addr;
-    args[2].i = infobuf.type;
-    args[3].i = (jint)infobuf.rc;
-    args[4].j = (jlong)infobuf.num_attrs;
-    args[5].j = infobuf.atime;
-    args[6].j = infobuf.mtime;
-    args[7].j = infobuf.ctime;
-    args[8].j = infobuf.btime;
-    args[9].l = hdrinfobuf;
+    args[0].j  = (jlong)infobuf.fileno;
+    args[1].j  = (jlong)infobuf.addr;
+    args[2].i  = infobuf.type;
+    args[3].i  = (jint)infobuf.rc;
+    args[4].j  = (jlong)infobuf.num_attrs;
+    args[5].j  = infobuf.atime;
+    args[6].j  = infobuf.mtime;
+    args[7].j  = infobuf.ctime;
+    args[8].j  = infobuf.btime;
+    args[9].l  = hdrinfobuf;
     args[10].l = ihinfobuf1;
     args[11].l = ihinfobuf2;
 
-    CALL_CONSTRUCTOR(ENVONLY, "hdf/hdf5lib/structs/H5O_info_t", "(JJIIJJJJJLhdf/hdf5lib/structs/H5O_hdr_info_t;Lhdf/hdf5lib/structs/H5_ih_info_t;Lhdf/hdf5lib/structs/H5_ih_info_t;)V", args, ret_obj);
+    CALL_CONSTRUCTOR(ENVONLY, "hdf/hdf5lib/structs/H5O_info_t",
+                     "(JJIIJJJJJLhdf/hdf5lib/structs/H5O_hdr_info_t;Lhdf/hdf5lib/structs/H5_ih_info_t;Lhdf/"
+                     "hdf5lib/structs/H5_ih_info_t;)V",
+                     args, ret_obj);
 
 done:
     return ret_obj;
@@ -198,8 +197,8 @@ done:
  * Signature: (JLjava/lang/String;IJ)Lhdf/hdf5lib/structs/H5O_info_t;
  */
 JNIEXPORT jobject JNICALL
-Java_hdf_hdf5lib_H5_H5Oget_1info_1by_1name
-    (JNIEnv *env, jclass clss, jlong loc_id, jstring name, jint fields, jlong access_id)
+Java_hdf_hdf5lib_H5_H5Oget_1info_1by_1name(JNIEnv *env, jclass clss, jlong loc_id, jstring name, jint fields,
+                                           jlong access_id)
 {
     H5O_info_t  infobuf;
     const char *objName = NULL;
@@ -207,7 +206,7 @@ Java_hdf_hdf5lib_H5_H5Oget_1info_1by_1name
     jobject     ihinfobuf1;
     jobject     ihinfobuf2;
     jvalue      args[12];
-    herr_t      status = FAIL;
+    herr_t      status  = FAIL;
     jobject     ret_obj = NULL;
 
     UNUSED(clss);
@@ -217,7 +216,8 @@ Java_hdf_hdf5lib_H5_H5Oget_1info_1by_1name
 
     PIN_JAVA_STRING(ENVONLY, name, objName, NULL, "H5Oget_info_by_name: object name not pinned");
 
-    if ((status = H5Oget_info_by_name2((hid_t)loc_id, objName, &infobuf, (unsigned)fields, (hid_t)access_id)) < 0)
+    if ((status =
+             H5Oget_info_by_name2((hid_t)loc_id, objName, &infobuf, (unsigned)fields, (hid_t)access_id)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
     args[0].i = (jint)infobuf.hdr.version;
@@ -246,20 +246,23 @@ Java_hdf_hdf5lib_H5_H5Oget_1info_1by_1name
     CALL_CONSTRUCTOR(ENVONLY, "hdf/hdf5lib/structs/H5_ih_info_t", "(JJ)V", args, ret_obj);
     ihinfobuf2 = ret_obj;
 
-    args[0].j = (jlong)infobuf.fileno;
-    args[1].j = (jlong)infobuf.addr;
-    args[2].i = infobuf.type;
-    args[3].i = (jint)infobuf.rc;
-    args[4].j = (jlong)infobuf.num_attrs;
-    args[5].j = infobuf.atime;
-    args[6].j = infobuf.mtime;
-    args[7].j = infobuf.ctime;
-    args[8].j = infobuf.btime;
-    args[9].l = hdrinfobuf;
+    args[0].j  = (jlong)infobuf.fileno;
+    args[1].j  = (jlong)infobuf.addr;
+    args[2].i  = infobuf.type;
+    args[3].i  = (jint)infobuf.rc;
+    args[4].j  = (jlong)infobuf.num_attrs;
+    args[5].j  = infobuf.atime;
+    args[6].j  = infobuf.mtime;
+    args[7].j  = infobuf.ctime;
+    args[8].j  = infobuf.btime;
+    args[9].l  = hdrinfobuf;
     args[10].l = ihinfobuf1;
     args[11].l = ihinfobuf2;
 
-    CALL_CONSTRUCTOR(ENVONLY, "hdf/hdf5lib/structs/H5O_info_t", "(JJIIJJJJJLhdf/hdf5lib/structs/H5O_hdr_info_t;Lhdf/hdf5lib/structs/H5_ih_info_t;Lhdf/hdf5lib/structs/H5_ih_info_t;)V", args, ret_obj);
+    CALL_CONSTRUCTOR(ENVONLY, "hdf/hdf5lib/structs/H5O_info_t",
+                     "(JJIIJJJJJLhdf/hdf5lib/structs/H5O_hdr_info_t;Lhdf/hdf5lib/structs/H5_ih_info_t;Lhdf/"
+                     "hdf5lib/structs/H5_ih_info_t;)V",
+                     args, ret_obj);
 
 done:
     if (objName)
@@ -274,9 +277,9 @@ done:
  * Signature: (JLjava/lang/String;IIJIJ)Lhdf/hdf5lib/structs/H5O_info_t;
  */
 JNIEXPORT jobject JNICALL
-Java_hdf_hdf5lib_H5_H5Oget_1info_1by_1idx
-    (JNIEnv *env, jclass clss, jlong loc_id,
-        jstring name, jint index_field, jint order, jlong link_n, jint fields, jlong access_id)
+Java_hdf_hdf5lib_H5_H5Oget_1info_1by_1idx(JNIEnv *env, jclass clss, jlong loc_id, jstring name,
+                                          jint index_field, jint order, jlong link_n, jint fields,
+                                          jlong access_id)
 {
     H5O_info_t  infobuf;
     const char *grpName = NULL;
@@ -284,7 +287,7 @@ Java_hdf_hdf5lib_H5_H5Oget_1info_1by_1idx
     jobject     ihinfobuf1;
     jobject     ihinfobuf2;
     jvalue      args[12];
-    herr_t      status = FAIL;
+    herr_t      status  = FAIL;
     jobject     ret_obj = NULL;
 
     UNUSED(clss);
@@ -294,7 +297,8 @@ Java_hdf_hdf5lib_H5_H5Oget_1info_1by_1idx
 
     PIN_JAVA_STRING(ENVONLY, name, grpName, NULL, "H5Oget_info_by_idx: group name not pinned");
 
-    if ((status = H5Oget_info_by_idx2((hid_t)loc_id, grpName, (H5_index_t)index_field, (H5_iter_order_t)order, (hsize_t)link_n, &infobuf, (unsigned)fields, (hid_t)access_id)) < 0)
+    if ((status = H5Oget_info_by_idx2((hid_t)loc_id, grpName, (H5_index_t)index_field, (H5_iter_order_t)order,
+                                      (hsize_t)link_n, &infobuf, (unsigned)fields, (hid_t)access_id)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
     args[0].i = (jint)infobuf.hdr.version;
@@ -323,20 +327,23 @@ Java_hdf_hdf5lib_H5_H5Oget_1info_1by_1idx
     CALL_CONSTRUCTOR(ENVONLY, "hdf/hdf5lib/structs/H5_ih_info_t", "(JJ)V", args, ret_obj);
     ihinfobuf2 = ret_obj;
 
-    args[0].j = (jlong)infobuf.fileno;
-    args[1].j = (jlong)infobuf.addr;
-    args[2].i = infobuf.type;
-    args[3].i = (jint)infobuf.rc;
-    args[4].j = (jlong)infobuf.num_attrs;
-    args[5].j = infobuf.atime;
-    args[6].j = infobuf.mtime;
-    args[7].j = infobuf.ctime;
-    args[8].j = infobuf.btime;
-    args[9].l = hdrinfobuf;
+    args[0].j  = (jlong)infobuf.fileno;
+    args[1].j  = (jlong)infobuf.addr;
+    args[2].i  = infobuf.type;
+    args[3].i  = (jint)infobuf.rc;
+    args[4].j  = (jlong)infobuf.num_attrs;
+    args[5].j  = infobuf.atime;
+    args[6].j  = infobuf.mtime;
+    args[7].j  = infobuf.ctime;
+    args[8].j  = infobuf.btime;
+    args[9].l  = hdrinfobuf;
     args[10].l = ihinfobuf1;
     args[11].l = ihinfobuf2;
 
-    CALL_CONSTRUCTOR(ENVONLY, "hdf/hdf5lib/structs/H5O_info_t", "(JJIIJJJJJLhdf/hdf5lib/structs/H5O_hdr_info_t;Lhdf/hdf5lib/structs/H5_ih_info_t;Lhdf/hdf5lib/structs/H5_ih_info_t;)V", args, ret_obj);
+    CALL_CONSTRUCTOR(ENVONLY, "hdf/hdf5lib/structs/H5O_info_t",
+                     "(JJIIJJJJJLhdf/hdf5lib/structs/H5O_hdr_info_t;Lhdf/hdf5lib/structs/H5_ih_info_t;Lhdf/"
+                     "hdf5lib/structs/H5_ih_info_t;)V",
+                     args, ret_obj);
 
 done:
     if (grpName)
@@ -351,12 +358,11 @@ done:
  * Signature: (JJLjava/lang/String;JJ)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Olink
-    (JNIEnv *env, jclass clss, jlong cur_loc_id, jlong dst_loc_id,
-        jstring dst_name, jlong create_id, jlong access_id)
+Java_hdf_hdf5lib_H5_H5Olink(JNIEnv *env, jclass clss, jlong cur_loc_id, jlong dst_loc_id, jstring dst_name,
+                            jlong create_id, jlong access_id)
 {
     const char *linkDstName = NULL;
-    herr_t      status = FAIL;
+    herr_t      status      = FAIL;
 
     UNUSED(clss);
 
@@ -365,7 +371,8 @@ Java_hdf_hdf5lib_H5_H5Olink
 
     PIN_JAVA_STRING(ENVONLY, dst_name, linkDstName, NULL, "H5Olink: link destination name not pinned");
 
-    if ((status = H5Olink((hid_t)cur_loc_id, (hid_t)dst_loc_id, linkDstName, (hid_t)create_id, (hid_t)access_id)) < 0)
+    if ((status = H5Olink((hid_t)cur_loc_id, (hid_t)dst_loc_id, linkDstName, (hid_t)create_id,
+                          (hid_t)access_id)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
 done:
@@ -374,14 +381,13 @@ done:
 } /* end Java_hdf_hdf5lib_H5_H5Olink */
 
 static herr_t
-H5O_iterate_cb
-    (hid_t g_id, const char *name, const H5O_info_t *info, void *cb_data)
+H5O_iterate_cb(hid_t g_id, const char *name, const H5O_info_t *info, void *cb_data)
 {
     cb_wrapper *wrapper = (cb_wrapper *)cb_data;
     jmethodID   mid;
-    jobject     cb_info_t = NULL;
+    jobject     cb_info_t      = NULL;
     jobject     visit_callback = wrapper->visit_callback;
-    jobject     ret_obj = NULL;
+    jobject     ret_obj        = NULL;
     jobject     hdrinfobuf;
     jobject     ihinfobuf1;
     jobject     ihinfobuf2;
@@ -390,7 +396,7 @@ H5O_iterate_cb
     jclass      cbcls;
     jvalue      args[12];
     void       *op_data = (void *)wrapper->op_data;
-    jint        status = FAIL;
+    jint        status  = FAIL;
 
     if (JVMPTR->AttachCurrentThread(JVMPAR, (void **)&cbenv, NULL) < 0) {
         CHECK_JNI_EXCEPTION(CBENVONLY, JNI_TRUE);
@@ -400,7 +406,10 @@ H5O_iterate_cb
     if (NULL == (cbcls = CBENVPTR->GetObjectClass(CBENVONLY, visit_callback)))
         CHECK_JNI_EXCEPTION(CBENVONLY, JNI_FALSE);
 
-    if (NULL == (mid = CBENVPTR->GetMethodID(CBENVONLY, cbcls, "callback", "(JLjava/lang/String;Lhdf/hdf5lib/structs/H5O_info_t;Lhdf/hdf5lib/callbacks/H5O_iterate_t;)I")))
+    if (NULL ==
+        (mid = CBENVPTR->GetMethodID(
+             CBENVONLY, cbcls, "callback",
+             "(JLjava/lang/String;Lhdf/hdf5lib/structs/H5O_info_t;Lhdf/hdf5lib/callbacks/H5O_iterate_t;)I")))
         CHECK_JNI_EXCEPTION(CBENVONLY, JNI_FALSE);
 
     if (NULL == (str = CBENVPTR->NewStringUTF(CBENVONLY, name)))
@@ -434,21 +443,24 @@ H5O_iterate_cb
     CALL_CONSTRUCTOR(CBENVONLY, "hdf/hdf5lib/structs/H5_ih_info_t", "(JJ)V", args, ret_obj);
     ihinfobuf2 = ret_obj;
 
-    args[0].j = (jlong)info->fileno;
-    args[1].j = (jlong)info->addr;
-    args[2].i = info->type;
-    args[3].i = (jint)info->rc;
-    args[4].j = (jlong)info->num_attrs;
-    args[5].j = info->atime;
-    args[6].j = info->mtime;
-    args[7].j = info->ctime;
-    args[8].j = info->btime;
-    args[9].l = hdrinfobuf;
+    args[0].j  = (jlong)info->fileno;
+    args[1].j  = (jlong)info->addr;
+    args[2].i  = info->type;
+    args[3].i  = (jint)info->rc;
+    args[4].j  = (jlong)info->num_attrs;
+    args[5].j  = info->atime;
+    args[6].j  = info->mtime;
+    args[7].j  = info->ctime;
+    args[8].j  = info->btime;
+    args[9].l  = hdrinfobuf;
     args[10].l = ihinfobuf1;
     args[11].l = ihinfobuf2;
 
     /* Get a reference to the H5O_info_t class */
-    CALL_CONSTRUCTOR(CBENVONLY, "hdf/hdf5lib/structs/H5O_info_t", "(JJIIJJJJJLhdf/hdf5lib/structs/H5O_hdr_info_t;Lhdf/hdf5lib/structs/H5_ih_info_t;Lhdf/hdf5lib/structs/H5_ih_info_t;)V", args, cb_info_t) ;
+    CALL_CONSTRUCTOR(CBENVONLY, "hdf/hdf5lib/structs/H5O_info_t",
+                     "(JJIIJJJJJLhdf/hdf5lib/structs/H5O_hdr_info_t;Lhdf/hdf5lib/structs/H5_ih_info_t;Lhdf/"
+                     "hdf5lib/structs/H5_ih_info_t;)V",
+                     args, cb_info_t);
 
     status = CBENVPTR->CallIntMethod(CBENVONLY, visit_callback, mid, g_id, str, cb_info_t, op_data);
     CHECK_JNI_EXCEPTION(CBENVONLY, JNI_FALSE);
@@ -466,12 +478,11 @@ done:
  * Signature: (JIILjava/lang/Object;Ljava/lang/Object;I)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Ovisit
-    (JNIEnv *env, jclass clss, jlong grp_id, jint idx_type, jint order,
-        jobject callback_op, jobject op_data, jint fields)
+Java_hdf_hdf5lib_H5_H5Ovisit(JNIEnv *env, jclass clss, jlong grp_id, jint idx_type, jint order,
+                             jobject callback_op, jobject op_data, jint fields)
 {
-    cb_wrapper wrapper = { callback_op, op_data };
-    herr_t     status = FAIL;
+    cb_wrapper wrapper = {callback_op, op_data};
+    herr_t     status  = FAIL;
 
     UNUSED(clss);
 
@@ -483,7 +494,8 @@ Java_hdf_hdf5lib_H5_H5Ovisit
     if (NULL == callback_op)
         H5_NULL_ARGUMENT_ERROR(ENVONLY, "H5Ovisit: callback_op is NULL");
 
-    if ((status = H5Ovisit2((hid_t)grp_id, (H5_index_t)idx_type, (H5_iter_order_t)order, (H5O_iterate_t)H5O_iterate_cb, (void *)&wrapper, (unsigned)fields)) < 0)
+    if ((status = H5Ovisit2((hid_t)grp_id, (H5_index_t)idx_type, (H5_iter_order_t)order,
+                            (H5O_iterate_t)H5O_iterate_cb, (void *)&wrapper, (unsigned)fields)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
 done:
@@ -496,13 +508,13 @@ done:
  * Signature: (JLjava/lang/String;IILjava/lang/Object;Ljava/lang/Object;IJ)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Ovisit_1by_1name
-    (JNIEnv *env, jclass clss, jlong grp_id, jstring name, jint idx_type, jint order,
-        jobject callback_op, jobject op_data, jint fields, jlong access_id)
+Java_hdf_hdf5lib_H5_H5Ovisit_1by_1name(JNIEnv *env, jclass clss, jlong grp_id, jstring name, jint idx_type,
+                                       jint order, jobject callback_op, jobject op_data, jint fields,
+                                       jlong access_id)
 {
-    cb_wrapper  wrapper = { callback_op, op_data };
+    cb_wrapper  wrapper = {callback_op, op_data};
     const char *objName = NULL;
-    herr_t      status = FAIL;
+    herr_t      status  = FAIL;
 
     UNUSED(clss);
 
@@ -518,7 +530,9 @@ Java_hdf_hdf5lib_H5_H5Ovisit_1by_1name
 
     PIN_JAVA_STRING(ENVONLY, name, objName, NULL, "H5Ovisit_by_name: object name not pinned");
 
-    if ((status = H5Ovisit_by_name2((hid_t)grp_id, objName, (H5_index_t)idx_type, (H5_iter_order_t)order, (H5O_iterate_t)H5O_iterate_cb, (void *)&wrapper, (unsigned)fields, (hid_t)access_id)) < 0)
+    if ((status = H5Ovisit_by_name2((hid_t)grp_id, objName, (H5_index_t)idx_type, (H5_iter_order_t)order,
+                                    (H5O_iterate_t)H5O_iterate_cb, (void *)&wrapper, (unsigned)fields,
+                                    (hid_t)access_id)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
 done:
@@ -534,11 +548,10 @@ done:
  * Signature: (JLjava/lang/String;)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Oset_1comment
-    (JNIEnv *env, jclass clss, jlong loc_id, jstring comment)
+Java_hdf_hdf5lib_H5_H5Oset_1comment(JNIEnv *env, jclass clss, jlong loc_id, jstring comment)
 {
     const char *oComment = NULL;
-    herr_t      status = FAIL;
+    herr_t      status   = FAIL;
 
     UNUSED(clss);
 
@@ -559,11 +572,10 @@ done:
  * Signature: (JLjava/lang/String;Ljava/lang/String;J)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Oset_1comment_1by_1name
-    (JNIEnv *env, jclass clss, jlong loc_id,
-        jstring name, jstring comment, jlong access_id)
+Java_hdf_hdf5lib_H5_H5Oset_1comment_1by_1name(JNIEnv *env, jclass clss, jlong loc_id, jstring name,
+                                              jstring comment, jlong access_id)
 {
-    const char *objName = NULL;
+    const char *objName    = NULL;
     const char *objComment = NULL;
     jboolean    isCopy;
     herr_t      status = FAIL;
@@ -576,7 +588,8 @@ Java_hdf_hdf5lib_H5_H5Oset_1comment_1by_1name
     PIN_JAVA_STRING(ENVONLY, name, objName, NULL, "H5Oset_comment_by_name: object name not pinned");
 
     if (NULL != comment)
-        PIN_JAVA_STRING(ENVONLY, comment, objComment, &isCopy, "H5Oset_comment_by_name: object comment not pinned");
+        PIN_JAVA_STRING(ENVONLY, comment, objComment, &isCopy,
+                        "H5Oset_comment_by_name: object comment not pinned");
 
     if ((status = H5Oset_comment_by_name((hid_t)loc_id, objName, objComment, (hid_t)access_id)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
@@ -594,13 +607,12 @@ done:
  * Signature: (J)Ljava/lang/String;
  */
 JNIEXPORT jstring JNICALL
-Java_hdf_hdf5lib_H5_H5Oget_1comment
-    (JNIEnv *env, jclass clss, jlong loc_id)
+Java_hdf_hdf5lib_H5_H5Oget_1comment(JNIEnv *env, jclass clss, jlong loc_id)
 {
-    jstring  str = NULL;
-    ssize_t  buf_size;
-    ssize_t  status = -1;
-    char    *oComment = NULL;
+    jstring str = NULL;
+    ssize_t buf_size;
+    ssize_t status   = -1;
+    char   *oComment = NULL;
 
     UNUSED(clss);
 
@@ -609,7 +621,7 @@ Java_hdf_hdf5lib_H5_H5Oget_1comment
         H5_LIBRARY_ERROR(ENVONLY);
 
     if (buf_size) {
-        if (NULL == (oComment = (char *) HDmalloc(sizeof(char) * (size_t)buf_size + 1)))
+        if (NULL == (oComment = (char *)HDmalloc(sizeof(char) * (size_t)buf_size + 1)))
             H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Oget_comment: failed to allocate object comment buffer");
 
         if ((status = H5Oget_comment((hid_t)loc_id, oComment, (size_t)buf_size + 1)) < 0)
@@ -633,11 +645,11 @@ done:
  * Signature: (JLjava/lang/String;J)Ljava/lang/String;
  */
 JNIEXPORT jstring JNICALL
-Java_hdf_hdf5lib_H5_H5Oget_1comment_1by_1name
-    (JNIEnv *env, jclass clss, jlong loc_id, jstring name, jlong access_id)
+Java_hdf_hdf5lib_H5_H5Oget_1comment_1by_1name(JNIEnv *env, jclass clss, jlong loc_id, jstring name,
+                                              jlong access_id)
 {
     const char *objName = NULL;
-    jstring     str = NULL;
+    jstring     str     = NULL;
     ssize_t     buf_size;
     ssize_t     status;
     char       *objComment = NULL;
@@ -654,10 +666,12 @@ Java_hdf_hdf5lib_H5_H5Oget_1comment_1by_1name
         H5_LIBRARY_ERROR(ENVONLY);
 
     if (buf_size) {
-        if (NULL == (objComment = (char *) HDmalloc(sizeof(char) * (size_t)buf_size + 1)))
-            H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Oget_comment_by_name: failed to allocate buffer for object comment");
+        if (NULL == (objComment = (char *)HDmalloc(sizeof(char) * (size_t)buf_size + 1)))
+            H5_OUT_OF_MEMORY_ERROR(ENVONLY,
+                                   "H5Oget_comment_by_name: failed to allocate buffer for object comment");
 
-        if ((status = H5Oget_comment_by_name((hid_t)loc_id, objName, objComment, (size_t)buf_size + 1, (hid_t)access_id)) < 0)
+        if ((status = H5Oget_comment_by_name((hid_t)loc_id, objName, objComment, (size_t)buf_size + 1,
+                                             (hid_t)access_id)) < 0)
             H5_LIBRARY_ERROR(ENVONLY);
         objComment[buf_size] = '\0';
 
@@ -680,11 +694,10 @@ done:
  * Signature: (JLjava/lang/String;J)Z
  */
 JNIEXPORT jboolean JNICALL
-Java_hdf_hdf5lib_H5_H5Oexists_1by_1name
-    (JNIEnv *env, jclass clss, jlong loc_id, jstring name, jlong access_id)
+Java_hdf_hdf5lib_H5_H5Oexists_1by_1name(JNIEnv *env, jclass clss, jlong loc_id, jstring name, jlong access_id)
 {
     const char *objName = NULL;
-    htri_t      bval = JNI_FALSE;
+    htri_t      bval    = JNI_FALSE;
 
     UNUSED(clss);
 
@@ -711,8 +724,7 @@ done:
  * Signature: (J)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Odecr_1refcount
-    (JNIEnv *env, jclass clss, jlong object_id)
+Java_hdf_hdf5lib_H5_H5Odecr_1refcount(JNIEnv *env, jclass clss, jlong object_id)
 {
     UNUSED(clss);
 
@@ -729,8 +741,7 @@ done:
  * Signature: (J)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Oincr_1refcount
-    (JNIEnv *env, jclass clss, jlong object_id)
+Java_hdf_hdf5lib_H5_H5Oincr_1refcount(JNIEnv *env, jclass clss, jlong object_id)
 {
     UNUSED(clss);
 
@@ -747,8 +758,7 @@ done:
  * Signature: (JJ)J;
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5__1H5Oopen_1by_1addr
-    (JNIEnv *env, jclass clss, jlong loc_id, jlong addr)
+Java_hdf_hdf5lib_H5__1H5Oopen_1by_1addr(JNIEnv *env, jclass clss, jlong loc_id, jlong addr)
 {
     hid_t retVal = H5I_INVALID_HID;
 
@@ -767,12 +777,11 @@ done:
  * Signature: (JLjava/lang/String;IIJJ)J;
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5__1H5Oopen_1by_1idx
-    (JNIEnv *env, jclass clss, jlong loc_id, jstring name,
-        jint index_field, jint order, jlong link_n, jlong lapl_id)
+Java_hdf_hdf5lib_H5__1H5Oopen_1by_1idx(JNIEnv *env, jclass clss, jlong loc_id, jstring name, jint index_field,
+                                       jint order, jlong link_n, jlong lapl_id)
 {
     const char *grpName = NULL;
-    hid_t       retVal = H5I_INVALID_HID;
+    hid_t       retVal  = H5I_INVALID_HID;
 
     UNUSED(clss);
 
@@ -781,7 +790,8 @@ Java_hdf_hdf5lib_H5__1H5Oopen_1by_1idx
 
     PIN_JAVA_STRING(ENVONLY, name, grpName, NULL, "H5Oopen_by_idx: object name not pinned");
 
-    if ((retVal = H5Oopen_by_idx((hid_t)loc_id, grpName, (H5_index_t)index_field, (H5_iter_order_t)order, (hsize_t)link_n, (hid_t)lapl_id)) < 0)
+    if ((retVal = H5Oopen_by_idx((hid_t)loc_id, grpName, (H5_index_t)index_field, (H5_iter_order_t)order,
+                                 (hsize_t)link_n, (hid_t)lapl_id)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
 done:
@@ -797,8 +807,7 @@ done:
  * Signature: (J)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Oflush
-    (JNIEnv *env, jclass clss, jlong loc_id)
+Java_hdf_hdf5lib_H5_H5Oflush(JNIEnv *env, jclass clss, jlong loc_id)
 {
     UNUSED(clss);
 
@@ -815,8 +824,7 @@ done:
  * Signature: (J)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Orefresh
-    (JNIEnv *env, jclass clss, jlong loc_id)
+Java_hdf_hdf5lib_H5_H5Orefresh(JNIEnv *env, jclass clss, jlong loc_id)
 {
     UNUSED(clss);
 
@@ -833,8 +841,7 @@ done:
  * Signature: (J)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Odisable_1mdc_1flushes
-    (JNIEnv *env, jclass clss, jlong loc_id)
+Java_hdf_hdf5lib_H5_H5Odisable_1mdc_1flushes(JNIEnv *env, jclass clss, jlong loc_id)
 {
     UNUSED(clss);
 
@@ -851,8 +858,7 @@ done:
  * Signature: (J)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Oenable_1mdc_1flushes
-    (JNIEnv *env, jclass clss, jlong loc_id)
+Java_hdf_hdf5lib_H5_H5Oenable_1mdc_1flushes(JNIEnv *env, jclass clss, jlong loc_id)
 {
     UNUSED(clss);
 
@@ -869,11 +875,10 @@ done:
  * Signature: (J)Z
  */
 JNIEXPORT jboolean JNICALL
-Java_hdf_hdf5lib_H5_H5Oare_1mdc_1flushes_1disabled
-    (JNIEnv *env, jclass clss, jlong loc_id)
+Java_hdf_hdf5lib_H5_H5Oare_1mdc_1flushes_1disabled(JNIEnv *env, jclass clss, jlong loc_id)
 {
-    jboolean bval = JNI_FALSE;
-    hbool_t    is_disabled = FALSE;
+    jboolean bval        = JNI_FALSE;
+    hbool_t  is_disabled = FALSE;
 
     UNUSED(clss);
 
@@ -881,14 +886,12 @@ Java_hdf_hdf5lib_H5_H5Oare_1mdc_1flushes_1disabled
         H5_LIBRARY_ERROR(ENVONLY);
 
     if (is_disabled == TRUE)
-        bval =  JNI_TRUE;
+        bval = JNI_TRUE;
 
 done:
     return bval;
 } /* end Java_hdf_hdf5lib_H5_H5Oare_1mdc_1flushes_1disabled */
 
-
-
 #ifdef __cplusplus
 } /* end extern "C" */
 #endif /* __cplusplus */
