@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -37,8 +36,7 @@ extern "C" {
  * Signature: (JJ)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Pset_1nlinks
-    (JNIEnv *env, jclass clss, jlong lapl_id, jlong nlinks)
+Java_hdf_hdf5lib_H5_H5Pset_1nlinks(JNIEnv *env, jclass clss, jlong lapl_id, jlong nlinks)
 {
     herr_t retVal = FAIL;
 
@@ -60,8 +58,7 @@ done:
  * Signature: (J)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5_H5Pget_1nlinks
-    (JNIEnv *env, jclass clss, jlong lapl_id)
+Java_hdf_hdf5lib_H5_H5Pget_1nlinks(JNIEnv *env, jclass clss, jlong lapl_id)
 {
     size_t nlinks = 0;
 
@@ -71,7 +68,7 @@ Java_hdf_hdf5lib_H5_H5Pget_1nlinks
         H5_LIBRARY_ERROR(ENVONLY);
 
 done:
-    return (jlong) nlinks;
+    return (jlong)nlinks;
 } /* end Java_hdf_hdf5lib_H5_H5Pget_1nlinks */
 
 /*
@@ -88,11 +85,10 @@ done:
  * Signature: (JLjava/lang/String;)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Pset_1elink_1prefix
-    (JNIEnv *env, jclass clss, jlong lapl_id, jstring prefix)
+Java_hdf_hdf5lib_H5_H5Pset_1elink_1prefix(JNIEnv *env, jclass clss, jlong lapl_id, jstring prefix)
 {
     const char *linkPrefix = NULL;
-    herr_t      retVal = FAIL;
+    herr_t      retVal     = FAIL;
 
     UNUSED(clss);
 
@@ -117,13 +113,12 @@ done:
  * Signature: (J[Ljava/lang/String;)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5_H5Pget_1elink_1prefix
-    (JNIEnv *env, jclass clss, jlong lapl_id, jobjectArray prefix)
+Java_hdf_hdf5lib_H5_H5Pget_1elink_1prefix(JNIEnv *env, jclass clss, jlong lapl_id, jobjectArray prefix)
 {
-    ssize_t  prefix_size = -1;
-    size_t   size = 0;
-    char    *pre = NULL;
-    jstring  str = NULL;
+    ssize_t prefix_size = -1;
+    size_t  size        = 0;
+    char   *pre         = NULL;
+    jstring str         = NULL;
 
     UNUSED(clss);
 
@@ -133,16 +128,17 @@ Java_hdf_hdf5lib_H5_H5Pget_1elink_1prefix
     if ((prefix_size = H5Pget_elink_prefix((hid_t)lapl_id, (char *)NULL, size)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
-    if (NULL == (pre = (char *) HDmalloc(sizeof(char) * (size_t) prefix_size + 1)))
+    if (NULL == (pre = (char *)HDmalloc(sizeof(char) * (size_t)prefix_size + 1)))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Pget_elink_prefix: memory allocation failed");
 
-    if (H5Pget_elink_prefix((hid_t)lapl_id, (char *)pre, (size_t) prefix_size + 1) < 0)
+    if (H5Pget_elink_prefix((hid_t)lapl_id, (char *)pre, (size_t)prefix_size + 1) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
     pre[prefix_size] = '\0';
 
     if (NULL == (str = ENVPTR->NewStringUTF(ENVONLY, pre))) {
         CHECK_JNI_EXCEPTION(ENVONLY, JNI_TRUE);
-        H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Pget_elink_prefix: out of memory - unable to construct string from UTF characters");
+        H5_OUT_OF_MEMORY_ERROR(
+            ENVONLY, "H5Pget_elink_prefix: out of memory - unable to construct string from UTF characters");
     }
 
     ENVPTR->SetObjectArrayElement(ENVONLY, prefix, 0, str);
@@ -161,8 +157,7 @@ done:
  * Signature: (JJ)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Pset_1elink_1fapl
-    (JNIEnv *env, jclass clss, jlong lapl_id, jlong fapl_id)
+Java_hdf_hdf5lib_H5_H5Pset_1elink_1fapl(JNIEnv *env, jclass clss, jlong lapl_id, jlong fapl_id)
 {
     herr_t retVal = FAIL;
 
@@ -181,8 +176,7 @@ done:
  * Signature: (J)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5__1H5Pget_1elink_1fapl
-    (JNIEnv *env, jclass clss, jlong lapl_id)
+Java_hdf_hdf5lib_H5__1H5Pget_1elink_1fapl(JNIEnv *env, jclass clss, jlong lapl_id)
 {
     hid_t retVal = H5I_INVALID_HID;
 
@@ -201,8 +195,7 @@ done:
  * Signature: (JI)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Pset_1elink_1acc_1flags
-    (JNIEnv *env, jclass clss, jlong lapl_id, jint flags)
+Java_hdf_hdf5lib_H5_H5Pset_1elink_1acc_1flags(JNIEnv *env, jclass clss, jlong lapl_id, jint flags)
 {
     herr_t retVal = FAIL;
 
@@ -212,7 +205,7 @@ Java_hdf_hdf5lib_H5_H5Pset_1elink_1acc_1flags
         H5_LIBRARY_ERROR(ENVONLY);
 
 done:
-    return (jint) retVal;
+    return (jint)retVal;
 } /* end Java_hdf_hdf5lib_H5_H5Pset_1elink_1acc_1flags */
 
 /*
@@ -221,8 +214,7 @@ done:
  * Signature: (J)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Pget_1elink_1acc_1flags
-    (JNIEnv *env, jclass clss, jlong lapl_id)
+Java_hdf_hdf5lib_H5_H5Pget_1elink_1acc_1flags(JNIEnv *env, jclass clss, jlong lapl_id)
 {
     unsigned flags;
 
