@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -23,55 +22,46 @@
 /****************/
 /* Module Setup */
 /****************/
-#include "H5Cmodule.h"         /* This source code file is part of the H5C module */
+#include "H5Cmodule.h" /* This source code file is part of the H5C module */
 
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"          /* Generic Functions                        */
+#include "H5private.h"  /* Generic Functions                        */
 #define H5AC_FRIEND     /* Suppress error about including H5ACpkg */
-#include "H5ACpkg.h"            /* Metadata cache                           */
-#include "H5Cpkg.h"             /* Cache                                    */
-#include "H5Clog.h"             /* Cache logging                            */
-#include "H5Eprivate.h"         /* Error handling                           */
-
+#include "H5ACpkg.h"    /* Metadata cache                           */
+#include "H5Cpkg.h"     /* Cache                                    */
+#include "H5Clog.h"     /* Cache logging                            */
+#include "H5Eprivate.h" /* Error handling                           */
 
 /****************/
 /* Local Macros */
 /****************/
 
-
 /******************/
 /* Local Typedefs */
 /******************/
 
-
 /********************/
 /* Package Typedefs */
 /********************/
 
-
 /********************/
 /* Local Prototypes */
 /********************/
 
-
 /*********************/
 /* Package Variables */
 /*********************/
 
-
 /*****************************/
 /* Library Private Variables */
 /*****************************/
 
-
 /*******************/
 /* Local Variables */
 /*******************/
 
-
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_set_up
  *
@@ -87,8 +77,8 @@
 herr_t
 H5C_log_set_up(H5C_t *cache, const char log_location[], H5C_log_style_t style, hbool_t start_immediately)
 {
-    int mpi_rank = -1;              /* -1 indicates serial (no MPI rank) */
-    herr_t ret_value = SUCCEED;     /* Return value */
+    int    mpi_rank  = -1;      /* -1 indicates serial (no MPI rank) */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -97,24 +87,24 @@ H5C_log_set_up(H5C_t *cache, const char log_location[], H5C_log_style_t style, h
     HDassert(log_location);
 
     /* Check logging flags */
-    if(cache->log_info->enabled)
+    if (cache->log_info->enabled)
         HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "logging already set up")
 
-    /* Get the rank when MPI is in use. Logging clients will usually
-     * use that to create per-process logs.
-     */
+        /* Get the rank when MPI is in use. Logging clients will usually
+         * use that to create per-process logs.
+         */
 #ifdef H5_HAVE_PARALLEL
-    if(NULL != cache->aux_ptr)
+    if (NULL != cache->aux_ptr)
         mpi_rank = ((H5AC_aux_t *)(cache->aux_ptr))->mpi_rank;
 #endif /*H5_HAVE_PARALLEL*/
 
     /* Set up logging */
-    if(H5C_LOG_STYLE_JSON == style) {
-        if(H5C_log_json_set_up(cache->log_info, log_location, mpi_rank) < 0)
+    if (H5C_LOG_STYLE_JSON == style) {
+        if (H5C_log_json_set_up(cache->log_info, log_location, mpi_rank) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to set up json logging")
     }
-    else if(H5C_LOG_STYLE_TRACE == style) {
-        if(H5C_log_trace_set_up(cache->log_info, log_location, mpi_rank) < 0)
+    else if (H5C_LOG_STYLE_TRACE == style) {
+        if (H5C_log_trace_set_up(cache->log_info, log_location, mpi_rank) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to set up trace logging")
     }
     else
@@ -124,16 +114,15 @@ H5C_log_set_up(H5C_t *cache, const char log_location[], H5C_log_style_t style, h
     cache->log_info->enabled = TRUE;
 
     /* Start logging if requested */
-    if(start_immediately)
-        if(H5C_start_logging(cache) < 0)
+    if (start_immediately)
+        if (H5C_start_logging(cache) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to start logging")
 
- done:
+done:
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_set_up() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_tear_down
  *
@@ -149,7 +138,7 @@ H5C_log_set_up(H5C_t *cache, const char log_location[], H5C_log_style_t style, h
 herr_t
 H5C_log_tear_down(H5C_t *cache)
 {
-    herr_t ret_value = SUCCEED;      /* Return value */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -157,27 +146,26 @@ H5C_log_tear_down(H5C_t *cache)
     HDassert(cache);
 
     /* Check logging flags */
-    if(FALSE == cache->log_info->enabled)
+    if (FALSE == cache->log_info->enabled)
         HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "logging not enabled")
 
     /* Stop logging if that's going on */
-    if(cache->log_info->logging)
-        if(H5C_stop_logging(cache) < 0)
+    if (cache->log_info->logging)
+        if (H5C_stop_logging(cache) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "unable to stop logging")
 
     /* Tear down logging */
-    if(cache->log_info->cls->tear_down_logging)
-        if(cache->log_info->cls->tear_down_logging(cache->log_info) < 0)
+    if (cache->log_info->cls->tear_down_logging)
+        if (cache->log_info->cls->tear_down_logging(cache->log_info) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific tear down call failed")
 
     /* Unset logging flags */
     cache->log_info->enabled = FALSE;
 
- done:
+done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_tear_down() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_start_logging
  *
@@ -193,7 +181,7 @@ H5C_log_tear_down(H5C_t *cache)
 herr_t
 H5C_start_logging(H5C_t *cache)
 {
-    herr_t ret_value = SUCCEED;      /* Return value */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -201,27 +189,26 @@ H5C_start_logging(H5C_t *cache)
     HDassert(cache);
 
     /* Check logging flags */
-    if(FALSE == cache->log_info->enabled)
+    if (FALSE == cache->log_info->enabled)
         HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "logging not enabled")
 
     /* Start logging */
-    if(cache->log_info->cls->start_logging)
-        if(cache->log_info->cls->start_logging(cache->log_info) < 0)
+    if (cache->log_info->cls->start_logging)
+        if (cache->log_info->cls->start_logging(cache->log_info) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific start call failed")
 
     /* Set logging flags */
     cache->log_info->logging = TRUE;
 
     /* Write a log message */
-    if(cache->log_info->cls->write_start_log_msg)
-        if(cache->log_info->cls->write_start_log_msg(cache->log_info->udata) < 0)
+    if (cache->log_info->cls->write_start_log_msg)
+        if (cache->log_info->cls->write_start_log_msg(cache->log_info->udata) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific write start call failed")
 
- done:
+done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_start_logging() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_stop_logging
  *
@@ -237,7 +224,7 @@ H5C_start_logging(H5C_t *cache)
 herr_t
 H5C_stop_logging(H5C_t *cache)
 {
-    herr_t ret_value = SUCCEED;      /* Return value */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -245,29 +232,28 @@ H5C_stop_logging(H5C_t *cache)
     HDassert(cache);
 
     /* Check logging flags */
-    if(FALSE == cache->log_info->enabled)
+    if (FALSE == cache->log_info->enabled)
         HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "logging not enabled")
-    if(FALSE == cache->log_info->logging)
+    if (FALSE == cache->log_info->logging)
         HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "logging not in progress")
 
     /* Write a log message */
-    if(cache->log_info->cls->write_stop_log_msg)
-        if(cache->log_info->cls->write_stop_log_msg(cache->log_info->udata) < 0)
+    if (cache->log_info->cls->write_stop_log_msg)
+        if (cache->log_info->cls->write_stop_log_msg(cache->log_info->udata) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific write stop call failed")
 
     /* Stop logging */
-    if(cache->log_info->cls->stop_logging)
-        if(cache->log_info->cls->stop_logging(cache->log_info) < 0)
+    if (cache->log_info->cls->stop_logging)
+        if (cache->log_info->cls->stop_logging(cache->log_info) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific stop call failed")
 
     /* Set logging flags */
     cache->log_info->logging = FALSE;
 
- done:
+done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_stop_logging() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_get_logging_status
  *
@@ -293,13 +279,12 @@ H5C_get_logging_status(const H5C_t *cache, /*OUT*/ hbool_t *is_enabled,
     HDassert(is_currently_logging);
 
     /* Get logging flags */
-    *is_enabled = cache->log_info->enabled;
+    *is_enabled           = cache->log_info->enabled;
     *is_currently_logging = cache->log_info->logging;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5C_get_logging_status() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_create_cache_msg
  *
@@ -315,7 +300,7 @@ H5C_get_logging_status(const H5C_t *cache, /*OUT*/ hbool_t *is_enabled,
 herr_t
 H5C_log_write_create_cache_msg(H5C_t *cache, herr_t fxn_ret_value)
 {
-    herr_t ret_value = SUCCEED;         /* Return value */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -323,8 +308,8 @@ H5C_log_write_create_cache_msg(H5C_t *cache, herr_t fxn_ret_value)
     HDassert(cache);
 
     /* Write a log message */
-    if(cache->log_info->cls->write_create_cache_log_msg)
-        if(cache->log_info->cls->write_create_cache_log_msg(cache->log_info->udata, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_create_cache_log_msg)
+        if (cache->log_info->cls->write_create_cache_log_msg(cache->log_info->udata, fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific write create cache call failed")
 
 done:
@@ -350,7 +335,7 @@ done:
 herr_t
 H5C_log_write_destroy_cache_msg(H5C_t *cache)
 {
-    herr_t ret_value = SUCCEED;         /* Return value */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -358,15 +343,14 @@ H5C_log_write_destroy_cache_msg(H5C_t *cache)
     HDassert(cache);
 
     /* Write a log message */
-    if(cache->log_info->cls->write_destroy_cache_log_msg)
-        if(cache->log_info->cls->write_destroy_cache_log_msg(cache->log_info->udata) < 0)
+    if (cache->log_info->cls->write_destroy_cache_log_msg)
+        if (cache->log_info->cls->write_destroy_cache_log_msg(cache->log_info->udata) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific write destroy cache call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_destroy_cache_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_evict_cache_msg
  *
@@ -390,15 +374,14 @@ H5C_log_write_evict_cache_msg(H5C_t *cache, herr_t fxn_ret_value)
     HDassert(cache);
 
     /* Write a log message */
-    if(cache->log_info->cls->write_evict_cache_log_msg)
-        if(cache->log_info->cls->write_evict_cache_log_msg(cache->log_info->udata, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_evict_cache_log_msg)
+        if (cache->log_info->cls->write_evict_cache_log_msg(cache->log_info->udata, fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific write evict cache call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_evict_cache_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_expunge_entry_msg
  *
@@ -412,8 +395,7 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_write_expunge_entry_msg(H5C_t *cache, haddr_t address,
-    int type_id, herr_t fxn_ret_value)
+H5C_log_write_expunge_entry_msg(H5C_t *cache, haddr_t address, int type_id, herr_t fxn_ret_value)
 {
     herr_t ret_value = SUCCEED;
 
@@ -423,15 +405,15 @@ H5C_log_write_expunge_entry_msg(H5C_t *cache, haddr_t address,
     HDassert(cache);
 
     /* Write a log message */
-    if(cache->log_info->cls->write_expunge_entry_log_msg)
-        if(cache->log_info->cls->write_expunge_entry_log_msg(cache->log_info->udata, address, type_id, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_expunge_entry_log_msg)
+        if (cache->log_info->cls->write_expunge_entry_log_msg(cache->log_info->udata, address, type_id,
+                                                              fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific write expunge entry call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_expunge_entry_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_flush_cache_msg
  *
@@ -455,15 +437,14 @@ H5C_log_write_flush_cache_msg(H5C_t *cache, herr_t fxn_ret_value)
     HDassert(cache);
 
     /* Write a log message */
-    if(cache->log_info->cls->write_flush_cache_log_msg)
-        if(cache->log_info->cls->write_flush_cache_log_msg(cache->log_info->udata, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_flush_cache_log_msg)
+        if (cache->log_info->cls->write_flush_cache_log_msg(cache->log_info->udata, fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific flush cache call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_flush_cache_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_insert_entry_msg
  *
@@ -477,8 +458,8 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_write_insert_entry_msg(H5C_t *cache, haddr_t address,
-    int type_id, unsigned flags, size_t size, herr_t fxn_ret_value)
+H5C_log_write_insert_entry_msg(H5C_t *cache, haddr_t address, int type_id, unsigned flags, size_t size,
+                               herr_t fxn_ret_value)
 {
     herr_t ret_value = SUCCEED;
 
@@ -488,15 +469,15 @@ H5C_log_write_insert_entry_msg(H5C_t *cache, haddr_t address,
     HDassert(cache);
 
     /* Write a log message */
-    if(cache->log_info->cls->write_insert_entry_log_msg)
-        if(cache->log_info->cls->write_insert_entry_log_msg(cache->log_info->udata, address, type_id, flags, size, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_insert_entry_log_msg)
+        if (cache->log_info->cls->write_insert_entry_log_msg(cache->log_info->udata, address, type_id, flags,
+                                                             size, fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific insert entry call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_insert_entry_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_mark_entry_dirty_msg
  *
@@ -510,8 +491,7 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_write_mark_entry_dirty_msg(H5C_t *cache, const H5C_cache_entry_t *entry,
-    herr_t fxn_ret_value)
+H5C_log_write_mark_entry_dirty_msg(H5C_t *cache, const H5C_cache_entry_t *entry, herr_t fxn_ret_value)
 {
     herr_t ret_value = SUCCEED;
 
@@ -522,15 +502,15 @@ H5C_log_write_mark_entry_dirty_msg(H5C_t *cache, const H5C_cache_entry_t *entry,
 
     /* Write a log message */
     HDassert(entry);
-    if(cache->log_info->cls->write_mark_entry_dirty_log_msg)
-        if(cache->log_info->cls->write_mark_entry_dirty_log_msg(cache->log_info->udata, entry, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_mark_entry_dirty_log_msg)
+        if (cache->log_info->cls->write_mark_entry_dirty_log_msg(cache->log_info->udata, entry,
+                                                                 fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific mark dirty entry call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_mark_entry_dirty_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_mark_entry_clean_msg
  *
@@ -544,10 +524,9 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_write_mark_entry_clean_msg(H5C_t *cache, const H5C_cache_entry_t *entry,
-    herr_t fxn_ret_value)
+H5C_log_write_mark_entry_clean_msg(H5C_t *cache, const H5C_cache_entry_t *entry, herr_t fxn_ret_value)
 {
-    herr_t ret_value = SUCCEED;         /* Return value */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -556,15 +535,15 @@ H5C_log_write_mark_entry_clean_msg(H5C_t *cache, const H5C_cache_entry_t *entry,
 
     /* Write a log message */
     HDassert(entry);
-    if(cache->log_info->cls->write_mark_entry_clean_log_msg)
-        if(cache->log_info->cls->write_mark_entry_clean_log_msg(cache->log_info->udata, entry, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_mark_entry_clean_log_msg)
+        if (cache->log_info->cls->write_mark_entry_clean_log_msg(cache->log_info->udata, entry,
+                                                                 fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific mark clean entry call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_mark_entry_clean_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_mark_unserialized_entry_msg
  *
@@ -578,8 +557,7 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_write_mark_unserialized_entry_msg(H5C_t *cache,
-    const H5C_cache_entry_t *entry, herr_t fxn_ret_value)
+H5C_log_write_mark_unserialized_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry, herr_t fxn_ret_value)
 {
     herr_t ret_value = SUCCEED;
 
@@ -590,15 +568,15 @@ H5C_log_write_mark_unserialized_entry_msg(H5C_t *cache,
 
     /* Write a log message */
     HDassert(entry);
-    if(cache->log_info->cls->write_mark_unserialized_entry_log_msg)
-        if(cache->log_info->cls->write_mark_unserialized_entry_log_msg(cache->log_info->udata, entry, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_mark_unserialized_entry_log_msg)
+        if (cache->log_info->cls->write_mark_unserialized_entry_log_msg(cache->log_info->udata, entry,
+                                                                        fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific mark unserialized entry call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_mark_unserialized_entry_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_mark_serialized_entry_msg
  *
@@ -612,10 +590,9 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_write_mark_serialized_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry,
-    herr_t fxn_ret_value)
+H5C_log_write_mark_serialized_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry, herr_t fxn_ret_value)
 {
-    herr_t ret_value = SUCCEED;         /* Return value */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -624,15 +601,15 @@ H5C_log_write_mark_serialized_entry_msg(H5C_t *cache, const H5C_cache_entry_t *e
 
     /* Write a log message */
     HDassert(entry);
-    if(cache->log_info->cls->write_mark_serialized_entry_log_msg)
-        if(cache->log_info->cls->write_mark_serialized_entry_log_msg(cache->log_info->udata, entry, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_mark_serialized_entry_log_msg)
+        if (cache->log_info->cls->write_mark_serialized_entry_log_msg(cache->log_info->udata, entry,
+                                                                      fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific mark serialized entry call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_mark_serialized_entry_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_move_entry_msg
  *
@@ -646,8 +623,8 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_write_move_entry_msg(H5C_t *cache, haddr_t old_addr, haddr_t new_addr,
-    int type_id, herr_t fxn_ret_value)
+H5C_log_write_move_entry_msg(H5C_t *cache, haddr_t old_addr, haddr_t new_addr, int type_id,
+                             herr_t fxn_ret_value)
 {
     herr_t ret_value = SUCCEED;
 
@@ -657,15 +634,15 @@ H5C_log_write_move_entry_msg(H5C_t *cache, haddr_t old_addr, haddr_t new_addr,
     HDassert(cache);
 
     /* Write a log message */
-    if(cache->log_info->cls->write_move_entry_log_msg)
-        if(cache->log_info->cls->write_move_entry_log_msg(cache->log_info->udata, old_addr, new_addr, type_id, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_move_entry_log_msg)
+        if (cache->log_info->cls->write_move_entry_log_msg(cache->log_info->udata, old_addr, new_addr,
+                                                           type_id, fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific move entry call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_move_entry_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_pin_entry_msg
  *
@@ -679,8 +656,7 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_write_pin_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry,
-    herr_t fxn_ret_value)
+H5C_log_write_pin_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry, herr_t fxn_ret_value)
 {
     herr_t ret_value = SUCCEED;
 
@@ -691,15 +667,14 @@ H5C_log_write_pin_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry,
 
     /* Write a log message */
     HDassert(entry);
-    if(cache->log_info->cls->write_pin_entry_log_msg)
-        if(cache->log_info->cls->write_pin_entry_log_msg(cache->log_info->udata, entry, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_pin_entry_log_msg)
+        if (cache->log_info->cls->write_pin_entry_log_msg(cache->log_info->udata, entry, fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific pin entry call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_pin_entry_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_create_fd_msg
  *
@@ -714,8 +689,8 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_write_create_fd_msg(H5C_t *cache, const H5C_cache_entry_t *parent,
-    const H5C_cache_entry_t *child, herr_t fxn_ret_value)
+H5C_log_write_create_fd_msg(H5C_t *cache, const H5C_cache_entry_t *parent, const H5C_cache_entry_t *child,
+                            herr_t fxn_ret_value)
 {
     herr_t ret_value = SUCCEED;
 
@@ -727,15 +702,15 @@ H5C_log_write_create_fd_msg(H5C_t *cache, const H5C_cache_entry_t *parent,
     /* Write a log message */
     HDassert(parent);
     HDassert(child);
-    if(cache->log_info->cls->write_create_fd_log_msg)
-        if(cache->log_info->cls->write_create_fd_log_msg(cache->log_info->udata, parent, child, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_create_fd_log_msg)
+        if (cache->log_info->cls->write_create_fd_log_msg(cache->log_info->udata, parent, child,
+                                                          fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific create fd call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_create_fd_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_protect_entry_msg
  *
@@ -749,8 +724,8 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_write_protect_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry,
-    int type_id, unsigned flags, herr_t fxn_ret_value)
+H5C_log_write_protect_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry, int type_id, unsigned flags,
+                                herr_t fxn_ret_value)
 {
     herr_t ret_value = SUCCEED;
 
@@ -761,15 +736,15 @@ H5C_log_write_protect_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry,
 
     /* Write a log message */
     HDassert(entry);
-    if(cache->log_info->cls->write_protect_entry_log_msg)
-        if(cache->log_info->cls->write_protect_entry_log_msg(cache->log_info->udata, entry, type_id, flags, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_protect_entry_log_msg)
+        if (cache->log_info->cls->write_protect_entry_log_msg(cache->log_info->udata, entry, type_id, flags,
+                                                              fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific protect entry call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_protect_entry_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_resize_entry_msg
  *
@@ -783,8 +758,8 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_write_resize_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry,
-    size_t new_size, herr_t fxn_ret_value)
+H5C_log_write_resize_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry, size_t new_size,
+                               herr_t fxn_ret_value)
 {
     herr_t ret_value = SUCCEED;
 
@@ -795,15 +770,15 @@ H5C_log_write_resize_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry,
 
     /* Write a log message */
     HDassert(entry);
-    if(cache->log_info->cls->write_resize_entry_log_msg)
-        if(cache->log_info->cls->write_resize_entry_log_msg(cache->log_info->udata, entry, new_size, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_resize_entry_log_msg)
+        if (cache->log_info->cls->write_resize_entry_log_msg(cache->log_info->udata, entry, new_size,
+                                                             fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific resize entry call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_resize_entry_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_unpin_entry_msg
  *
@@ -817,8 +792,7 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_write_unpin_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry,
-    herr_t fxn_ret_value)
+H5C_log_write_unpin_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry, herr_t fxn_ret_value)
 {
     herr_t ret_value = SUCCEED;
 
@@ -829,15 +803,14 @@ H5C_log_write_unpin_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry,
 
     /* Write a log message */
     HDassert(entry);
-    if(cache->log_info->cls->write_unpin_entry_log_msg)
-        if(cache->log_info->cls->write_unpin_entry_log_msg(cache->log_info->udata, entry, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_unpin_entry_log_msg)
+        if (cache->log_info->cls->write_unpin_entry_log_msg(cache->log_info->udata, entry, fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific unpin entry call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_unpin_entry_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_destroy_fd_msg
  *
@@ -852,8 +825,8 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_write_destroy_fd_msg(H5C_t *cache, const H5C_cache_entry_t *parent,
-    const H5C_cache_entry_t *child, herr_t fxn_ret_value)
+H5C_log_write_destroy_fd_msg(H5C_t *cache, const H5C_cache_entry_t *parent, const H5C_cache_entry_t *child,
+                             herr_t fxn_ret_value)
 {
     herr_t ret_value = SUCCEED;
 
@@ -865,15 +838,15 @@ H5C_log_write_destroy_fd_msg(H5C_t *cache, const H5C_cache_entry_t *parent,
     /* Write a log message */
     HDassert(parent);
     HDassert(child);
-    if(cache->log_info->cls->write_destroy_fd_log_msg)
-        if(cache->log_info->cls->write_destroy_fd_log_msg(cache->log_info->udata, parent, child, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_destroy_fd_log_msg)
+        if (cache->log_info->cls->write_destroy_fd_log_msg(cache->log_info->udata, parent, child,
+                                                           fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific destroy fd call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_destroy_fd_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_unprotect_entry_msg
  *
@@ -887,8 +860,8 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_write_unprotect_entry_msg(H5C_t *cache, haddr_t address,
-    int type_id, unsigned flags, herr_t fxn_ret_value)
+H5C_log_write_unprotect_entry_msg(H5C_t *cache, haddr_t address, int type_id, unsigned flags,
+                                  herr_t fxn_ret_value)
 {
     herr_t ret_value = SUCCEED;
 
@@ -898,15 +871,15 @@ H5C_log_write_unprotect_entry_msg(H5C_t *cache, haddr_t address,
     HDassert(cache);
 
     /* Write a log message */
-    if(cache->log_info->cls->write_unprotect_entry_log_msg)
-        if(cache->log_info->cls->write_unprotect_entry_log_msg(cache->log_info->udata, address, type_id, flags, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_unprotect_entry_log_msg)
+        if (cache->log_info->cls->write_unprotect_entry_log_msg(cache->log_info->udata, address, type_id,
+                                                                flags, fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific unprotect entry call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_unprotect_entry_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_set_cache_config_msg
  *
@@ -920,8 +893,7 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_write_set_cache_config_msg(H5C_t *cache, const H5AC_cache_config_t *config,
-    herr_t fxn_ret_value)
+H5C_log_write_set_cache_config_msg(H5C_t *cache, const H5AC_cache_config_t *config, herr_t fxn_ret_value)
 {
     herr_t ret_value = SUCCEED;
 
@@ -932,15 +904,15 @@ H5C_log_write_set_cache_config_msg(H5C_t *cache, const H5AC_cache_config_t *conf
 
     /* Write a log message */
     HDassert(config);
-    if(cache->log_info->cls->write_set_cache_config_log_msg)
-        if(cache->log_info->cls->write_set_cache_config_log_msg(cache->log_info->udata, config, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_set_cache_config_log_msg)
+        if (cache->log_info->cls->write_set_cache_config_log_msg(cache->log_info->udata, config,
+                                                                 fxn_ret_value) < 0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific set cache config call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_set_cache_config_msg() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5C_log_write_remove_entry_msg
  *
@@ -954,8 +926,7 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5C_log_write_remove_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry,
-    herr_t fxn_ret_value)
+H5C_log_write_remove_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry, herr_t fxn_ret_value)
 {
     herr_t ret_value = SUCCEED;
 
@@ -966,11 +937,11 @@ H5C_log_write_remove_entry_msg(H5C_t *cache, const H5C_cache_entry_t *entry,
 
     /* Write a log message */
     HDassert(entry);
-    if(cache->log_info->cls->write_remove_entry_log_msg)
-        if(cache->log_info->cls->write_remove_entry_log_msg(cache->log_info->udata, entry, fxn_ret_value) < 0)
+    if (cache->log_info->cls->write_remove_entry_log_msg)
+        if (cache->log_info->cls->write_remove_entry_log_msg(cache->log_info->udata, entry, fxn_ret_value) <
+            0)
             HGOTO_ERROR(H5E_CACHE, H5E_LOGGING, FAIL, "log-specific remove entry call failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5C_log_write_remove_entry_msg() */
-
