@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -26,24 +25,21 @@
 /* Module Declaration */
 /**********************/
 
-#include "H5EAmodule.h"         /* This source code file is part of the H5EA module */
-
+#include "H5EAmodule.h" /* This source code file is part of the H5EA module */
 
 /***********************/
 /* Other Packages Used */
 /***********************/
 
-
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"		/* Generic Functions			*/
-#include "H5Eprivate.h"		/* Error handling		  	*/
-#include "H5EApkg.h"		/* Extensible Arrays			*/
-#include "H5MFprivate.h"	/* File memory management		*/
-#include "H5MMprivate.h"	/* Memory management			*/
-#include "H5VMprivate.h"	/* Vectors and arrays 			*/
-
+#include "H5private.h"   /* Generic Functions			*/
+#include "H5Eprivate.h"  /* Error handling		  	*/
+#include "H5EApkg.h"     /* Extensible Arrays			*/
+#include "H5MFprivate.h" /* File memory management		*/
+#include "H5MMprivate.h" /* Memory management			*/
+#include "H5VMprivate.h" /* Vectors and arrays 			*/
 
 /****************/
 /* Local Macros */
@@ -55,9 +51,7 @@
 #endif /* NDEBUG */
 
 /* # of elements in a data block for a particular super block */
-#define H5EA_SBLK_DBLK_NELMTS(s, m)                                           \
-    (size_t)H5_EXP2(((s) + 1) / 2) * (m)
-
+#define H5EA_SBLK_DBLK_NELMTS(s, m) (size_t) H5_EXP2(((s) + 1) / 2) * (m)
 
 /******************/
 /* Local Typedefs */
@@ -66,27 +60,22 @@
 /* Alias for pointer to factory, for use when allocating sequences of them */
 typedef H5FL_fac_head_t *H5FL_fac_head_ptr_t;
 
-
 /********************/
 /* Package Typedefs */
 /********************/
 
-
 /********************/
 /* Local Prototypes */
 /********************/
 
-
 /*********************/
 /* Package Variables */
 /*********************/
 
-
 /*****************************/
 /* Library Private Variables */
 /*****************************/
 
-
 /*******************/
 /* Local Variables */
 /*******************/
@@ -100,8 +89,6 @@ H5FL_SEQ_DEFINE_STATIC(H5FL_fac_head_ptr_t);
 /* Declare a free list to manage the H5EA_sblk_info_t sequence information */
 H5FL_SEQ_DEFINE_STATIC(H5EA_sblk_info_t);
 
-
-
 /*-------------------------------------------------------------------------
  * Function:	H5EA__hdr_alloc
  *
@@ -114,40 +101,42 @@ H5FL_SEQ_DEFINE_STATIC(H5EA_sblk_info_t);
  *
  *-------------------------------------------------------------------------
  */
-BEGIN_FUNC(PKG, ERR,
-H5EA_hdr_t *, NULL, NULL,
-H5EA__hdr_alloc(H5F_t *f))
+H5EA_hdr_t *
+H5EA__hdr_alloc(H5F_t *f)
+{
+    H5EA_hdr_t *hdr       = NULL; /* Shared extensible array header */
+    H5EA_hdr_t *ret_value = NULL;
 
-    /* Local variables */
-    H5EA_hdr_t *hdr = NULL;          /* Shared extensible array header */
+    FUNC_ENTER_PACKAGE
 
     /* Check arguments */
     HDassert(f);
 
     /* Allocate space for the shared information */
-    if(NULL == (hdr = H5FL_CALLOC(H5EA_hdr_t)))
-        H5E_THROW(H5E_CANTALLOC, "memory allocation failed for extensible array shared header")
+    if (NULL == (hdr = H5FL_CALLOC(H5EA_hdr_t)))
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTALLOC, NULL,
+                    "memory allocation failed for extensible array shared header")
 
     /* Set non-zero internal fields */
     hdr->addr = HADDR_UNDEF;
 
     /* Set the internal parameters for the array */
-    hdr->f = f;
-    hdr->swmr_write = (H5F_INTENT(f) & H5F_ACC_SWMR_WRITE) > 0;
+    hdr->f           = f;
+    hdr->swmr_write  = (H5F_INTENT(f) & H5F_ACC_SWMR_WRITE) > 0;
     hdr->sizeof_addr = H5F_SIZEOF_ADDR(f);
     hdr->sizeof_size = H5F_SIZEOF_SIZE(f);
 
     /* Set the return value */
     ret_value = hdr;
 
-CATCH
-    if(!ret_value)
-        if(hdr && H5EA__hdr_dest(hdr) < 0)
-            H5E_THROW(H5E_CANTFREE, "unable to destroy extensible array header")
+done:
+    if (!ret_value)
+        if (hdr && H5EA__hdr_dest(hdr) < 0)
+            HDONE_ERROR(H5E_EARRAY, H5E_CANTFREE, NULL, "unable to destroy extensible array header")
 
-END_FUNC(PKG)   /* end H5EA__hdr_alloc() */
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5EA__hdr_alloc() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5EA__hdr_init
  *
@@ -183,14 +172,15 @@ END_FUNC(PKG)   /* end H5EA__hdr_alloc() */
  *
  *-------------------------------------------------------------------------
  */
-BEGIN_FUNC(PKG, ERR,
-herr_t, SUCCEED, FAIL,
-H5EA__hdr_init(H5EA_hdr_t *hdr, void *ctx_udata))
+herr_t
+H5EA__hdr_init(H5EA_hdr_t *hdr, void *ctx_udata)
+{
+    hsize_t start_idx;  /* First element index for each super block */
+    hsize_t start_dblk; /* First data block index for each super block */
+    size_t  u;          /* Local index variable */
+    herr_t  ret_value = SUCCEED;
 
-    /* Local variables */
-    hsize_t start_idx;          /* First element index for each super block */
-    hsize_t start_dblk;         /* First data block index for each super block */
-    size_t u;                   /* Local index variable */
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(hdr);
@@ -199,42 +189,42 @@ H5EA__hdr_init(H5EA_hdr_t *hdr, void *ctx_udata))
     HDassert(hdr->cparam.sup_blk_min_data_ptrs);
 
     /* Compute general information */
-    hdr->nsblks = 1 + (hdr->cparam.max_nelmts_bits - H5VM_log2_of2(hdr->cparam.data_blk_min_elmts));
+    hdr->nsblks           = 1 + (hdr->cparam.max_nelmts_bits - H5VM_log2_of2(hdr->cparam.data_blk_min_elmts));
     hdr->dblk_page_nelmts = (size_t)1 << hdr->cparam.max_dblk_page_nelmts_bits;
-    hdr->arr_off_size = (unsigned char)H5EA_SIZEOF_OFFSET_BITS(hdr->cparam.max_nelmts_bits);
+    hdr->arr_off_size     = (unsigned char)H5EA_SIZEOF_OFFSET_BITS(hdr->cparam.max_nelmts_bits);
 
     /* Allocate information for each super block */
-    if(NULL == (hdr->sblk_info = H5FL_SEQ_MALLOC(H5EA_sblk_info_t, hdr->nsblks)))
-        H5E_THROW(H5E_CANTALLOC, "memory allocation failed for super block info array")
+    if (NULL == (hdr->sblk_info = H5FL_SEQ_MALLOC(H5EA_sblk_info_t, hdr->nsblks)))
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTALLOC, FAIL, "memory allocation failed for super block info array")
 
     /* Compute information about each super block */
-    start_idx = 0;
+    start_idx  = 0;
     start_dblk = 0;
-    for(u = 0; u < hdr->nsblks; u++) {
-        hdr->sblk_info[u].ndblks = (size_t)H5_EXP2(u / 2);
+    for (u = 0; u < hdr->nsblks; u++) {
+        hdr->sblk_info[u].ndblks      = (size_t)H5_EXP2(u / 2);
         hdr->sblk_info[u].dblk_nelmts = H5EA_SBLK_DBLK_NELMTS(u, hdr->cparam.data_blk_min_elmts);
-        hdr->sblk_info[u].start_idx = start_idx;
-        hdr->sblk_info[u].start_dblk = start_dblk;
+        hdr->sblk_info[u].start_idx   = start_idx;
+        hdr->sblk_info[u].start_dblk  = start_dblk;
 
         /* Advance starting indices for next super block */
         start_idx += (hsize_t)hdr->sblk_info[u].ndblks * (hsize_t)hdr->sblk_info[u].dblk_nelmts;
         start_dblk += (hsize_t)hdr->sblk_info[u].ndblks;
-    } /* end for */
+    }
 
     /* Set size of header on disk (locally and in statistics) */
     hdr->stats.computed.hdr_size = hdr->size = H5EA_HEADER_SIZE_HDR(hdr);
 
     /* Create the callback context, if there's one */
-    if(hdr->cparam.cls->crt_context) {
-        if(NULL == (hdr->cb_ctx = (*hdr->cparam.cls->crt_context)(ctx_udata)))
-            H5E_THROW(H5E_CANTCREATE, "unable to create extensible array client callback context")
-    } /* end if */
+    if (hdr->cparam.cls->crt_context) {
+        if (NULL == (hdr->cb_ctx = (*hdr->cparam.cls->crt_context)(ctx_udata)))
+            HGOTO_ERROR(H5E_EARRAY, H5E_CANTCREATE, FAIL,
+                        "unable to create extensible array client callback context")
+    }
 
-CATCH
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5EA__hdr_init() */
 
-END_FUNC(PKG)   /* end H5EA__hdr_init() */
-
-
 /*-------------------------------------------------------------------------
  * Function:	H5EA__hdr_alloc_elmts
  *
@@ -247,60 +237,65 @@ END_FUNC(PKG)   /* end H5EA__hdr_init() */
  *
  *-------------------------------------------------------------------------
  */
-BEGIN_FUNC(PKG, ERR,
-void *, NULL, NULL,
-H5EA__hdr_alloc_elmts(H5EA_hdr_t *hdr, size_t nelmts))
+void *
+H5EA__hdr_alloc_elmts(H5EA_hdr_t *hdr, size_t nelmts)
+{
+    void    *elmts = NULL; /* Element buffer allocated */
+    unsigned idx;          /* Index of element buffer factory in header */
+    void    *ret_value = NULL;
 
-    /* Local variables */
-    void *elmts = NULL;         /* Element buffer allocated */
-    unsigned idx;               /* Index of element buffer factory in header */
+    FUNC_ENTER_PACKAGE
 
     /* Check arguments */
     HDassert(hdr);
     HDassert(nelmts > 0);
 
     /* Compute the index of the element buffer factory */
-    H5_CHECK_OVERFLOW(nelmts, /*From:*/size_t, /*To:*/uint32_t);
+    H5_CHECK_OVERFLOW(nelmts, /*From:*/ size_t, /*To:*/ uint32_t);
     idx = H5VM_log2_of2((uint32_t)nelmts) - H5VM_log2_of2((uint32_t)hdr->cparam.data_blk_min_elmts);
 
     /* Check for needing to increase size of array of factories */
-    if(idx >= hdr->elmt_fac.nalloc) {
-        H5FL_fac_head_t **new_fac;      /* New array of element factories */
-        size_t new_nalloc = MAX3(1, (idx + 1), (2 * hdr->elmt_fac.nalloc));   /* New number of factories allocated */
+    if (idx >= hdr->elmt_fac.nalloc) {
+        H5FL_fac_head_t **new_fac; /* New array of element factories */
+        size_t            new_nalloc =
+            MAX3(1, (idx + 1), (2 * hdr->elmt_fac.nalloc)); /* New number of factories allocated */
 
         /* Re-allocate array of element factories */
-        if(NULL == (new_fac = H5FL_SEQ_REALLOC(H5FL_fac_head_ptr_t, hdr->elmt_fac.fac, new_nalloc)))
-            H5E_THROW(H5E_CANTALLOC, "memory allocation failed for data block data element buffer factory array")
+        if (NULL == (new_fac = H5FL_SEQ_REALLOC(H5FL_fac_head_ptr_t, hdr->elmt_fac.fac, new_nalloc)))
+            HGOTO_ERROR(H5E_EARRAY, H5E_CANTALLOC, NULL,
+                        "memory allocation failed for data block data element buffer factory array")
 
         /* Zero out new elements allocated */
-        HDmemset(new_fac + hdr->elmt_fac.nalloc, 0, (new_nalloc - hdr->elmt_fac.nalloc) * sizeof(H5FL_fac_head_ptr_t));
+        HDmemset(new_fac + hdr->elmt_fac.nalloc, 0,
+                 (new_nalloc - hdr->elmt_fac.nalloc) * sizeof(H5FL_fac_head_ptr_t));
 
         /* Update information about element factories in header */
         hdr->elmt_fac.nalloc = new_nalloc;
-        hdr->elmt_fac.fac = new_fac;
+        hdr->elmt_fac.fac    = new_fac;
     } /* end if */
 
     /* Check for un-initialized factory at index */
-    if(NULL == hdr->elmt_fac.fac[idx]) {
-        if(NULL == (hdr->elmt_fac.fac[idx] = H5FL_fac_init(nelmts * (size_t)hdr->cparam.cls->nat_elmt_size)))
-            H5E_THROW(H5E_CANTINIT, "can't create data block data element buffer factory")
+    if (NULL == hdr->elmt_fac.fac[idx]) {
+        if (NULL == (hdr->elmt_fac.fac[idx] = H5FL_fac_init(nelmts * (size_t)hdr->cparam.cls->nat_elmt_size)))
+            HGOTO_ERROR(H5E_EARRAY, H5E_CANTINIT, NULL, "can't create data block data element buffer factory")
     } /* end if */
 
     /* Allocate buffer for elements in index block */
-    if(NULL == (elmts = H5FL_FAC_MALLOC(hdr->elmt_fac.fac[idx])))
-        H5E_THROW(H5E_CANTALLOC, "memory allocation failed for data block data element buffer")
+    if (NULL == (elmts = H5FL_FAC_MALLOC(hdr->elmt_fac.fac[idx])))
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTALLOC, NULL,
+                    "memory allocation failed for data block data element buffer")
 
     /* Set the return value */
     ret_value = elmts;
 
-CATCH
-    if(!ret_value)
-        if(elmts)
+done:
+    if (!ret_value)
+        if (elmts)
             elmts = H5FL_FAC_FREE(hdr->elmt_fac.fac[idx], elmts);
 
-END_FUNC(PKG)   /* end H5EA__hdr_alloc_elmts() */
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5EA__hdr_alloc_elmts() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5EA__hdr_free_elmts
  *
@@ -313,12 +308,12 @@ END_FUNC(PKG)   /* end H5EA__hdr_alloc_elmts() */
  *
  *-------------------------------------------------------------------------
  */
-BEGIN_FUNC(PKG, NOERR,
-herr_t, SUCCEED, -,
-H5EA__hdr_free_elmts(H5EA_hdr_t *hdr, size_t nelmts, void *elmts))
+herr_t
+H5EA__hdr_free_elmts(H5EA_hdr_t *hdr, size_t nelmts, void *elmts)
+{
+    unsigned idx; /* Index of element buffer factory in header */
 
-    /* Local variables */
-    unsigned idx;               /* Index of element buffer factory in header */
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Check arguments */
     HDassert(hdr);
@@ -326,7 +321,7 @@ H5EA__hdr_free_elmts(H5EA_hdr_t *hdr, size_t nelmts, void *elmts))
     HDassert(elmts);
 
     /* Compute the index of the element buffer factory */
-    H5_CHECK_OVERFLOW(nelmts, /*From:*/size_t, /*To:*/uint32_t);
+    H5_CHECK_OVERFLOW(nelmts, /*From:*/ size_t, /*To:*/ uint32_t);
     idx = H5VM_log2_of2((uint32_t)nelmts) - H5VM_log2_of2((uint32_t)hdr->cparam.data_blk_min_elmts);
 
     /* Free buffer for elements in index block */
@@ -334,70 +329,82 @@ H5EA__hdr_free_elmts(H5EA_hdr_t *hdr, size_t nelmts, void *elmts))
     HDassert(hdr->elmt_fac.fac[idx]);
     elmts = H5FL_FAC_FREE(hdr->elmt_fac.fac[idx], elmts);
 
-END_FUNC(PKG)   /* end H5EA__hdr_free_elmts() */
+    FUNC_LEAVE_NOAPI(SUCCEED)
+} /* end H5EA__hdr_free_elmts() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5EA__hdr_create
  *
  * Purpose:	Creates a new extensible array header in the file
  *
- * Return:	SUCCEED/FAIL
+ * Return:      Success:    Address of new header in the file
+ *              Failure:    HADDR_UNDEF
  *
  * Programmer:	Quincey Koziol
  *		Jun 17 2008
  *
  *-------------------------------------------------------------------------
  */
-BEGIN_FUNC(PKG, ERR,
-haddr_t, HADDR_UNDEF, HADDR_UNDEF,
-H5EA__hdr_create(H5F_t *f, const H5EA_create_t *cparam, void *ctx_udata))
+haddr_t
+H5EA__hdr_create(H5F_t *f, const H5EA_create_t *cparam, void *ctx_udata)
+{
+    H5EA_hdr_t *hdr       = NULL;  /* Extensible array header */
+    hbool_t     inserted  = FALSE; /* Whether the header was inserted into cache */
+    haddr_t     ret_value = HADDR_UNDEF;
 
-    /* Local variables */
-    H5EA_hdr_t *hdr = NULL;     /* Extensible array header */
-    hbool_t inserted = FALSE;   /* Whether the header was inserted into cache */
+    FUNC_ENTER_PACKAGE
 
     /* Check arguments */
     HDassert(f);
     HDassert(cparam);
 
 #ifndef NDEBUG
-{
-    unsigned sblk_idx;          /* Super block index for first "actual" super block */
-    size_t dblk_nelmts;         /* Number of data block elements */
-    size_t dblk_page_nelmts;    /* Number of elements in a data block page */
+    {
+        unsigned sblk_idx;         /* Super block index for first "actual" super block */
+        size_t   dblk_nelmts;      /* Number of data block elements */
+        size_t   dblk_page_nelmts; /* Number of elements in a data block page */
 
-    /* Check for valid parameters */
-    if(cparam->raw_elmt_size == 0)
-        H5E_THROW(H5E_BADVALUE, "element size must be greater than zero")
-    if(cparam->max_nelmts_bits == 0)
-        H5E_THROW(H5E_BADVALUE, "max. # of elements bits must be greater than zero")
-    if(cparam->max_nelmts_bits > H5EA_MAX_NELMTS_IDX_MAX)
-        H5E_THROW(H5E_BADVALUE, "max. # of elements bits must be <= %u", (unsigned)H5EA_MAX_NELMTS_IDX_MAX)
-    if(cparam->sup_blk_min_data_ptrs < 2)
-        H5E_THROW(H5E_BADVALUE, "min # of data block pointers in super block must be >= two")
-    if(!POWER_OF_TWO(cparam->sup_blk_min_data_ptrs))
-        H5E_THROW(H5E_BADVALUE, "min # of data block pointers in super block must be power of two")
-    if(!POWER_OF_TWO(cparam->data_blk_min_elmts))
-        H5E_THROW(H5E_BADVALUE, "min # of elements per data block must be power of two")
-    dblk_page_nelmts = (size_t)1 << cparam->max_dblk_page_nelmts_bits;
-    if(dblk_page_nelmts < cparam->idx_blk_elmts)
-        H5E_THROW(H5E_BADVALUE, "# of elements per data block page must be greater than # of elements in index block")
+        /* Check for valid parameters */
+        if (cparam->raw_elmt_size == 0)
+            HGOTO_ERROR(H5E_EARRAY, H5E_BADVALUE, HADDR_UNDEF, "element size must be greater than zero")
+        if (cparam->max_nelmts_bits == 0)
+            HGOTO_ERROR(H5E_EARRAY, H5E_BADVALUE, HADDR_UNDEF,
+                        "max. # of elements bits must be greater than zero")
+        if (cparam->max_nelmts_bits > H5EA_MAX_NELMTS_IDX_MAX)
+            HGOTO_ERROR(H5E_EARRAY, H5E_BADVALUE, HADDR_UNDEF, "max. # of elements bits must be <= %u",
+                        (unsigned)H5EA_MAX_NELMTS_IDX_MAX)
+        if (cparam->sup_blk_min_data_ptrs < 2)
+            HGOTO_ERROR(H5E_EARRAY, H5E_BADVALUE, HADDR_UNDEF,
+                        "min # of data block pointers in super block must be >= two")
+        if (!POWER_OF_TWO(cparam->sup_blk_min_data_ptrs))
+            HGOTO_ERROR(H5E_EARRAY, H5E_BADVALUE, HADDR_UNDEF,
+                        "min # of data block pointers in super block must be power of two")
+        if (!POWER_OF_TWO(cparam->data_blk_min_elmts))
+            HGOTO_ERROR(H5E_EARRAY, H5E_BADVALUE, HADDR_UNDEF,
+                        "min # of elements per data block must be power of two")
+        dblk_page_nelmts = (size_t)1 << cparam->max_dblk_page_nelmts_bits;
+        if (dblk_page_nelmts < cparam->idx_blk_elmts)
+            HGOTO_ERROR(H5E_EARRAY, H5E_BADVALUE, HADDR_UNDEF,
+                        "# of elements per data block page must be greater than # of elements in index block")
 
-    /* Compute the number of elements in data blocks for first actual super block */
-    sblk_idx = H5EA_SBLK_FIRST_IDX(cparam->sup_blk_min_data_ptrs);
-    dblk_nelmts = H5EA_SBLK_DBLK_NELMTS(sblk_idx, cparam->data_blk_min_elmts);
-    if(dblk_page_nelmts < dblk_nelmts)
-        H5E_THROW(H5E_BADVALUE, "max. # of elements per data block page bits must be > # of elements in first data block from super block")
+        /* Compute the number of elements in data blocks for first actual super block */
+        sblk_idx    = H5EA_SBLK_FIRST_IDX(cparam->sup_blk_min_data_ptrs);
+        dblk_nelmts = H5EA_SBLK_DBLK_NELMTS(sblk_idx, cparam->data_blk_min_elmts);
+        if (dblk_page_nelmts < dblk_nelmts)
+            HGOTO_ERROR(H5E_EARRAY, H5E_BADVALUE, HADDR_UNDEF,
+                        "max. # of elements per data block page bits must be > # of elements in "
+                        "first data block from super block")
 
-    if(cparam->max_dblk_page_nelmts_bits > cparam->max_nelmts_bits)
-        H5E_THROW(H5E_BADVALUE, "max. # of elements per data block page bits must be <= max. # of elements bits")
-}
+        if (cparam->max_dblk_page_nelmts_bits > cparam->max_nelmts_bits)
+            HGOTO_ERROR(H5E_EARRAY, H5E_BADVALUE, HADDR_UNDEF,
+                        "max. # of elements per data block page bits must be <= max. # of elements bits")
+    }
 #endif /* NDEBUG */
 
     /* Allocate space for the shared information */
-    if(NULL == (hdr = H5EA__hdr_alloc(f)))
-        H5E_THROW(H5E_CANTALLOC, "memory allocation failed for extensible array shared header")
+    if (NULL == (hdr = H5EA__hdr_alloc(f)))
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTALLOC, HADDR_UNDEF,
+                    "memory allocation failed for extensible array shared header")
 
     /* Set the internal parameters for the array */
     hdr->idx_blk_addr = HADDR_UNDEF;
@@ -406,51 +413,57 @@ H5EA__hdr_create(H5F_t *f, const H5EA_create_t *cparam, void *ctx_udata))
     H5MM_memcpy(&hdr->cparam, cparam, sizeof(hdr->cparam));
 
     /* Finish initializing extensible array header */
-    if(H5EA__hdr_init(hdr, ctx_udata) < 0)
-        H5E_THROW(H5E_CANTINIT, "initialization failed for extensible array header")
+    if (H5EA__hdr_init(hdr, ctx_udata) < 0)
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTINIT, HADDR_UNDEF,
+                    "initialization failed for extensible array header")
 
     /* Allocate space for the header on disk */
-    if(HADDR_UNDEF == (hdr->addr = H5MF_alloc(f, H5FD_MEM_EARRAY_HDR, (hsize_t)hdr->size)))
-        H5E_THROW(H5E_CANTALLOC, "file allocation failed for extensible array header")
+    if (HADDR_UNDEF == (hdr->addr = H5MF_alloc(f, H5FD_MEM_EARRAY_HDR, (hsize_t)hdr->size)))
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTALLOC, HADDR_UNDEF,
+                    "file allocation failed for extensible array header")
 
     /* Create 'top' proxy for extensible array entries */
-    if(hdr->swmr_write)
-        if(NULL == (hdr->top_proxy = H5AC_proxy_entry_create()))
-            H5E_THROW(H5E_CANTCREATE, "can't create extensible array entry proxy")
+    if (hdr->swmr_write)
+        if (NULL == (hdr->top_proxy = H5AC_proxy_entry_create()))
+            HGOTO_ERROR(H5E_EARRAY, H5E_CANTCREATE, HADDR_UNDEF, "can't create extensible array entry proxy")
 
     /* Cache the new extensible array header */
-    if(H5AC_insert_entry(f, H5AC_EARRAY_HDR, hdr->addr, hdr, H5AC__NO_FLAGS_SET) < 0)
-        H5E_THROW(H5E_CANTINSERT, "can't add extensible array header to cache")
+    if (H5AC_insert_entry(f, H5AC_EARRAY_HDR, hdr->addr, hdr, H5AC__NO_FLAGS_SET) < 0)
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTINSERT, HADDR_UNDEF, "can't add extensible array header to cache")
     inserted = TRUE;
 
     /* Add header as child of 'top' proxy */
-    if(hdr->top_proxy)
-        if(H5AC_proxy_entry_add_child(hdr->top_proxy, f, hdr) < 0)
-            H5E_THROW(H5E_CANTSET, "unable to add extensible array entry as child of array proxy")
+    if (hdr->top_proxy)
+        if (H5AC_proxy_entry_add_child(hdr->top_proxy, f, hdr) < 0)
+            HGOTO_ERROR(H5E_EARRAY, H5E_CANTSET, HADDR_UNDEF,
+                        "unable to add extensible array entry as child of array proxy")
 
     /* Set address of array header to return */
     ret_value = hdr->addr;
 
-CATCH
-    if(!H5F_addr_defined(ret_value))
-        if(hdr) {
+done:
+    if (!H5F_addr_defined(ret_value))
+        if (hdr) {
             /* Remove from cache, if inserted */
-            if(inserted)
-                if(H5AC_remove_entry(hdr) < 0)
-                    H5E_THROW(H5E_CANTREMOVE, "unable to remove extensible array header from cache")
+            if (inserted)
+                if (H5AC_remove_entry(hdr) < 0)
+                    HDONE_ERROR(H5E_EARRAY, H5E_CANTREMOVE, HADDR_UNDEF,
+                                "unable to remove extensible array header from cache")
 
             /* Release header's disk space */
-            if(H5F_addr_defined(hdr->addr) && H5MF_xfree(f, H5FD_MEM_EARRAY_HDR, hdr->addr, (hsize_t)hdr->size) < 0)
-                H5E_THROW(H5E_CANTFREE, "unable to free extensible array header")
+            if (H5F_addr_defined(hdr->addr) &&
+                H5MF_xfree(f, H5FD_MEM_EARRAY_HDR, hdr->addr, (hsize_t)hdr->size) < 0)
+                HDONE_ERROR(H5E_EARRAY, H5E_CANTFREE, HADDR_UNDEF, "unable to free extensible array header")
 
             /* Destroy header */
-            if(H5EA__hdr_dest(hdr) < 0)
-                H5E_THROW(H5E_CANTFREE, "unable to destroy extensible array header")
+            if (H5EA__hdr_dest(hdr) < 0)
+                HDONE_ERROR(H5E_EARRAY, H5E_CANTFREE, HADDR_UNDEF,
+                            "unable to destroy extensible array header")
         } /* end if */
 
-END_FUNC(PKG)   /* end H5EA__hdr_create() */
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5EA__hdr_create() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5EA__hdr_incr
  *
@@ -463,26 +476,28 @@ END_FUNC(PKG)   /* end H5EA__hdr_create() */
  *
  *-------------------------------------------------------------------------
  */
-BEGIN_FUNC(PKG, ERR,
-herr_t, SUCCEED, FAIL,
-H5EA__hdr_incr(H5EA_hdr_t *hdr))
+herr_t
+H5EA__hdr_incr(H5EA_hdr_t *hdr)
+{
+    herr_t ret_value = SUCCEED;
+
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(hdr);
 
     /* Mark header as un-evictable when something is depending on it */
-    if(hdr->rc == 0)
-        if(H5AC_pin_protected_entry(hdr) < 0)
-            H5E_THROW(H5E_CANTPIN, "unable to pin extensible array header")
+    if (hdr->rc == 0)
+        if (H5AC_pin_protected_entry(hdr) < 0)
+            HGOTO_ERROR(H5E_EARRAY, H5E_CANTPIN, FAIL, "unable to pin extensible array header")
 
     /* Increment reference count on shared header */
     hdr->rc++;
 
-CATCH
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5EA__hdr_incr() */
 
-END_FUNC(PKG)   /* end H5EA__hdr_incr() */
-
-
 /*-------------------------------------------------------------------------
  * Function:	H5EA__hdr_decr
  *
@@ -495,9 +510,12 @@ END_FUNC(PKG)   /* end H5EA__hdr_incr() */
  *
  *-------------------------------------------------------------------------
  */
-BEGIN_FUNC(PKG, ERR,
-herr_t, SUCCEED, FAIL,
-H5EA__hdr_decr(H5EA_hdr_t *hdr))
+herr_t
+H5EA__hdr_decr(H5EA_hdr_t *hdr)
+{
+    herr_t ret_value = SUCCEED;
+
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(hdr);
@@ -507,17 +525,16 @@ H5EA__hdr_decr(H5EA_hdr_t *hdr))
     hdr->rc--;
 
     /* Mark header as evictable again when nothing depend on it */
-    if(hdr->rc == 0) {
+    if (hdr->rc == 0) {
         HDassert(hdr->file_rc == 0);
-        if(H5AC_unpin_entry(hdr) < 0)
-            H5E_THROW(H5E_CANTUNPIN, "unable to unpin extensible array header")
-    } /* end if */
+        if (H5AC_unpin_entry(hdr) < 0)
+            HGOTO_ERROR(H5E_EARRAY, H5E_CANTUNPIN, FAIL, "unable to unpin extensible array header")
+    }
 
-CATCH
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5EA__hdr_decr() */
 
-END_FUNC(PKG)   /* end H5EA__hdr_decr() */
-
-
 /*-------------------------------------------------------------------------
  * Function:	H5EA__hdr_fuse_incr
  *
@@ -530,9 +547,10 @@ END_FUNC(PKG)   /* end H5EA__hdr_decr() */
  *
  *-------------------------------------------------------------------------
  */
-BEGIN_FUNC(PKG, NOERR,
-herr_t, SUCCEED, -,
-H5EA__hdr_fuse_incr(H5EA_hdr_t *hdr))
+herr_t
+H5EA__hdr_fuse_incr(H5EA_hdr_t *hdr)
+{
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
     HDassert(hdr);
@@ -540,24 +558,28 @@ H5EA__hdr_fuse_incr(H5EA_hdr_t *hdr))
     /* Increment file reference count on shared header */
     hdr->file_rc++;
 
-END_FUNC(PKG)   /* end H5EA__hdr_fuse_incr() */
+    FUNC_LEAVE_NOAPI(SUCCEED)
+} /* end H5EA__hdr_fuse_incr() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5EA__hdr_fuse_decr
  *
  * Purpose:	Decrement file reference count on shared array header
  *
- * Return:	Non-negative on success/Negative on failure
+ * Return:      Success:    The reference count of the header
+ *              Failure:    Can't fail
  *
  * Programmer:	Quincey Koziol
  *		Aug 26 2008
  *
  *-------------------------------------------------------------------------
  */
-BEGIN_FUNC(PKG, NOERR,
-size_t, 0, -,
-H5EA__hdr_fuse_decr(H5EA_hdr_t *hdr))
+size_t
+H5EA__hdr_fuse_decr(H5EA_hdr_t *hdr)
+{
+    size_t ret_value = 0;
+
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
     HDassert(hdr);
@@ -569,9 +591,9 @@ H5EA__hdr_fuse_decr(H5EA_hdr_t *hdr))
     /* Set return value */
     ret_value = hdr->file_rc;
 
-END_FUNC(PKG)   /* end H5EA__hdr_fuse_decr() */
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5EA__hdr_fuse_decr() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5EA__hdr_modified
  *
@@ -584,23 +606,25 @@ END_FUNC(PKG)   /* end H5EA__hdr_fuse_decr() */
  *
  *-------------------------------------------------------------------------
  */
-BEGIN_FUNC(PKG, ERR,
-herr_t, SUCCEED, FAIL,
-H5EA__hdr_modified(H5EA_hdr_t *hdr))
+herr_t
+H5EA__hdr_modified(H5EA_hdr_t *hdr)
+{
+    herr_t ret_value = SUCCEED;
+
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(hdr);
     HDassert(hdr->f);
 
     /* Mark header as dirty in cache */
-    if(H5AC_mark_entry_dirty(hdr) < 0)
-        H5E_THROW(H5E_CANTMARKDIRTY, "unable to mark extensible array header as dirty")
+    if (H5AC_mark_entry_dirty(hdr) < 0)
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTMARKDIRTY, FAIL, "unable to mark extensible array header as dirty")
 
-CATCH
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5EA__hdr_modified() */
 
-END_FUNC(PKG)   /* end H5EA__hdr_modified() */
-
-
 /*-------------------------------------------------------------------------
  * Function:	H5EA__hdr_protect
  *
@@ -613,14 +637,14 @@ END_FUNC(PKG)   /* end H5EA__hdr_modified() */
  *
  *-------------------------------------------------------------------------
  */
-BEGIN_FUNC(PKG, ERR,
-H5EA_hdr_t *, NULL, NULL,
-H5EA__hdr_protect(H5F_t *f, haddr_t ea_addr, void *ctx_udata,
-    unsigned flags))
+H5EA_hdr_t *
+H5EA__hdr_protect(H5F_t *f, haddr_t ea_addr, void *ctx_udata, unsigned flags)
+{
+    H5EA_hdr_t         *hdr;   /* Extensible array header */
+    H5EA_hdr_cache_ud_t udata; /* User data for cache callbacks */
+    H5EA_hdr_t         *ret_value = NULL;
 
-    /* Local variables */
-    H5EA_hdr_t *hdr;            /* Extensible array header */
-    H5EA_hdr_cache_ud_t udata;  /* User data for cache callbacks */
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(f);
@@ -630,34 +654,35 @@ H5EA__hdr_protect(H5F_t *f, haddr_t ea_addr, void *ctx_udata,
     HDassert((flags & (unsigned)(~H5AC__READ_ONLY_FLAG)) == 0);
 
     /* Set up user data for cache callbacks */
-    udata.f = f;
-    udata.addr = ea_addr;
+    udata.f         = f;
+    udata.addr      = ea_addr;
     udata.ctx_udata = ctx_udata;
 
     /* Protect the header */
-    if(NULL == (hdr = (H5EA_hdr_t *)H5AC_protect(f, H5AC_EARRAY_HDR, ea_addr, &udata, flags)))
-        H5E_THROW(H5E_CANTPROTECT, "unable to protect extensible array header, address = %llu", (unsigned long long)ea_addr)
-    hdr->f = f;   /* (Must be set again here, in case the header was already in the cache -QAK) */
+    if (NULL == (hdr = (H5EA_hdr_t *)H5AC_protect(f, H5AC_EARRAY_HDR, ea_addr, &udata, flags)))
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTPROTECT, NULL,
+                    "unable to protect extensible array header, address = %llu", (unsigned long long)ea_addr)
+    hdr->f = f; /* (Must be set again here, in case the header was already in the cache -QAK) */
 
     /* Create top proxy, if it doesn't exist */
-    if(hdr->swmr_write && NULL == hdr->top_proxy) {
+    if (hdr->swmr_write && NULL == hdr->top_proxy) {
         /* Create 'top' proxy for extensible array entries */
-        if(NULL == (hdr->top_proxy = H5AC_proxy_entry_create()))
-            H5E_THROW(H5E_CANTCREATE, "can't create extensible array entry proxy")
+        if (NULL == (hdr->top_proxy = H5AC_proxy_entry_create()))
+            HGOTO_ERROR(H5E_EARRAY, H5E_CANTCREATE, NULL, "can't create extensible array entry proxy")
 
         /* Add header as child of 'top' proxy */
-        if(H5AC_proxy_entry_add_child(hdr->top_proxy, f, hdr) < 0)
-            H5E_THROW(H5E_CANTSET, "unable to add extensible array entry as child of array proxy")
+        if (H5AC_proxy_entry_add_child(hdr->top_proxy, f, hdr) < 0)
+            HGOTO_ERROR(H5E_EARRAY, H5E_CANTSET, NULL,
+                        "unable to add extensible array entry as child of array proxy")
     } /* end if */
 
     /* Set return value */
     ret_value = hdr;
 
-CATCH
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5EA__hdr_protect() */
 
-END_FUNC(PKG)   /* end H5EA__hdr_protect() */
-
-
 /*-------------------------------------------------------------------------
  * Function:	H5EA__hdr_unprotect
  *
@@ -670,24 +695,25 @@ END_FUNC(PKG)   /* end H5EA__hdr_protect() */
  *
  *-------------------------------------------------------------------------
  */
-BEGIN_FUNC(PKG, ERR,
-herr_t, SUCCEED, FAIL,
-H5EA__hdr_unprotect(H5EA_hdr_t *hdr, unsigned cache_flags))
+herr_t
+H5EA__hdr_unprotect(H5EA_hdr_t *hdr, unsigned cache_flags)
+{
+    herr_t ret_value = SUCCEED;
 
-    /* Local variables */
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(hdr);
 
     /* Unprotect the header */
-    if(H5AC_unprotect(hdr->f, H5AC_EARRAY_HDR, hdr->addr, hdr, cache_flags) < 0)
-        H5E_THROW(H5E_CANTUNPROTECT, "unable to unprotect extensible array hdr, address = %llu", (unsigned long long)hdr->addr)
+    if (H5AC_unprotect(hdr->f, H5AC_EARRAY_HDR, hdr->addr, hdr, cache_flags) < 0)
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL,
+                    "unable to unprotect extensible array hdr, address = %llu", (unsigned long long)hdr->addr)
 
-CATCH
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5EA__hdr_unprotect() */
 
-END_FUNC(PKG)   /* end H5EA__hdr_unprotect() */
-
-
 /*-------------------------------------------------------------------------
  * Function:	H5EA__hdr_delete
  *
@@ -700,50 +726,49 @@ END_FUNC(PKG)   /* end H5EA__hdr_unprotect() */
  *
  *-------------------------------------------------------------------------
  */
-BEGIN_FUNC(PKG, ERR,
-herr_t, SUCCEED, FAIL,
-H5EA__hdr_delete(H5EA_hdr_t *hdr))
+herr_t
+H5EA__hdr_delete(H5EA_hdr_t *hdr)
+{
+    unsigned cache_flags = H5AC__NO_FLAGS_SET; /* Flags for unprotecting header */
+    herr_t   ret_value   = SUCCEED;
 
-    /* Local variables */
-    unsigned cache_flags = H5AC__NO_FLAGS_SET;  /* Flags for unprotecting header */
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(hdr);
     HDassert(!hdr->file_rc);
 
 #ifndef NDEBUG
-{
-    unsigned hdr_status = 0;         /* Array header's status in the metadata cache */
+    unsigned hdr_status = 0; /* Array header's status in the metadata cache */
 
     /* Check the array header's status in the metadata cache */
-    if(H5AC_get_entry_status(hdr->f, hdr->addr, &hdr_status) < 0)
-        H5E_THROW(H5E_CANTGET, "unable to check metadata cache status for array header")
+    if (H5AC_get_entry_status(hdr->f, hdr->addr, &hdr_status) < 0)
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTGET, FAIL, "unable to check metadata cache status for array header")
 
     /* Sanity checks on array header */
     HDassert(hdr_status & H5AC_ES__IN_CACHE);
     HDassert(hdr_status & H5AC_ES__IS_PROTECTED);
-} /* end block */
 #endif /* NDEBUG */
 
     /* Check for index block */
-    if(H5F_addr_defined(hdr->idx_blk_addr)) {
+    if (H5F_addr_defined(hdr->idx_blk_addr)) {
         /* Delete index block */
-        if(H5EA__iblock_delete(hdr) < 0)
-            H5E_THROW(H5E_CANTDELETE, "unable to delete extensible array index block")
+        if (H5EA__iblock_delete(hdr) < 0)
+            HGOTO_ERROR(H5E_EARRAY, H5E_CANTDELETE, FAIL, "unable to delete extensible array index block")
     } /* end if */
 
     /* Set flags to finish deleting header on unprotect */
     cache_flags |= H5AC__DIRTIED_FLAG | H5AC__DELETED_FLAG | H5AC__FREE_FILE_SPACE_FLAG;
 
-CATCH
+done:
 
     /* Unprotect the header, deleting it if an error hasn't occurred */
-    if(H5EA__hdr_unprotect(hdr, cache_flags) < 0)
-        H5E_THROW(H5E_CANTUNPROTECT, "unable to release extensible array header")
+    if (H5EA__hdr_unprotect(hdr, cache_flags) < 0)
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release extensible array header")
 
-END_FUNC(PKG)   /* end H5EA__hdr_delete() */
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5EA__hdr_delete() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5EA__hdr_dest
  *
@@ -756,57 +781,61 @@ END_FUNC(PKG)   /* end H5EA__hdr_delete() */
  *
  *-------------------------------------------------------------------------
  */
-BEGIN_FUNC(PKG, ERR,
-herr_t, SUCCEED, FAIL,
-H5EA__hdr_dest(H5EA_hdr_t *hdr))
+herr_t
+H5EA__hdr_dest(H5EA_hdr_t *hdr)
+{
+    herr_t ret_value = SUCCEED;
+
+    FUNC_ENTER_PACKAGE
 
     /* Check arguments */
     HDassert(hdr);
     HDassert(hdr->rc == 0);
 
     /* Destroy the callback context */
-    if(hdr->cb_ctx) {
-        if((*hdr->cparam.cls->dst_context)(hdr->cb_ctx) < 0)
-            H5E_THROW(H5E_CANTRELEASE, "unable to destroy extensible array client callback context")
+    if (hdr->cb_ctx) {
+        if ((*hdr->cparam.cls->dst_context)(hdr->cb_ctx) < 0)
+            HGOTO_ERROR(H5E_EARRAY, H5E_CANTRELEASE, FAIL,
+                        "unable to destroy extensible array client callback context")
     } /* end if */
     hdr->cb_ctx = NULL;
 
     /* Check for data block element buffer factory info to free */
-    if(hdr->elmt_fac.fac) {
-        unsigned u;         /* Local index variable */
+    if (hdr->elmt_fac.fac) {
+        unsigned u; /* Local index variable */
 
         /* Sanity check */
         HDassert(hdr->elmt_fac.nalloc > 0);
 
         /* Iterate over factories, shutting them down */
-        for(u = 0; u < hdr->elmt_fac.nalloc; u++) {
+        for (u = 0; u < hdr->elmt_fac.nalloc; u++) {
             /* Check if this factory has been initialized */
-            if(hdr->elmt_fac.fac[u]) {
-                if(H5FL_fac_term(hdr->elmt_fac.fac[u]) < 0)
-                    H5E_THROW(H5E_CANTRELEASE, "unable to destroy extensible array header factory")
+            if (hdr->elmt_fac.fac[u]) {
+                if (H5FL_fac_term(hdr->elmt_fac.fac[u]) < 0)
+                    HGOTO_ERROR(H5E_EARRAY, H5E_CANTRELEASE, FAIL,
+                                "unable to destroy extensible array header factory")
                 hdr->elmt_fac.fac[u] = NULL;
             } /* end if */
-        } /* end for */
+        }     /* end for */
 
         /* Free factory array */
         hdr->elmt_fac.fac = (H5FL_fac_head_t **)H5FL_SEQ_FREE(H5FL_fac_head_ptr_t, hdr->elmt_fac.fac);
     } /* end if */
 
     /* Free the super block info array */
-    if(hdr->sblk_info)
+    if (hdr->sblk_info)
         hdr->sblk_info = (H5EA_sblk_info_t *)H5FL_SEQ_FREE(H5EA_sblk_info_t, hdr->sblk_info);
 
     /* Destroy the 'top' proxy */
-    if(hdr->top_proxy) {
-        if(H5AC_proxy_entry_dest(hdr->top_proxy) < 0)
-            H5E_THROW(H5E_CANTRELEASE, "unable to destroy extensible array 'top' proxy")
+    if (hdr->top_proxy) {
+        if (H5AC_proxy_entry_dest(hdr->top_proxy) < 0)
+            HGOTO_ERROR(H5E_EARRAY, H5E_CANTRELEASE, FAIL, "unable to destroy extensible array 'top' proxy")
         hdr->top_proxy = NULL;
     } /* end if */
 
     /* Free the shared info itself */
     hdr = H5FL_FREE(H5EA_hdr_t, hdr);
 
-CATCH
-
-END_FUNC(PKG)   /* end H5EA__hdr_dest() */
-
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5EA__hdr_dest() */
