@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -26,58 +25,47 @@
 /* Module Declaration */
 /**********************/
 
-#include "H5EAmodule.h"         /* This source code file is part of the H5EA module */
-
+#include "H5EAmodule.h" /* This source code file is part of the H5EA module */
 
 /***********************/
 /* Other Packages Used */
 /***********************/
 
-
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"		/* Generic Functions			*/
-#include "H5Eprivate.h"		/* Error handling		  	*/
-#include "H5EApkg.h"		/* Extensible Arrays			*/
-
+#include "H5private.h"  /* Generic Functions			*/
+#include "H5Eprivate.h" /* Error handling		  	*/
+#include "H5EApkg.h"    /* Extensible Arrays			*/
 
 /****************/
 /* Local Macros */
 /****************/
 
-
 /******************/
 /* Local Typedefs */
 /******************/
 
-
 /********************/
 /* Package Typedefs */
 /********************/
 
-
 /********************/
 /* Local Prototypes */
 /********************/
 
-
 /*********************/
 /* Package Variables */
 /*********************/
 
-
 /*****************************/
 /* Library Private Variables */
 /*****************************/
 
-
 /*******************/
 /* Local Variables */
 /*******************/
 
-
-
 /*-------------------------------------------------------------------------
  * Function:	H5EA__create_flush_depend
  *
@@ -90,23 +78,25 @@
  *
  *-------------------------------------------------------------------------
  */
-BEGIN_FUNC(PKG, ERR,
-herr_t, SUCCEED, FAIL,
-H5EA__create_flush_depend(H5AC_info_t *parent_entry, H5AC_info_t *child_entry))
+herr_t
+H5EA__create_flush_depend(H5AC_info_t *parent_entry, H5AC_info_t *child_entry)
+{
+    herr_t ret_value = SUCCEED; /* Return value */
+
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(parent_entry);
     HDassert(child_entry);
 
     /* Create a flush dependency between parent and child entry */
-    if(H5AC_create_flush_dependency(parent_entry, child_entry) < 0)
-        H5E_THROW(H5E_CANTDEPEND, "unable to create flush dependency")
+    if (H5AC_create_flush_dependency(parent_entry, child_entry) < 0)
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTDEPEND, FAIL, "unable to create flush dependency")
 
-CATCH
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5EA__create_flush_depend() */
 
-END_FUNC(PKG)   /* end H5EA__create_flush_depend() */
-
-
 /*-------------------------------------------------------------------------
  * Function:	H5EA__destroy_flush_depend
  *
@@ -119,19 +109,21 @@ END_FUNC(PKG)   /* end H5EA__create_flush_depend() */
  *
  *-------------------------------------------------------------------------
  */
-BEGIN_FUNC(PKG, ERR,
-herr_t, SUCCEED, FAIL,
-H5EA__destroy_flush_depend(H5AC_info_t *parent_entry, H5AC_info_t *child_entry))
+herr_t
+H5EA__destroy_flush_depend(H5AC_info_t *parent_entry, H5AC_info_t *child_entry)
+{
+    herr_t ret_value = SUCCEED; /* Return value */
+
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(parent_entry);
     HDassert(child_entry);
 
     /* Destroy a flush dependency between parent and child entry */
-    if(H5AC_destroy_flush_dependency(parent_entry, child_entry) < 0)
-        H5E_THROW(H5E_CANTUNDEPEND, "unable to destroy flush dependency")
-
-CATCH
-
-END_FUNC(PKG)   /* end H5EA__destroy_flush_depend() */
+    if (H5AC_destroy_flush_dependency(parent_entry, child_entry) < 0)
+        HGOTO_ERROR(H5E_EARRAY, H5E_CANTUNDEPEND, FAIL, "unable to destroy flush dependency")
 
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5EA__destroy_flush_depend() */
