@@ -5,7 +5,7 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -18,16 +18,15 @@
  *		H5FA package.  Including this header means that the source file
  *		is part of the H5FA package.
  */
-#ifndef _H5FAmodule_H
-#define _H5FAmodule_H
+#ifndef H5FAmodule_H
+#define H5FAmodule_H
 
 /* Define the proper control macros for the generic FUNC_ENTER/LEAVE and error
  *      reporting macros.
  */
 #define H5FA_MODULE
-#define H5_MY_PKG       H5FA
-#define H5_MY_PKG_ERR   H5E_FARRAY
-#define H5_MY_PKG_INIT  NO
-
-#endif /* _H5FAmodule_H */
+#define H5_MY_PKG      H5FA
+#define H5_MY_PKG_ERR  H5E_FARRAY
+#define H5_MY_PKG_INIT NO
 
+#endif /* H5FAmodule_H */
