@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -15,7 +14,7 @@
  *
  * Created:             H5Fquery.c
  *                      Jan 10 2008
- *                      Quincey Koziol <koziol@hdfgroup.org>
+ *                      Quincey Koziol
  *
  * Purpose:             File structure query routines.
  *
@@ -26,54 +25,65 @@
 /* Module Setup */
 /****************/
 
-#include "H5Fmodule.h"        /* This source code file is part of the H5F module */
-
+#include "H5Fmodule.h" /* This source code file is part of the H5F module */
 
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"          /* Generic Functions                        */
-#include "H5Eprivate.h"         /* Error handling                           */
-#include "H5Fpkg.h"             /* File access                              */
-#include "H5FDprivate.h"        /* File drivers                             */
-
+#include "H5private.h"   /* Generic Functions                        */
+#include "H5Eprivate.h"  /* Error handling                           */
+#include "H5Fpkg.h"      /* File access                              */
+#include "H5FDprivate.h" /* File drivers                             */
 
 /****************/
 /* Local Macros */
 /****************/
 
-
 /******************/
 /* Local Typedefs */
 /******************/
 
-
 /********************/
 /* Package Typedefs */
 /********************/
 
-
 /********************/
 /* Local Prototypes */
 /********************/
 
-
 /*********************/
 /* Package Variables */
 /*********************/
 
-
 /*****************************/
 /* Library Private Variables */
 /*****************************/
 
-
 /*******************/
 /* Local Variables */
 /*******************/
 
+/*-------------------------------------------------------------------------
+ * Function: H5F_shared_get_intent
+ *
+ * Purpose:  Quick and dirty routine to retrieve the file's 'intent' flags
+ *           (Mainly added to stop non-file routines from poking about in the
+ *           H5F_shared_t data structure)
+ *
+ * Return:   'intent' on success/abort on failure (shouldn't fail)
+ *-------------------------------------------------------------------------
+ */
+unsigned
+H5F_shared_get_intent(const H5F_shared_t *f_sh)
+{
+    /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+    FUNC_ENTER_NOAPI_NOINIT_NOERR
+
+    HDassert(f_sh);
+
+    FUNC_LEAVE_NOAPI(f_sh->flags)
+} /* end H5F_shared_get_intent() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_intent
  *
@@ -95,7 +105,6 @@ H5F_get_intent(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->flags)
 } /* end H5F_get_intent() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5F_get_low_bound
  *
@@ -120,7 +129,6 @@ H5F_get_low_bound(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->low_bound)
 } /* end H5F_get_low_bound() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5F_get_high_bound
  *
@@ -145,7 +153,6 @@ H5F_get_high_bound(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->high_bound)
 } /* end H5F_get_high_bound() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_open_name
  *
@@ -167,7 +174,6 @@ H5F_get_open_name(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->open_name)
 } /* end H5F_get_open_name() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_actual_name
  *
@@ -189,13 +195,12 @@ H5F_get_actual_name(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->actual_name)
 } /* end H5F_get_actual_name() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_extpath
  *
  * Purpose:  Retrieve the file's 'extpath' flags
- *           This is used by H5L_extern_traverse() and H5D_build_file_prefix() to retrieve the main file's location
- *           when searching the target file.
+ *           This is used by H5L_extern_traverse() and H5D_build_file_prefix()
+ *           to retrieve the main file's location when searching the target file.
  *
  * Return:   'extpath' on success/abort on failure (shouldn't fail)
  *-------------------------------------------------------------------------
@@ -212,7 +217,6 @@ H5F_get_extpath(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->extpath)
 } /* end H5F_get_extpath() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_shared
  *
@@ -221,7 +225,7 @@ H5F_get_extpath(const H5F_t *f)
  * Return:   'shared' on success/abort on failure (shouldn't fail)
  *-------------------------------------------------------------------------
  */
-H5F_file_t *
+H5F_shared_t *
 H5F_get_shared(const H5F_t *f)
 {
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
@@ -232,7 +236,6 @@ H5F_get_shared(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared)
 } /* end H5F_get_shared() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_same_shared
  *
@@ -255,7 +258,6 @@ H5F_same_shared(const H5F_t *f1, const H5F_t *f2)
     FUNC_LEAVE_NOAPI(f1->shared == f2->shared)
 } /* end H5F_same_shared() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_nopen_objs
  *
@@ -275,13 +277,12 @@ H5F_get_nopen_objs(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->nopen_objs)
 } /* end H5F_get_nopen_objs() */
 
-
 /*-------------------------------------------------------------------------
- * Function: H5F_get_file_id
+ * Function:    H5F_get_file_id
  *
- * Purpose:  Retrieve the file's 'file_id' value
+ * Purpose:     Retrieve the file's 'file_id' value
  *
- * Return:   'file_id' on success/abort on failure (shouldn't fail)
+ * Return:      'file_id' on success/abort on failure (shouldn't fail)
  *-------------------------------------------------------------------------
  */
 hid_t
@@ -295,7 +296,6 @@ H5F_get_file_id(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->file_id)
 } /* end H5F_get_file_id() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_parent
  *
@@ -315,7 +315,6 @@ H5F_get_parent(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->parent)
 } /* end H5F_get_parent() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_nmounts
  *
@@ -335,7 +334,6 @@ H5F_get_nmounts(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->nmounts)
 } /* end H5F_get_nmounts() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_read_attempts
  *
@@ -355,7 +353,6 @@ H5F_get_read_attempts(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->read_attempts)
 } /* end H5F_get_read_attempts() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_fcpl
  *
@@ -377,7 +374,6 @@ H5F_get_fcpl(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->fcpl_id)
 } /* end H5F_get_fcpl() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_sizeof_addr
  *
@@ -400,7 +396,6 @@ H5F_sizeof_addr(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->sizeof_addr)
 } /* end H5F_sizeof_addr() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_sizeof_size
  *
@@ -423,7 +418,6 @@ H5F_sizeof_size(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->sizeof_size)
 } /* H5F_sizeof_size() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_sohm_addr
  *
@@ -444,7 +438,6 @@ H5F_get_sohm_addr(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->sohm_addr)
 } /* end H5F_get_sohm_addr() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_sohm_vers
  *
@@ -465,7 +458,6 @@ H5F_get_sohm_vers(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->sohm_vers)
 } /* end H5F_get_sohm_vers() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_sohm_nindexes
  *
@@ -486,7 +478,6 @@ H5F_get_sohm_nindexes(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->sohm_nindexes)
 } /* end H5F_get_sohm_nindexes() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_sym_leaf_k
  *
@@ -512,7 +503,6 @@ H5F_sym_leaf_k(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->sblock->sym_leaf_k)
 } /* end H5F_sym_leaf_k() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_min_dset_ohdr
  *
@@ -531,7 +521,6 @@ H5F_get_min_dset_ohdr(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->crt_dset_min_ohdr_flag)
 } /* end H5F_get_min_dset_ohdr */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_Kvalue
  *
@@ -558,7 +547,6 @@ H5F_Kvalue(const H5F_t *f, const H5B_class_t *type)
     FUNC_LEAVE_NOAPI(f->shared->sblock->btree_k[type->id])
 } /* end H5F_Kvalue() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_nrefs
  *
@@ -579,7 +567,6 @@ H5F_get_nrefs(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->nrefs)
 } /* end H5F_get_nrefs() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_rdcc_nslots
  *
@@ -604,7 +591,6 @@ H5F_rdcc_nslots(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->rdcc_nslots)
 } /* end H5F_rdcc_nelmts() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_rdcc_nbytes
  *
@@ -629,7 +615,6 @@ H5F_rdcc_nbytes(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->rdcc_nbytes)
 } /* end H5F_rdcc_nbytes() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_rdcc_w0
  *
@@ -654,7 +639,6 @@ H5F_rdcc_w0(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->rdcc_w0)
 } /* end H5F_rdcc_w0() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_base_addr
  *
@@ -678,7 +662,6 @@ H5F_get_base_addr(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->sblock->base_addr)
 } /* end H5F_get_base_addr() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_grp_btree_shared
  *
@@ -703,7 +686,6 @@ H5F_grp_btree_shared(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->grp_btree_shared)
 } /* end H5F_grp_btree_shared() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_sieve_buf_size
  *
@@ -728,7 +710,6 @@ H5F_sieve_buf_size(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->sieve_buf_size)
 } /* end H5F_sieve_buf_size() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_gc_ref
  *
@@ -740,7 +721,6 @@ H5F_sieve_buf_size(const H5F_t *f)
  *          Failure:    (should not happen)
  *
  * Programmer:  Quincey Koziol
- *              koziol@ncsa.uiuc.edu
  *              Jul  8 2005
  *
  *-------------------------------------------------------------------------
@@ -757,7 +737,6 @@ H5F_gc_ref(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->gc_ref)
 } /* end H5F_gc_ref() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_fc_degree
  *
@@ -779,7 +758,6 @@ H5F_get_fc_degree(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->fc_degree)
 } /* end H5F_get_fc_degree() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5F_get_evict_on_close
  *
@@ -803,7 +781,6 @@ H5F_get_evict_on_close(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->evict_on_close)
 } /* end H5F_get_evict_on_close() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_store_msg_crt_idx
  *
@@ -825,7 +802,26 @@ H5F_store_msg_crt_idx(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->store_msg_crt_idx)
 } /* end H5F_store_msg_crt_idx() */
 
-
+/*-------------------------------------------------------------------------
+ * Function: H5F_shared_has_feature
+ *
+ * Purpose:  Check if a file has a particular feature enabled
+ *
+ * Return:   Success:    Non-negative - TRUE or FALSE
+ *           Failure:    Negative (should not happen)
+ *-------------------------------------------------------------------------
+ */
+hbool_t
+H5F_shared_has_feature(const H5F_shared_t *f_sh, unsigned feature)
+{
+    /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+    FUNC_ENTER_NOAPI_NOINIT_NOERR
+
+    HDassert(f_sh);
+
+    FUNC_LEAVE_NOAPI((hbool_t)(f_sh->lf->feature_flags & feature))
+} /* end H5F_shared_has_feature() */
+
 /*-------------------------------------------------------------------------
  * Function: H5F_has_feature
  *
@@ -844,10 +840,9 @@ H5F_has_feature(const H5F_t *f, unsigned feature)
     HDassert(f);
     HDassert(f->shared);
 
-    FUNC_LEAVE_NOAPI((hbool_t)(f->shared->lf->feature_flags&feature))
+    FUNC_LEAVE_NOAPI((hbool_t)(f->shared->lf->feature_flags & feature))
 } /* end H5F_has_feature() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_driver_id
  *
@@ -871,7 +866,6 @@ H5F_get_driver_id(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->lf->driver_id)
 } /* end H5F_get_driver_id() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_fileno
  *
@@ -885,7 +879,7 @@ H5F_get_driver_id(const H5F_t *f)
 herr_t
 H5F_get_fileno(const H5F_t *f, unsigned long *filenum)
 {
-    herr_t    ret_value = SUCCEED;
+    herr_t ret_value = SUCCEED;
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -895,14 +889,38 @@ H5F_get_fileno(const H5F_t *f, unsigned long *filenum)
     HDassert(filenum);
 
     /* Retrieve the file's serial number */
-    if(H5FD_get_fileno(f->shared->lf, filenum) < 0)
-    HGOTO_ERROR(H5E_FILE, H5E_BADRANGE, FAIL, "can't retrieve fileno")
+    if (H5FD_get_fileno(f->shared->lf, filenum) < 0)
+        HGOTO_ERROR(H5E_FILE, H5E_BADRANGE, FAIL, "can't retrieve fileno")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5F_get_fileno() */
 
-
+/*-------------------------------------------------------------------------
+ * Function: H5F_shared_get_eoa
+ *
+ * Purpose:  Quick and dirty routine to retrieve the file's 'eoa' value
+ *
+ * Return:   Non-negative on success/Negative on failure
+ *-------------------------------------------------------------------------
+ */
+haddr_t
+H5F_shared_get_eoa(const H5F_shared_t *f_sh, H5FD_mem_t type)
+{
+    haddr_t ret_value = HADDR_UNDEF; /* Return value */
+
+    FUNC_ENTER_NOAPI(HADDR_UNDEF)
+
+    HDassert(f_sh);
+
+    /* Dispatch to driver */
+    if (HADDR_UNDEF == (ret_value = H5FD_get_eoa(f_sh->lf, type)))
+        HGOTO_ERROR(H5E_VFL, H5E_CANTINIT, HADDR_UNDEF, "driver get_eoa request failed")
+
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5F_shared_get_eoa() */
+
 /*-------------------------------------------------------------------------
  * Function: H5F_get_eoa
  *
@@ -914,7 +932,7 @@ done:
 haddr_t
 H5F_get_eoa(const H5F_t *f, H5FD_mem_t type)
 {
-    haddr_t    ret_value = HADDR_UNDEF;        /* Return value */
+    haddr_t ret_value = HADDR_UNDEF; /* Return value */
 
     FUNC_ENTER_NOAPI(HADDR_UNDEF)
 
@@ -922,14 +940,13 @@ H5F_get_eoa(const H5F_t *f, H5FD_mem_t type)
     HDassert(f->shared);
 
     /* Dispatch to driver */
-    if(HADDR_UNDEF == (ret_value = H5FD_get_eoa(f->shared->lf, type)))
-    HGOTO_ERROR(H5E_VFL, H5E_CANTINIT, HADDR_UNDEF, "driver get_eoa request failed")
+    if (HADDR_UNDEF == (ret_value = H5FD_get_eoa(f->shared->lf, type)))
+        HGOTO_ERROR(H5E_VFL, H5E_CANTINIT, HADDR_UNDEF, "driver get_eoa request failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5F_get_eoa() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5F_get_vfd_handle
  *
@@ -943,7 +960,7 @@ done:
 herr_t
 H5F_get_vfd_handle(const H5F_t *file, hid_t fapl, void **file_handle)
 {
-    herr_t ret_value = SUCCEED;         /* Return value */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -952,14 +969,13 @@ H5F_get_vfd_handle(const H5F_t *file, hid_t fapl, void **file_handle)
     HDassert(file_handle);
 
     /* Get the VFD handle */
-    if(H5FD_get_vfd_handle(file->shared->lf, fapl, file_handle) < 0)
+    if (H5FD_get_vfd_handle(file->shared->lf, fapl, file_handle) < 0)
         HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get file handle for file driver")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5F_get_vfd_handle() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_is_tmp_addr
  *
@@ -983,7 +999,6 @@ H5F_is_tmp_addr(const H5F_t *f, haddr_t addr)
     FUNC_LEAVE_NOAPI(H5F_addr_le(f->shared->tmp_addr, addr))
 } /* end H5F_is_tmp_addr() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_use_tmp_space
  *
@@ -1008,7 +1023,7 @@ H5F_use_tmp_space(const H5F_t *f)
 } /* end H5F_use_tmp_space() */
 
 #ifdef H5_HAVE_PARALLEL
-
+
 /*-------------------------------------------------------------------------
  * Function: H5F_coll_md_read
  *
@@ -1030,7 +1045,6 @@ H5F_coll_md_read(const H5F_t *f)
 } /* end H5F_coll_md_read() */
 #endif /* H5_HAVE_PARALLEL */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_use_mdc_logging
  *
@@ -1054,7 +1068,6 @@ H5F_use_mdc_logging(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->use_mdc_logging)
 } /* end H5F_use_mdc_logging() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_start_mdc_log_on_access
  *
@@ -1078,7 +1091,6 @@ H5F_start_mdc_log_on_access(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->start_mdc_log_on_access)
 } /* end H5F_start_mdc_log_on_access() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_mdc_log_location
  *
@@ -1102,7 +1114,6 @@ H5F_mdc_log_location(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->mdc_log_location)
 } /* end H5F_mdc_log_location() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_alignment
  *
@@ -1124,7 +1135,6 @@ H5F_get_alignment(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->alignment)
 } /* end H5F_get_alignment() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_threshold
  *
@@ -1146,7 +1156,6 @@ H5F_get_threshold(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->threshold)
 } /* end H5F_get_threshold() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_pgend_meta_thres
  *
@@ -1168,7 +1177,6 @@ H5F_get_pgend_meta_thres(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->pgend_meta_thres)
 } /* end H5F_get_pgend_meta_thres() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_point_of_no_return
  *
@@ -1190,7 +1198,6 @@ H5F_get_point_of_no_return(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->point_of_no_return)
 } /* end H5F_get_point_of_no_return() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_first_alloc_dealloc
  *
@@ -1212,7 +1219,6 @@ H5F_get_first_alloc_dealloc(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->first_alloc_dealloc)
 } /* end H5F_get_first_alloc_dealloc() */
 
-
 /*-------------------------------------------------------------------------
  * Function: H5F_get_eoa_pre_fsm_fsalloc
  *
@@ -1234,3 +1240,22 @@ H5F_get_eoa_pre_fsm_fsalloc(const H5F_t *f)
     FUNC_LEAVE_NOAPI(f->shared->eoa_pre_fsm_fsalloc)
 } /* end H5F_get_eoa_pre_fsm_fsalloc() */
 
+/*-------------------------------------------------------------------------
+ * Function: H5F_get_file_locking
+ *
+ * Purpose:  Get the file locking flag for the file
+ *
+ * Return:   TRUE/FALSE
+ *
+ *-------------------------------------------------------------------------
+ */
+hbool_t
+H5F_get_file_locking(const H5F_t *f)
+{
+    FUNC_ENTER_NOAPI_NOINIT_NOERR
+
+    HDassert(f);
+    HDassert(f->shared);
+
+    FUNC_LEAVE_NOAPI(f->shared->use_file_locking)
+} /* end H5F_get_file_locking */
