@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -75,41 +74,35 @@
 /* Module Setup */
 /****************/
 
-#include "H5Gmodule.h"          /* This source code file is part of the H5G module */
-
+#include "H5Gmodule.h" /* This source code file is part of the H5G module */
 
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"          /* Generic Functions                        */
-#include "H5ACprivate.h"        /* Metadata cache                           */
-#include "H5CXprivate.h"        /* API Contexts                             */
-#include "H5Eprivate.h"         /* Error handling                           */
-#include "H5Gpkg.h"             /* Groups                                   */
-#include "H5Iprivate.h"         /* IDs                                      */
-#include "H5Pprivate.h"         /* Property lists                           */
-
+#include "H5private.h"   /* Generic Functions                        */
+#include "H5ACprivate.h" /* Metadata cache                           */
+#include "H5CXprivate.h" /* API Contexts                             */
+#include "H5Eprivate.h"  /* Error handling                           */
+#include "H5Gpkg.h"      /* Groups                                   */
+#include "H5Iprivate.h"  /* IDs                                      */
+#include "H5Pprivate.h"  /* Property lists                           */
 
 /****************/
 /* Local Macros */
 /****************/
 
-
 /******************/
 /* Local Typedefs */
 /******************/
 
-
 /********************/
 /* Package Typedefs */
 /********************/
 
-
 /********************/
 /* Local Prototypes */
 /********************/
 
-
 /*********************/
 /* Package Variables */
 /*********************/
@@ -117,29 +110,25 @@
 /* Package initialization variable */
 hbool_t H5_PKG_INIT_VAR = FALSE;
 
-
 /*****************************/
 /* Library Private Variables */
 /*****************************/
 
-
 /*******************/
 /* Local Variables */
 /*******************/
 
 /* Group ID class */
 static const H5I_class_t H5I_GROUP_CLS[1] = {{
-    H5I_GROUP,                      /* ID class value */
-    0,                              /* Class flags */
-    0,                              /* # of reserved IDs for class */
-    (H5I_free_t)H5G__close_cb       /* Callback routine for closing objects of this class */
+    H5I_GROUP,                /* ID class value */
+    0,                        /* Class flags */
+    0,                        /* # of reserved IDs for class */
+    (H5I_free_t)H5G__close_cb /* Callback routine for closing objects of this class */
 }};
 
 /* Flag indicating "top" of interface has been initialized */
 static hbool_t H5G_top_package_initialize_s = FALSE;
 
-
-
 /*-------------------------------------------------------------------------
  * Function:	H5G__init_package
  *
@@ -162,13 +151,13 @@ static hbool_t H5G_top_package_initialize_s = FALSE;
 herr_t
 H5G__init_package(void)
 {
-    herr_t          ret_value = SUCCEED;  /* Return value */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE
 
     /* Initialize the atom group for the group IDs */
-    if(H5I_register_type(H5I_GROUP_CLS) < 0)
-	HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to initialize interface")
+    if (H5I_register_type(H5I_GROUP_CLS) < 0)
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to initialize interface")
 
     /* Mark "top" of interface as initialized, too */
     H5G_top_package_initialize_s = TRUE;
@@ -177,7 +166,6 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G__init_package() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5G_top_term_package
  *
@@ -195,25 +183,24 @@ done:
 int
 H5G_top_term_package(void)
 {
-    int	n = 0;
+    int n = 0;
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    if(H5G_top_package_initialize_s) {
-        if(H5I_nmembers(H5I_GROUP) > 0) {
+    if (H5G_top_package_initialize_s) {
+        if (H5I_nmembers(H5I_GROUP) > 0) {
             (void)H5I_clear_type(H5I_GROUP, FALSE, FALSE);
             n++; /*H5I*/
-        } /* end if */
+        }        /* end if */
 
         /* Mark closed */
-        if(0 == n)
+        if (0 == n)
             H5G_top_package_initialize_s = FALSE;
     } /* end if */
 
     FUNC_LEAVE_NOAPI(n)
 } /* end H5G_top_term_package() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5G_term_package
  *
@@ -234,11 +221,11 @@ H5G_top_term_package(void)
 int
 H5G_term_package(void)
 {
-    int	n = 0;
+    int n = 0;
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    if(H5_PKG_INIT_VAR) {
+    if (H5_PKG_INIT_VAR) {
         /* Sanity checks */
         HDassert(0 == H5I_nmembers(H5I_GROUP));
         HDassert(FALSE == H5G_top_package_initialize_s);
@@ -247,14 +234,13 @@ H5G_term_package(void)
         n += (H5I_dec_type_ref(H5I_GROUP) > 0);
 
         /* Mark closed */
-        if(0 == n)
+        if (0 == n)
             H5_PKG_INIT_VAR = FALSE;
     } /* end if */
 
     FUNC_LEAVE_NOAPI(n)
 } /* end H5G_term_package() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Gcreate2
  *
@@ -279,58 +265,54 @@ H5G_term_package(void)
  *-------------------------------------------------------------------------
  */
 hid_t
-H5Gcreate2(hid_t loc_id, const char *name, hid_t lcpl_id, hid_t gcpl_id,
-    hid_t gapl_id)
+H5Gcreate2(hid_t loc_id, const char *name, hid_t lcpl_id, hid_t gcpl_id, hid_t gapl_id)
 {
-    H5G_loc_t	    loc;                /* Location to create group */
-    H5G_t	   *grp = NULL;         /* New group created */
-    hid_t	    ret_value;          /* Return value */
+    H5G_loc_t loc;        /* Location to create group */
+    H5G_t    *grp = NULL; /* New group created */
+    hid_t     ret_value;  /* Return value */
 
     FUNC_ENTER_API(H5I_INVALID_HID)
     H5TRACE5("i", "i*siii", loc_id, name, lcpl_id, gcpl_id, gapl_id);
 
     /* Check arguments */
-    if(H5G_loc(loc_id, &loc) < 0)
-	HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not a location")
-    if(!name || !*name)
-	HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5I_INVALID_HID, "no name")
+    if (H5G_loc(loc_id, &loc) < 0)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not a location")
+    if (!name || !*name)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5I_INVALID_HID, "no name")
 
     /* Get correct property list */
-    if(H5P_DEFAULT == lcpl_id)
+    if (H5P_DEFAULT == lcpl_id)
         lcpl_id = H5P_LINK_CREATE_DEFAULT;
-    else
-        if(TRUE != H5P_isa_class(lcpl_id, H5P_LINK_CREATE))
-            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not link creation property list")
+    else if (TRUE != H5P_isa_class(lcpl_id, H5P_LINK_CREATE))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not link creation property list")
 
     /* Check group creation property list */
-    if(H5P_DEFAULT == gcpl_id)
+    if (H5P_DEFAULT == gcpl_id)
         gcpl_id = H5P_GROUP_CREATE_DEFAULT;
-    else
-        if(TRUE != H5P_isa_class(gcpl_id, H5P_GROUP_CREATE))
-            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not group create property list")
+    else if (TRUE != H5P_isa_class(gcpl_id, H5P_GROUP_CREATE))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not group create property list")
 
     /* Set the LCPL for the API context */
     H5CX_set_lcpl(lcpl_id);
 
     /* Verify access property list and set up collective metadata if appropriate */
-    if(H5CX_set_apl(&gapl_id, H5P_CLS_GACC, loc_id, TRUE) < 0)
+    if (H5CX_set_apl(&gapl_id, H5P_CLS_GACC, loc_id, TRUE) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTSET, H5I_INVALID_HID, "can't set access property list info")
 
     /* Create the new group & get its ID */
-    if(NULL == (grp = H5G__create_named(&loc, name, lcpl_id, gcpl_id)))
+    if (NULL == (grp = H5G__create_named(&loc, name, lcpl_id, gcpl_id)))
         HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, H5I_INVALID_HID, "unable to create group")
-    if((ret_value = H5I_register(H5I_GROUP, grp, TRUE)) < 0)
-	HGOTO_ERROR(H5E_ATOM, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register group")
+    if ((ret_value = H5I_register(H5I_GROUP, grp, TRUE)) < 0)
+        HGOTO_ERROR(H5E_ATOM, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register group")
 
 done:
-    if(ret_value < 0)
-        if(grp && H5G_close(grp) < 0)
+    if (ret_value < 0)
+        if (grp && H5G_close(grp) < 0)
             HDONE_ERROR(H5E_SYM, H5E_CLOSEERROR, H5I_INVALID_HID, "unable to release group")
 
     FUNC_LEAVE_API(ret_value)
 } /* end H5Gcreate2() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Gcreate_anon
  *
@@ -366,63 +348,62 @@ done:
 hid_t
 H5Gcreate_anon(hid_t loc_id, hid_t gcpl_id, hid_t gapl_id)
 {
-    H5G_loc_t	    loc;
-    H5G_t	   *grp = NULL;
-    H5G_obj_create_t gcrt_info;         /* Information for group creation */
-    hid_t	    ret_value;
+    H5G_loc_t        loc;
+    H5G_t           *grp = NULL;
+    H5G_obj_create_t gcrt_info; /* Information for group creation */
+    hid_t            ret_value;
 
     FUNC_ENTER_API(H5I_INVALID_HID)
     H5TRACE3("i", "iii", loc_id, gcpl_id, gapl_id);
 
     /* Check arguments */
-    if(H5G_loc(loc_id, &loc) < 0)
-	HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not a location")
+    if (H5G_loc(loc_id, &loc) < 0)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not a location")
 
     /* Check group creation property list */
-    if(H5P_DEFAULT == gcpl_id)
+    if (H5P_DEFAULT == gcpl_id)
         gcpl_id = H5P_GROUP_CREATE_DEFAULT;
-    else
-        if(TRUE != H5P_isa_class(gcpl_id, H5P_GROUP_CREATE))
-            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not group create property list")
+    else if (TRUE != H5P_isa_class(gcpl_id, H5P_GROUP_CREATE))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not group create property list")
 
     /* Verify access property list and set up collective metadata if appropriate */
-    if(H5CX_set_apl(&gapl_id, H5P_CLS_GACC, loc_id, TRUE) < 0)
+    if (H5CX_set_apl(&gapl_id, H5P_CLS_GACC, loc_id, TRUE) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTSET, H5I_INVALID_HID, "can't set access property list info")
 
     /* Set up group creation info */
-    gcrt_info.gcpl_id = gcpl_id;
+    gcrt_info.gcpl_id    = gcpl_id;
     gcrt_info.cache_type = H5G_NOTHING_CACHED;
     HDmemset(&gcrt_info.cache, 0, sizeof(gcrt_info.cache));
 
     /* Create the new group & get its ID */
-    if(NULL == (grp = H5G__create(loc.oloc->file, &gcrt_info)))
+    if (NULL == (grp = H5G__create(loc.oloc->file, &gcrt_info)))
         HGOTO_ERROR(H5E_SYM, H5E_CANTCREATE, H5I_INVALID_HID, "unable to create group")
-    if((ret_value = H5I_register(H5I_GROUP, grp, TRUE)) < 0)
+    if ((ret_value = H5I_register(H5I_GROUP, grp, TRUE)) < 0)
         HGOTO_ERROR(H5E_ATOM, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register group")
 
 done:
     /* Release the group's object header, if it was created */
-    if(grp) {
-        H5O_loc_t *oloc;         /* Object location for group */
+    if (grp) {
+        H5O_loc_t *oloc; /* Object location for group */
 
         /* Get the new group's object location */
-        if(NULL == (oloc = H5G_oloc(grp)))
+        if (NULL == (oloc = H5G_oloc(grp)))
             HDONE_ERROR(H5E_SYM, H5E_CANTGET, H5I_INVALID_HID, "unable to get object location of group")
 
         /* Decrement refcount on group's object header in memory */
-        if(H5O_dec_rc_by_loc(oloc) < 0)
-           HDONE_ERROR(H5E_SYM, H5E_CANTDEC, H5I_INVALID_HID, "unable to decrement refcount on newly created object")
+        if (H5O_dec_rc_by_loc(oloc) < 0)
+            HDONE_ERROR(H5E_SYM, H5E_CANTDEC, H5I_INVALID_HID,
+                        "unable to decrement refcount on newly created object")
     } /* end if */
 
     /* Cleanup on failure */
-    if(ret_value < 0)
-        if(grp && H5G_close(grp) < 0)
+    if (ret_value < 0)
+        if (grp && H5G_close(grp) < 0)
             HDONE_ERROR(H5E_SYM, H5E_CLOSEERROR, H5I_INVALID_HID, "unable to release group")
 
     FUNC_LEAVE_API(ret_value)
 } /* end H5Gcreate_anon() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Gopen2
  *
@@ -441,40 +422,39 @@ done:
 hid_t
 H5Gopen2(hid_t loc_id, const char *name, hid_t gapl_id)
 {
-    H5G_t       *grp = NULL;            /* Group opened */
-    H5G_loc_t	loc;                    /* Location of parent for group */
-    hid_t       ret_value;              /* Return value */
+    H5G_t    *grp = NULL; /* Group opened */
+    H5G_loc_t loc;        /* Location of parent for group */
+    hid_t     ret_value;  /* Return value */
 
     FUNC_ENTER_API(H5I_INVALID_HID)
     H5TRACE3("i", "i*si", loc_id, name, gapl_id);
 
     /* Check args */
-    if(H5G_loc(loc_id, &loc) < 0)
+    if (H5G_loc(loc_id, &loc) < 0)
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not a location")
-    if(!name || !*name)
+    if (!name || !*name)
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5I_INVALID_HID, "no name")
 
     /* Verify access property list and set up collective metadata if appropriate */
-    if(H5CX_set_apl(&gapl_id, H5P_CLS_GACC, loc_id, FALSE) < 0)
+    if (H5CX_set_apl(&gapl_id, H5P_CLS_GACC, loc_id, FALSE) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTSET, H5I_INVALID_HID, "can't set access property list info")
 
     /* Open the group */
-    if(NULL == (grp = H5G__open_name(&loc, name)))
+    if (NULL == (grp = H5G__open_name(&loc, name)))
         HGOTO_ERROR(H5E_SYM, H5E_CANTOPENOBJ, H5I_INVALID_HID, "unable to open group")
 
     /* Register an ID for the group */
-    if((ret_value = H5I_register(H5I_GROUP, grp, TRUE)) < 0)
+    if ((ret_value = H5I_register(H5I_GROUP, grp, TRUE)) < 0)
         HGOTO_ERROR(H5E_ATOM, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register group")
 
 done:
-    if(ret_value < 0)
-        if(grp && H5G_close(grp) < 0)
+    if (ret_value < 0)
+        if (grp && H5G_close(grp) < 0)
             HDONE_ERROR(H5E_SYM, H5E_CLOSEERROR, H5I_INVALID_HID, "unable to release group")
 
     FUNC_LEAVE_API(ret_value)
 } /* end H5Gopen2() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Gget_create_plist
  *
@@ -491,25 +471,24 @@ done:
 hid_t
 H5Gget_create_plist(hid_t group_id)
 {
-    H5G_t	*group = NULL;
-    hid_t	ret_value = H5I_INVALID_HID;        /* Return value */
+    H5G_t *group     = NULL;
+    hid_t  ret_value = H5I_INVALID_HID; /* Return value */
 
     FUNC_ENTER_API(H5I_INVALID_HID)
     H5TRACE1("i", "i", group_id);
 
     /* Check args */
-    if(NULL == (group = (H5G_t *)H5I_object_verify(group_id, H5I_GROUP)))
+    if (NULL == (group = (H5G_t *)H5I_object_verify(group_id, H5I_GROUP)))
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not a group")
 
     /* Retrieve the GCPL */
-    if((ret_value = H5G_get_create_plist(group)) < 0)
+    if ((ret_value = H5G_get_create_plist(group)) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTGET, H5I_INVALID_HID, "can't get group's creation property list")
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Gget_create_plist() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Gget_info
  *
@@ -522,33 +501,32 @@ done:
 herr_t
 H5Gget_info(hid_t grp_id, H5G_info_t *grp_info)
 {
-    H5I_type_t  id_type;                /* Type of ID */
-    H5G_loc_t	loc;                    /* Location of group */
-    herr_t      ret_value = SUCCEED;    /* Return value */
+    H5I_type_t id_type;             /* Type of ID */
+    H5G_loc_t  loc;                 /* Location of group */
+    herr_t     ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
     H5TRACE2("e", "i*x", grp_id, grp_info);
 
     /* Check args */
     id_type = H5I_get_type(grp_id);
-    if(!(H5I_GROUP == id_type || H5I_FILE == id_type))
+    if (!(H5I_GROUP == id_type || H5I_FILE == id_type))
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid argument")
-    if(!grp_info)
+    if (!grp_info)
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no info struct")
 
     /* Get group location */
-    if(H5G_loc(grp_id, &loc) < 0)
+    if (H5G_loc(grp_id, &loc) < 0)
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a location")
 
     /* Retrieve the group's information */
-    if(H5G__obj_info(loc.oloc, grp_info) < 0)
+    if (H5G__obj_info(loc.oloc, grp_info) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTGET, FAIL, "can't retrieve group info")
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Gget_info() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Gget_info_by_name
  *
@@ -560,36 +538,34 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5Gget_info_by_name(hid_t loc_id, const char *name, H5G_info_t *grp_info,
-    hid_t lapl_id)
+H5Gget_info_by_name(hid_t loc_id, const char *name, H5G_info_t *grp_info, hid_t lapl_id)
 {
-    H5G_loc_t	loc;                    /* Location of group */
-    herr_t      ret_value = SUCCEED;    /* Return value */
+    H5G_loc_t loc;                 /* Location of group */
+    herr_t    ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
     H5TRACE4("e", "i*s*xi", loc_id, name, grp_info, lapl_id);
 
     /* Check args */
-    if(H5G_loc(loc_id, &loc) < 0)
+    if (H5G_loc(loc_id, &loc) < 0)
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a location")
-    if(!name || !*name)
+    if (!name || !*name)
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no name")
-    if(!grp_info)
+    if (!grp_info)
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no info struct")
 
     /* Verify access property list and set up collective metadata if appropriate */
-    if(H5CX_set_apl(&lapl_id, H5P_CLS_LACC, loc_id, FALSE) < 0)
+    if (H5CX_set_apl(&lapl_id, H5P_CLS_LACC, loc_id, FALSE) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set access property list info")
 
     /* Retrieve the group's information */
-    if(H5G__get_info_by_name(&loc, name, grp_info/*out*/) < 0)
+    if (H5G__get_info_by_name(&loc, name, grp_info /*out*/) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTGET, FAIL, "can't retrieve group info")
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Gget_info_by_name() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Gget_info_by_idx
  *
@@ -601,41 +577,39 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5Gget_info_by_idx(hid_t loc_id, const char *group_name, H5_index_t idx_type,
-    H5_iter_order_t order, hsize_t n, H5G_info_t *grp_info, hid_t lapl_id)
+H5Gget_info_by_idx(hid_t loc_id, const char *group_name, H5_index_t idx_type, H5_iter_order_t order,
+                   hsize_t n, H5G_info_t *grp_info, hid_t lapl_id)
 {
-    H5G_loc_t	loc;                    /* Location of group */
-    herr_t      ret_value = SUCCEED;    /* Return value */
+    H5G_loc_t loc;                 /* Location of group */
+    herr_t    ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE7("e", "i*sIiIoh*xi", loc_id, group_name, idx_type, order, n, grp_info,
-             lapl_id);
+    H5TRACE7("e", "i*sIiIoh*xi", loc_id, group_name, idx_type, order, n, grp_info, lapl_id);
 
     /* Check args */
-    if(H5G_loc(loc_id, &loc) < 0)
+    if (H5G_loc(loc_id, &loc) < 0)
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a location")
-    if(!group_name || !*group_name)
-	HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no name specified")
-    if(idx_type <= H5_INDEX_UNKNOWN || idx_type >= H5_INDEX_N)
-	HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid index type specified")
-    if(order <= H5_ITER_UNKNOWN || order >= H5_ITER_N)
-	HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid iteration order specified")
-    if(!grp_info)
+    if (!group_name || !*group_name)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no name specified")
+    if (idx_type <= H5_INDEX_UNKNOWN || idx_type >= H5_INDEX_N)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid index type specified")
+    if (order <= H5_ITER_UNKNOWN || order >= H5_ITER_N)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid iteration order specified")
+    if (!grp_info)
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no info struct")
 
     /* Verify access property list and set up collective metadata if appropriate */
-    if(H5CX_set_apl(&lapl_id, H5P_CLS_LACC, loc_id, FALSE) < 0)
+    if (H5CX_set_apl(&lapl_id, H5P_CLS_LACC, loc_id, FALSE) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set access property list info")
 
     /* Retrieve the group's information */
-    if(H5G__get_info_by_idx(&loc, group_name, idx_type, order, n, grp_info/*out*/) < 0)
+    if (H5G__get_info_by_idx(&loc, group_name, idx_type, order, n, grp_info /*out*/) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTGET, FAIL, "can't retrieve group info")
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Gget_info_by_idx() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Gclose
  *
@@ -649,26 +623,25 @@ done:
 herr_t
 H5Gclose(hid_t group_id)
 {
-    herr_t  ret_value = SUCCEED;    /* Return value                     */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
     H5TRACE1("e", "i", group_id);
 
     /* Check args */
-    if(NULL == H5I_object_verify(group_id, H5I_GROUP))
+    if (NULL == H5I_object_verify(group_id, H5I_GROUP))
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group")
 
     /* Decrement the counter on the group atom. It will be freed if the count
      * reaches zero.
      */
-    if(H5I_dec_app_ref(group_id) < 0)
-    	HGOTO_ERROR(H5E_SYM, H5E_CANTRELEASE, FAIL, "unable to close group")
+    if (H5I_dec_app_ref(group_id) < 0)
+        HGOTO_ERROR(H5E_SYM, H5E_CANTRELEASE, FAIL, "unable to close group")
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Gclose() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Gflush
  *
@@ -691,22 +664,21 @@ H5Gflush(hid_t group_id)
     H5TRACE1("e", "i", group_id);
 
     /* Check args */
-    if(NULL == (grp = (H5G_t *)H5I_object_verify(group_id, H5I_GROUP)))
+    if (NULL == (grp = (H5G_t *)H5I_object_verify(group_id, H5I_GROUP)))
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group")
 
     /* Set up collective metadata if appropriate */
-    if(H5CX_set_loc(group_id) < 0)
+    if (H5CX_set_loc(group_id) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set collective metadata read info")
 
     /* Flush metadata to file */
-    if(H5O_flush_common(&grp->oloc, group_id) < 0)
+    if (H5O_flush_common(&grp->oloc, group_id) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTFLUSH, FAIL, "unable to flush group and object flush callback")
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* H5Gflush */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Grefresh
  *
@@ -729,18 +701,17 @@ H5Grefresh(hid_t group_id)
     H5TRACE1("e", "i", group_id);
 
     /* Check args */
-    if(NULL == (grp = (H5G_t *)H5I_object_verify(group_id, H5I_GROUP)))
+    if (NULL == (grp = (H5G_t *)H5I_object_verify(group_id, H5I_GROUP)))
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a group")
 
     /* Set up collective metadata if appropriate */
-    if(H5CX_set_loc(group_id) < 0)
+    if (H5CX_set_loc(group_id) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTSET, FAIL, "can't set collective metadata read info")
 
     /* Call private function to refresh group object */
-    if((H5O_refresh_metadata(group_id, grp->oloc)) < 0)
+    if ((H5O_refresh_metadata(group_id, grp->oloc)) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTLOAD, FAIL, "unable to refresh group")
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* H5Grefresh */
-
