@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -26,37 +25,32 @@
 /* Module Setup */
 /****************/
 
-#include "H5Gmodule.h"          /* This source code file is part of the H5G module */
-
+#include "H5Gmodule.h" /* This source code file is part of the H5G module */
 
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"		/* Generic Functions			*/
-#include "H5Eprivate.h"		/* Error handling		  	*/
-#include "H5Gpkg.h"		/* Groups		  		*/
-#include "H5HLprivate.h"	/* Local Heaps				*/
-#include "H5Iprivate.h"         /* IDs                                  */
-#include "H5Lprivate.h"		/* Links                                */
-#include "H5MMprivate.h"	/* Memory management			*/
-#include "H5Ppublic.h"		/* Property Lists                       */
-
+#include "H5private.h"   /* Generic Functions			*/
+#include "H5Eprivate.h"  /* Error handling		  	*/
+#include "H5Gpkg.h"      /* Groups		  		*/
+#include "H5HLprivate.h" /* Local Heaps				*/
+#include "H5Iprivate.h"  /* IDs                                  */
+#include "H5Lprivate.h"  /* Links                                */
+#include "H5MMprivate.h" /* Memory management			*/
+#include "H5Ppublic.h"   /* Property Lists                       */
 
 /****************/
 /* Local Macros */
 /****************/
 
-
 /******************/
 /* Local Typedefs */
 /******************/
 
-
 /********************/
 /* Package Typedefs */
 /********************/
 
-
 /********************/
 /* Local Prototypes */
 /********************/
@@ -66,23 +60,18 @@ static int H5G_link_cmp_name_dec(const void *lnk1, const void *lnk2);
 static int H5G_link_cmp_corder_inc(const void *lnk1, const void *lnk2);
 static int H5G_link_cmp_corder_dec(const void *lnk1, const void *lnk2);
 
-
 /*********************/
 /* Package Variables */
 /*********************/
 
-
 /*****************************/
 /* Library Private Variables */
 /*****************************/
 
-
 /*******************/
 /* Local Variables */
 /*******************/
 
-
-
 /*-------------------------------------------------------------------------
  * Function:	H5G_link_cmp_name_inc
  *
@@ -108,7 +97,6 @@ H5G_link_cmp_name_inc(const void *lnk1, const void *lnk2)
     FUNC_LEAVE_NOAPI(HDstrcmp(((const H5O_link_t *)lnk1)->name, ((const H5O_link_t *)lnk2)->name))
 } /* end H5G_link_cmp_name_inc() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5G_link_cmp_name_dec
  *
@@ -134,7 +122,6 @@ H5G_link_cmp_name_dec(const void *lnk1, const void *lnk2)
     FUNC_LEAVE_NOAPI(HDstrcmp(((const H5O_link_t *)lnk2)->name, ((const H5O_link_t *)lnk1)->name))
 } /* end H5G_link_cmp_name_dec() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5G_link_cmp_corder_inc
  *
@@ -154,13 +141,13 @@ H5G_link_cmp_name_dec(const void *lnk1, const void *lnk2)
 static int
 H5G_link_cmp_corder_inc(const void *lnk1, const void *lnk2)
 {
-    int ret_value = -1;         /* Return value */
+    int ret_value = -1; /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    if(((const H5O_link_t *)lnk1)->corder < ((const H5O_link_t *)lnk2)->corder)
+    if (((const H5O_link_t *)lnk1)->corder < ((const H5O_link_t *)lnk2)->corder)
         ret_value = -1;
-    else if(((const H5O_link_t *)lnk1)->corder > ((const H5O_link_t *)lnk2)->corder)
+    else if (((const H5O_link_t *)lnk1)->corder > ((const H5O_link_t *)lnk2)->corder)
         ret_value = 1;
     else
         ret_value = 0;
@@ -168,7 +155,6 @@ H5G_link_cmp_corder_inc(const void *lnk1, const void *lnk2)
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G_link_cmp_corder_inc() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5G_link_cmp_corder_dec
  *
@@ -188,13 +174,13 @@ H5G_link_cmp_corder_inc(const void *lnk1, const void *lnk2)
 static int
 H5G_link_cmp_corder_dec(const void *lnk1, const void *lnk2)
 {
-    int ret_value = -1;         /* Return value */
+    int ret_value = -1; /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    if(((const H5O_link_t *)lnk1)->corder < ((const H5O_link_t *)lnk2)->corder)
+    if (((const H5O_link_t *)lnk1)->corder < ((const H5O_link_t *)lnk2)->corder)
         ret_value = 1;
-    else if(((const H5O_link_t *)lnk1)->corder > ((const H5O_link_t *)lnk2)->corder)
+    else if (((const H5O_link_t *)lnk1)->corder > ((const H5O_link_t *)lnk2)->corder)
         ret_value = -1;
     else
         ret_value = 0;
@@ -202,7 +188,6 @@ H5G_link_cmp_corder_dec(const void *lnk1, const void *lnk2)
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G_link_cmp_corder_dec() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5G__ent_to_link
  *
@@ -216,11 +201,10 @@ H5G_link_cmp_corder_dec(const void *lnk1, const void *lnk2)
  *-------------------------------------------------------------------------
  */
 herr_t
-H5G__ent_to_link(H5O_link_t *lnk, const H5HL_t *heap,
-    const H5G_entry_t *ent, const char *name)
+H5G__ent_to_link(H5O_link_t *lnk, const H5HL_t *heap, const H5G_entry_t *ent, const char *name)
 {
-    hbool_t dup_soft = FALSE;           /* xstrdup the symbolic link name or not */
-    herr_t ret_value = SUCCEED;         /* Return value */
+    hbool_t dup_soft  = FALSE;   /* xstrdup the symbolic link name or not */
+    herr_t  ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE
 
@@ -231,21 +215,21 @@ H5G__ent_to_link(H5O_link_t *lnk, const H5HL_t *heap,
     HDassert(name);
 
     /* Set (default) common info for link */
-    lnk->cset = H5F_DEFAULT_CSET;
-    lnk->corder = 0;
-    lnk->corder_valid = FALSE;       /* Creation order not valid for this link */
-    if((lnk->name = H5MM_xstrdup(name)) == NULL)
+    lnk->cset         = H5F_DEFAULT_CSET;
+    lnk->corder       = 0;
+    lnk->corder_valid = FALSE; /* Creation order not valid for this link */
+    if ((lnk->name = H5MM_xstrdup(name)) == NULL)
         HGOTO_ERROR(H5E_LINK, H5E_CANTGET, FAIL, "unable to duplicate link name")
 
     /* Object is a symbolic or hard link */
-    if(ent->type == H5G_CACHED_SLINK) {
-        const char *s;          /* Pointer to link value */
+    if (ent->type == H5G_CACHED_SLINK) {
+        const char *s; /* Pointer to link value */
 
-        if((s = (const char *)H5HL_offset_into(heap, ent->cache.slink.lval_offset)) == NULL)
+        if ((s = (const char *)H5HL_offset_into(heap, ent->cache.slink.lval_offset)) == NULL)
             HGOTO_ERROR(H5E_LINK, H5E_CANTGET, FAIL, "unable to get symbolic link name")
 
         /* Copy the link value */
-        if((lnk->u.soft.name = H5MM_xstrdup(s)) == NULL)
+        if ((lnk->u.soft.name = H5MM_xstrdup(s)) == NULL)
             HGOTO_ERROR(H5E_LINK, H5E_CANTGET, FAIL, "unable to duplicate symbolic link name")
 
         dup_soft = TRUE;
@@ -262,16 +246,15 @@ H5G__ent_to_link(H5O_link_t *lnk, const H5HL_t *heap,
     } /* end else */
 
 done:
-    if(ret_value < 0) {
-        if(lnk->name)
+    if (ret_value < 0) {
+        if (lnk->name)
             H5MM_xfree(lnk->name);
-        if(ent->type == H5G_CACHED_SLINK && dup_soft)
+        if (ent->type == H5G_CACHED_SLINK && dup_soft)
             H5MM_xfree(lnk->u.soft.name);
     }
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G__ent_to_link() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5G_link_to_info
  *
@@ -287,7 +270,7 @@ done:
 herr_t
 H5G_link_to_info(const H5O_link_t *lnk, H5L_info_t *info)
 {
-    herr_t ret_value = SUCCEED;         /* Return value */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -295,13 +278,13 @@ H5G_link_to_info(const H5O_link_t *lnk, H5L_info_t *info)
     HDassert(lnk);
 
     /* Get information from the link */
-    if(info) {
-        info->cset = lnk->cset;
-        info->corder = lnk->corder;
+    if (info) {
+        info->cset         = lnk->cset;
+        info->corder       = lnk->corder;
         info->corder_valid = lnk->corder_valid;
-        info->type = lnk->type;
+        info->type         = lnk->type;
 
-        switch(lnk->type) {
+        switch (lnk->type) {
             case H5L_TYPE_HARD:
                 info->u.address = lnk->u.hard.addr;
                 break;
@@ -313,11 +296,10 @@ H5G_link_to_info(const H5O_link_t *lnk, H5L_info_t *info)
             case H5L_TYPE_ERROR:
             case H5L_TYPE_EXTERNAL:
             case H5L_TYPE_MAX:
-            default:
-            {
-                const H5L_class_t *link_class;      /* User-defined link class */
+            default: {
+                const H5L_class_t *link_class; /* User-defined link class */
 
-                if(lnk->type < H5L_TYPE_UD_MIN || lnk->type > H5L_TYPE_MAX)
+                if (lnk->type < H5L_TYPE_UD_MIN || lnk->type > H5L_TYPE_MAX)
                     HGOTO_ERROR(H5E_LINK, H5E_BADTYPE, FAIL, "unknown link class")
 
                 /* User-defined link; call its query function to get the link udata size. */
@@ -327,27 +309,29 @@ H5G_link_to_info(const H5O_link_t *lnk, H5L_info_t *info)
                  */
                 link_class = H5L_find_class(lnk->type);
 
-                if(link_class != NULL && link_class->query_func != NULL) {
-                    ssize_t cb_ret;             /* Return value from UD callback */
+                if (link_class != NULL && link_class->query_func != NULL) {
+                    ssize_t cb_ret; /* Return value from UD callback */
 
                     /* Call the link's query routine to retrieve the user-defined link's value size */
-                    /* (in case the query routine packs/unpacks the link value in some way that changes its size) */
-                    if((cb_ret = (link_class->query_func)(lnk->name, lnk->u.ud.udata, lnk->u.ud.size, NULL, (size_t)0)) < 0)
-                        HGOTO_ERROR(H5E_LINK, H5E_CALLBACK, FAIL, "query buffer size callback returned failure")
+                    /* (in case the query routine packs/unpacks the link value in some way that changes its
+                     * size) */
+                    if ((cb_ret = (link_class->query_func)(lnk->name, lnk->u.ud.udata, lnk->u.ud.size, NULL,
+                                                           (size_t)0)) < 0)
+                        HGOTO_ERROR(H5E_LINK, H5E_CALLBACK, FAIL,
+                                    "query buffer size callback returned failure")
 
                     info->u.val_size = (size_t)cb_ret;
                 } /* end if */
                 else
                     info->u.val_size = 0;
             } /* end case */
-        } /* end switch */
-    } /* end if */
+        }     /* end switch */
+    }         /* end if */
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G_link_to_info() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5G__link_to_loc
  *
@@ -361,10 +345,9 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5G__link_to_loc(const H5G_loc_t *grp_loc, const H5O_link_t *lnk,
-    H5G_loc_t *obj_loc)
+H5G__link_to_loc(const H5G_loc_t *grp_loc, const H5O_link_t *lnk, H5G_loc_t *obj_loc)
 {
-    herr_t ret_value = SUCCEED;         /* Return value */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE
 
@@ -378,24 +361,23 @@ H5G__link_to_loc(const H5G_loc_t *grp_loc, const H5O_link_t *lnk,
      */
 
     /* Check for unknown library-internal link */
-    if(lnk->type > H5L_TYPE_BUILTIN_MAX && lnk->type < H5L_TYPE_UD_MIN)
+    if (lnk->type > H5L_TYPE_BUILTIN_MAX && lnk->type < H5L_TYPE_UD_MIN)
         HGOTO_ERROR(H5E_SYM, H5E_UNSUPPORTED, FAIL, "unknown link type")
 
     /* Build object's group hier. location */
-    if(H5G_name_set(grp_loc->path, obj_loc->path, lnk->name) < 0)
+    if (H5G_name_set(grp_loc->path, obj_loc->path, lnk->name) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "cannot set name")
 
     /* Set the object location, if it's a hard link set the address also */
-    obj_loc->oloc->file = grp_loc->oloc->file;
+    obj_loc->oloc->file         = grp_loc->oloc->file;
     obj_loc->oloc->holding_file = FALSE;
-    if(lnk->type == H5L_TYPE_HARD)
+    if (lnk->type == H5L_TYPE_HARD)
         obj_loc->oloc->addr = lnk->u.hard.addr;
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G__link_to_loc() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5G__link_sort_table
  *
@@ -409,10 +391,9 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5G__link_sort_table(H5G_link_table_t *ltable, H5_index_t idx_type,
-    H5_iter_order_t order)
+H5G__link_sort_table(H5G_link_table_t *ltable, H5_index_t idx_type, H5_iter_order_t order)
 {
-    herr_t  ret_value = SUCCEED;
+    herr_t ret_value = SUCCEED;
 
     FUNC_ENTER_PACKAGE_NOERR
 
@@ -420,26 +401,26 @@ H5G__link_sort_table(H5G_link_table_t *ltable, H5_index_t idx_type,
     HDassert(ltable);
 
     /* Can't sort when empty since the links table will be NULL */
-    if(0 == ltable->nlinks)
+    if (0 == ltable->nlinks)
         HGOTO_DONE(ret_value);
 
     /* This should never be NULL if the number of links is non-zero */
     HDassert(ltable->lnks);
 
     /* Pick appropriate sorting routine */
-    if(idx_type == H5_INDEX_NAME) {
-        if(order == H5_ITER_INC)
+    if (idx_type == H5_INDEX_NAME) {
+        if (order == H5_ITER_INC)
             HDqsort(ltable->lnks, ltable->nlinks, sizeof(H5O_link_t), H5G_link_cmp_name_inc);
-        else if(order == H5_ITER_DEC)
+        else if (order == H5_ITER_DEC)
             HDqsort(ltable->lnks, ltable->nlinks, sizeof(H5O_link_t), H5G_link_cmp_name_dec);
         else
             HDassert(order == H5_ITER_NATIVE);
     } /* end if */
     else {
         HDassert(idx_type == H5_INDEX_CRT_ORDER);
-        if(order == H5_ITER_INC)
+        if (order == H5_ITER_INC)
             HDqsort(ltable->lnks, ltable->nlinks, sizeof(H5O_link_t), H5G_link_cmp_corder_inc);
-        else if(order == H5_ITER_DEC)
+        else if (order == H5_ITER_DEC)
             HDqsort(ltable->lnks, ltable->nlinks, sizeof(H5O_link_t), H5G_link_cmp_corder_dec);
         else
             HDassert(order == H5_ITER_NATIVE);
@@ -449,7 +430,6 @@ done:
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5G__link_sort_table() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5G__link_iterate_table
  *
@@ -465,11 +445,11 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5G__link_iterate_table(const H5G_link_table_t *ltable, hsize_t skip,
-    hsize_t *last_lnk, const H5G_lib_iterate_t op, void *op_data)
+H5G__link_iterate_table(const H5G_link_table_t *ltable, hsize_t skip, hsize_t *last_lnk,
+                        const H5G_lib_iterate_t op, void *op_data)
 {
-    size_t u;                           /* Local index variable */
-    herr_t ret_value = H5_ITER_CONT;   /* Return value */
+    size_t u;                        /* Local index variable */
+    herr_t ret_value = H5_ITER_CONT; /* Return value */
 
     FUNC_ENTER_PACKAGE_NOERR
 
@@ -478,28 +458,27 @@ H5G__link_iterate_table(const H5G_link_table_t *ltable, hsize_t skip,
     HDassert(op);
 
     /* Skip over links, if requested */
-    if(last_lnk)
+    if (last_lnk)
         *last_lnk += skip;
 
     /* Iterate over link messages */
     H5_CHECKED_ASSIGN(u, size_t, skip, hsize_t)
-    for(; u < ltable->nlinks && !ret_value; u++) {
+    for (; u < ltable->nlinks && !ret_value; u++) {
         /* Make the callback */
         ret_value = (op)(&(ltable->lnks[u]), op_data);
 
         /* Increment the number of entries passed through */
-        if(last_lnk)
+        if (last_lnk)
             (*last_lnk)++;
     } /* end for */
 
     /* Check for callback failure and pass along return value */
-    if(ret_value < 0)
+    if (ret_value < 0)
         HERROR(H5E_SYM, H5E_CANTNEXT, "iteration operator failed");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G__link_iterate_table() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5G__link_release_table
  *
@@ -516,8 +495,8 @@ H5G__link_iterate_table(const H5G_link_table_t *ltable, hsize_t skip,
 herr_t
 H5G__link_release_table(H5G_link_table_t *ltable)
 {
-    size_t      u;                      /* Local index variable */
-    herr_t	ret_value = SUCCEED;    /* Return value */
+    size_t u;                   /* Local index variable */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE
 
@@ -525,10 +504,10 @@ H5G__link_release_table(H5G_link_table_t *ltable)
     HDassert(ltable);
 
     /* Release link info, if any */
-    if(ltable->nlinks > 0) {
+    if (ltable->nlinks > 0) {
         /* Free link message information */
-        for(u = 0; u < ltable->nlinks; u++)
-            if(H5O_msg_reset(H5O_LINK_ID, &(ltable->lnks[u])) < 0)
+        for (u = 0; u < ltable->nlinks; u++)
+            if (H5O_msg_reset(H5O_LINK_ID, &(ltable->lnks[u])) < 0)
                 HGOTO_ERROR(H5E_SYM, H5E_CANTFREE, FAIL, "unable to release link message")
 
         /* Free table of links */
@@ -541,7 +520,6 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G__link_release_table() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5G__link_name_replace
  *
@@ -558,8 +536,8 @@ done:
 herr_t
 H5G__link_name_replace(H5F_t *file, H5RS_str_t *grp_full_path_r, const H5O_link_t *lnk)
 {
-    H5RS_str_t *obj_path_r = NULL;      /* Full path for link being removed */
-    herr_t ret_value = SUCCEED;         /* Return value */
+    H5RS_str_t *obj_path_r = NULL;    /* Full path for link being removed */
+    herr_t      ret_value  = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE
 
@@ -567,16 +545,15 @@ H5G__link_name_replace(H5F_t *file, H5RS_str_t *grp_full_path_r, const H5O_link_
     HDassert(file);
 
     /* Search the open IDs and replace names for unlinked object */
-    if(grp_full_path_r) {
+    if (grp_full_path_r) {
         obj_path_r = H5G_build_fullpath_refstr_str(grp_full_path_r, lnk->name);
-        if(H5G_name_replace(lnk, H5G_NAME_DELETE, file, obj_path_r, NULL, NULL) < 0)
+        if (H5G_name_replace(lnk, H5G_NAME_DELETE, file, obj_path_r, NULL, NULL) < 0)
             HGOTO_ERROR(H5E_SYM, H5E_CANTDELETE, FAIL, "unable to replace name")
     }
 
 done:
-    if(obj_path_r)
+    if (obj_path_r)
         H5RS_decr(obj_path_r);
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G__link_name_replace() */
-
