@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -22,72 +21,66 @@
  *-------------------------------------------------------------------------
  */
 
-#define H5A_FRIEND		/*suppress error about including H5Apkg	  */
-#include "H5Omodule.h"          /* This source code file is part of the H5O module */
-
-
-#include "H5private.h"		/* Generic Functions			*/
-#include "H5Apkg.h"             /* Attributes				*/
-#include "H5Eprivate.h"		/* Error handling		  	*/
-#include "H5FLprivate.h"	/* Free lists                           */
-#include "H5Opkg.h"             /* Object headers			*/
+#define H5A_FRIEND     /*suppress error about including H5Apkg	  */
+#include "H5Omodule.h" /* This source code file is part of the H5O module */
 
+#include "H5private.h"   /* Generic Functions			*/
+#include "H5Apkg.h"      /* Attributes				*/
+#include "H5Eprivate.h"  /* Error handling		  	*/
+#include "H5FLprivate.h" /* Free lists                           */
+#include "H5Opkg.h"      /* Object headers			*/
 
 /* PRIVATE PROTOTYPES */
-static void *H5O__ainfo_decode(H5F_t *f, H5O_t *open_oh, unsigned mesg_flags,
-    unsigned *ioflags, size_t p_size, const uint8_t *p);
+static void  *H5O__ainfo_decode(H5F_t *f, H5O_t *open_oh, unsigned mesg_flags, unsigned *ioflags,
+                                size_t p_size, const uint8_t *p);
 static herr_t H5O_ainfo_encode(H5F_t *f, hbool_t disable_shared, uint8_t *p, const void *_mesg);
-static void *H5O_ainfo_copy(const void *_mesg, void *_dest);
+static void  *H5O_ainfo_copy(const void *_mesg, void *_dest);
 static size_t H5O_ainfo_size(const H5F_t *f, hbool_t disable_shared, const void *_mesg);
 static herr_t H5O__ainfo_free(void *_mesg);
 static herr_t H5O__ainfo_delete(H5F_t *f, H5O_t *open_oh, void *_mesg);
-static herr_t H5O_ainfo_pre_copy_file(H5F_t *file_src, const void *mesg_src,
-    hbool_t *deleted, const H5O_copy_t *cpy_info, void *udata);
-static void *H5O__ainfo_copy_file(H5F_t *file_src, void *mesg_src,
-    H5F_t *file_dst, hbool_t *recompute_size, unsigned *mesg_flags,
-    H5O_copy_t *cpy_info, void *udata);
-static herr_t H5O__ainfo_post_copy_file(const H5O_loc_t *src_oloc,
-    const void *mesg_src, H5O_loc_t *dst_oloc, void *mesg_dst,
-    unsigned *mesg_flags, H5O_copy_t *cpy_info);
-static herr_t H5O__ainfo_debug(H5F_t *f, const void *_mesg, FILE * stream,
-    int indent, int fwidth);
+static herr_t H5O_ainfo_pre_copy_file(H5F_t *file_src, const void *mesg_src, hbool_t *deleted,
+                                      const H5O_copy_t *cpy_info, void *udata);
+static void  *H5O__ainfo_copy_file(H5F_t *file_src, void *mesg_src, H5F_t *file_dst, hbool_t *recompute_size,
+                                   unsigned *mesg_flags, H5O_copy_t *cpy_info, void *udata);
+static herr_t H5O__ainfo_post_copy_file(const H5O_loc_t *src_oloc, const void *mesg_src, H5O_loc_t *dst_oloc,
+                                        void *mesg_dst, unsigned *mesg_flags, H5O_copy_t *cpy_info);
+static herr_t H5O__ainfo_debug(H5F_t *f, const void *_mesg, FILE *stream, int indent, int fwidth);
 
 /* This message derives from H5O message class */
 const H5O_msg_class_t H5O_MSG_AINFO[1] = {{
-    H5O_AINFO_ID,            	/*message id number             */
-    "ainfo",                 	/*message name for debugging    */
-    sizeof(H5O_ainfo_t),     	/*native message size           */
-    0,				/* messages are sharable?       */
-    H5O__ainfo_decode,        	/*decode message                */
-    H5O_ainfo_encode,        	/*encode message                */
-    H5O_ainfo_copy,          	/*copy the native value         */
-    H5O_ainfo_size,          	/*size of symbol table entry    */
-    NULL,                   	/*default reset method          */
-    H5O__ainfo_free,	        /* free method			*/
-    H5O__ainfo_delete,	        /* file delete method		*/
-    NULL,			/* link method			*/
-    NULL,			/*set share method		*/
-    NULL,		    	/*can share method		*/
-    H5O_ainfo_pre_copy_file,	/* pre copy native value to file */
-    H5O__ainfo_copy_file,	/* copy native value to file    */
-    H5O__ainfo_post_copy_file,  /* post copy native value to file */
-    NULL,			/* get creation index		*/
-    NULL,			/* set creation index		*/
-    H5O__ainfo_debug          	/*debug the message             */
+    H5O_AINFO_ID,              /*message id number             */
+    "ainfo",                   /*message name for debugging    */
+    sizeof(H5O_ainfo_t),       /*native message size           */
+    0,                         /* messages are shareable?       */
+    H5O__ainfo_decode,         /*decode message                */
+    H5O_ainfo_encode,          /*encode message                */
+    H5O_ainfo_copy,            /*copy the native value         */
+    H5O_ainfo_size,            /*size of symbol table entry    */
+    NULL,                      /*default reset method          */
+    H5O__ainfo_free,           /* free method			*/
+    H5O__ainfo_delete,         /* file delete method		*/
+    NULL,                      /* link method			*/
+    NULL,                      /*set share method		*/
+    NULL,                      /*can share method		*/
+    H5O_ainfo_pre_copy_file,   /* pre copy native value to file */
+    H5O__ainfo_copy_file,      /* copy native value to file    */
+    H5O__ainfo_post_copy_file, /* post copy native value to file */
+    NULL,                      /* get creation index		*/
+    NULL,                      /* set creation index		*/
+    H5O__ainfo_debug           /*debug the message             */
 }};
 
 /* Current version of attribute info information */
-#define H5O_AINFO_VERSION 	0
+#define H5O_AINFO_VERSION 0
 
 /* Flags for attribute info flag encoding */
-#define H5O_AINFO_TRACK_CORDER          0x01
-#define H5O_AINFO_INDEX_CORDER          0x02
-#define H5O_AINFO_ALL_FLAGS             (H5O_AINFO_TRACK_CORDER | H5O_AINFO_INDEX_CORDER)
+#define H5O_AINFO_TRACK_CORDER 0x01
+#define H5O_AINFO_INDEX_CORDER 0x02
+#define H5O_AINFO_ALL_FLAGS    (H5O_AINFO_TRACK_CORDER | H5O_AINFO_INDEX_CORDER)
 
 /* Declare a free list to manage the H5O_ainfo_t struct */
 H5FL_DEFINE_STATIC(H5O_ainfo_t);
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5O__ainfo_decode
  *
@@ -102,13 +95,12 @@ H5FL_DEFINE_STATIC(H5O_ainfo_t);
  *-------------------------------------------------------------------------
  */
 static void *
-H5O__ainfo_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh,
-    unsigned H5_ATTR_UNUSED mesg_flags, unsigned H5_ATTR_UNUSED *ioflags,
-    size_t H5_ATTR_UNUSED p_size, const uint8_t *p)
+H5O__ainfo_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UNUSED mesg_flags,
+                  unsigned H5_ATTR_UNUSED *ioflags, size_t H5_ATTR_UNUSED p_size, const uint8_t *p)
 {
-    H5O_ainfo_t	*ainfo = NULL;  /* Attribute info */
-    unsigned char flags;        /* Flags for encoding attribute info */
-    void *ret_value = NULL;     /* Return value */
+    H5O_ainfo_t  *ainfo = NULL;     /* Attribute info */
+    unsigned char flags;            /* Flags for encoding attribute info */
+    void         *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_STATIC
 
@@ -117,16 +109,16 @@ H5O__ainfo_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh,
     HDassert(p);
 
     /* Version of message */
-    if(*p++ != H5O_AINFO_VERSION)
+    if (*p++ != H5O_AINFO_VERSION)
         HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad version number for message")
 
     /* Allocate space for message */
-    if(NULL == (ainfo = H5FL_MALLOC(H5O_ainfo_t)))
-	HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+    if (NULL == (ainfo = H5FL_MALLOC(H5O_ainfo_t)))
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
 
     /* Get the flags for the message */
     flags = *p++;
-    if(flags & ~H5O_AINFO_ALL_FLAGS)
+    if (flags & ~H5O_AINFO_ALL_FLAGS)
         HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, NULL, "bad flag value for message")
     ainfo->track_corder = (flags & H5O_AINFO_TRACK_CORDER) ? TRUE : FALSE;
     ainfo->index_corder = (flags & H5O_AINFO_INDEX_CORDER) ? TRUE : FALSE;
@@ -135,7 +127,7 @@ H5O__ainfo_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh,
     ainfo->nattrs = HSIZET_MAX;
 
     /* Max. creation order value for the object */
-    if(ainfo->track_corder)
+    if (ainfo->track_corder)
         UINT16DECODE(p, ainfo->max_crt_idx)
     else
         ainfo->max_crt_idx = H5O_MAX_CRT_ORDER_IDX;
@@ -147,7 +139,7 @@ H5O__ainfo_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh,
     H5F_addr_decode(f, &p, &(ainfo->name_bt2_addr));
 
     /* Address of v2 B-tree to index creation order of links, if there is one */
-    if(ainfo->index_corder)
+    if (ainfo->index_corder)
         H5F_addr_decode(f, &p, &(ainfo->corder_bt2_addr));
     else
         ainfo->corder_bt2_addr = HADDR_UNDEF;
@@ -156,13 +148,12 @@ H5O__ainfo_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh,
     ret_value = ainfo;
 
 done:
-    if(ret_value == NULL && ainfo != NULL)
+    if (ret_value == NULL && ainfo != NULL)
         ainfo = H5FL_FREE(H5O_ainfo_t, ainfo);
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O__ainfo_decode() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5O_ainfo_encode
  *
@@ -178,8 +169,8 @@ done:
 static herr_t
 H5O_ainfo_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, const void *_mesg)
 {
-    const H5O_ainfo_t   *ainfo = (const H5O_ainfo_t *)_mesg;
-    unsigned char       flags;          /* Flags for encoding attribute info */
+    const H5O_ainfo_t *ainfo = (const H5O_ainfo_t *)_mesg;
+    unsigned char      flags; /* Flags for encoding attribute info */
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
@@ -194,10 +185,10 @@ H5O_ainfo_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, co
     /* The flags for the attribute indices */
     flags = (unsigned char)(ainfo->track_corder ? H5O_AINFO_TRACK_CORDER : 0);
     flags = (unsigned char)(flags | (ainfo->index_corder ? H5O_AINFO_INDEX_CORDER : 0));
-    *p++ = flags;
+    *p++  = flags;
 
     /* Max. creation order value for the object */
-    if(ainfo->track_corder)
+    if (ainfo->track_corder)
         UINT16ENCODE(p, ainfo->max_crt_idx);
 
     /* Address of fractal heap to store "dense" attributes */
@@ -207,7 +198,7 @@ H5O_ainfo_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, co
     H5F_addr_encode(f, &p, ainfo->name_bt2_addr);
 
     /* Address of v2 B-tree to index creation order of attributes, if they are indexed */
-    if(ainfo->index_corder)
+    if (ainfo->index_corder)
         H5F_addr_encode(f, &p, ainfo->corder_bt2_addr);
     else
         HDassert(!H5F_addr_defined(ainfo->corder_bt2_addr));
@@ -215,7 +206,6 @@ H5O_ainfo_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, co
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5O_ainfo_encode() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5O_ainfo_copy
  *
@@ -233,16 +223,16 @@ H5O_ainfo_encode(H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, co
 static void *
 H5O_ainfo_copy(const void *_mesg, void *_dest)
 {
-    const H5O_ainfo_t   *ainfo = (const H5O_ainfo_t *)_mesg;
-    H5O_ainfo_t         *dest = (H5O_ainfo_t *) _dest;
-    void                *ret_value = NULL;     /* Return value */
+    const H5O_ainfo_t *ainfo     = (const H5O_ainfo_t *)_mesg;
+    H5O_ainfo_t       *dest      = (H5O_ainfo_t *)_dest;
+    void              *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT
 
     /* check args */
     HDassert(ainfo);
-    if(!dest && NULL == (dest = H5FL_MALLOC(H5O_ainfo_t)))
-	HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+    if (!dest && NULL == (dest = H5FL_MALLOC(H5O_ainfo_t)))
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
 
     /* copy */
     *dest = *ainfo;
@@ -254,7 +244,6 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_ainfo_copy() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5O_ainfo_size
  *
@@ -273,23 +262,25 @@ done:
 static size_t
 H5O_ainfo_size(const H5F_t *f, hbool_t H5_ATTR_UNUSED disable_shared, const void *_mesg)
 {
-    const H5O_ainfo_t   *ainfo = (const H5O_ainfo_t *)_mesg;
-    size_t ret_value = 0;       /* Return value */
+    const H5O_ainfo_t *ainfo     = (const H5O_ainfo_t *)_mesg;
+    size_t             ret_value = 0; /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Set return value */
-    ret_value = (size_t)(1                       /* Version */
-                + 1                     /* Index flags */
-                + (ainfo->track_corder ? 2 : 0) /* Curr. max. creation order value */
-                + H5F_SIZEOF_ADDR(f)    /* Address of fractal heap to store "dense" attributes */
-                + H5F_SIZEOF_ADDR(f)    /* Address of v2 B-tree for indexing names of attributes */
-                + (ainfo->index_corder ? H5F_SIZEOF_ADDR(f) : 0));   /* Address of v2 B-tree for indexing creation order values of attributes */
+    ret_value =
+        (size_t)(1                               /* Version */
+                 + 1                             /* Index flags */
+                 + (ainfo->track_corder ? 2 : 0) /* Curr. max. creation order value */
+                 + H5F_SIZEOF_ADDR(f)            /* Address of fractal heap to store "dense" attributes */
+                 + H5F_SIZEOF_ADDR(f)            /* Address of v2 B-tree for indexing names of attributes */
+                 + (ainfo->index_corder
+                        ? H5F_SIZEOF_ADDR(f)
+                        : 0)); /* Address of v2 B-tree for indexing creation order values of attributes */
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_ainfo_size() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5O__ainfo_free
  *
@@ -314,7 +305,6 @@ H5O__ainfo_free(void *mesg)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5O__ainfo_free() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5O__ainfo_delete
  *
@@ -332,8 +322,8 @@ H5O__ainfo_free(void *mesg)
 static herr_t
 H5O__ainfo_delete(H5F_t *f, H5O_t *open_oh, void *_mesg)
 {
-    H5O_ainfo_t *ainfo = (H5O_ainfo_t *)_mesg;
-    herr_t ret_value = SUCCEED;   /* Return value */
+    H5O_ainfo_t *ainfo     = (H5O_ainfo_t *)_mesg;
+    herr_t       ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_STATIC
 
@@ -343,16 +333,15 @@ H5O__ainfo_delete(H5F_t *f, H5O_t *open_oh, void *_mesg)
     HDassert(open_oh);
 
     /* If the object is using "dense" attribute storage, delete it */
-    if(H5F_addr_defined(ainfo->fheap_addr))
+    if (H5F_addr_defined(ainfo->fheap_addr))
         /* Delete the attribute */
-        if(H5A__dense_delete(f, ainfo) < 0)
+        if (H5A__dense_delete(f, ainfo) < 0)
             HGOTO_ERROR(H5E_OHDR, H5E_CANTFREE, FAIL, "unable to free dense attribute storage")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O__ainfo_delete() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5O_ainfo_pre_copy_file
  *
@@ -369,7 +358,7 @@ done:
  */
 static herr_t
 H5O_ainfo_pre_copy_file(H5F_t H5_ATTR_UNUSED *file_src, const void H5_ATTR_UNUSED *native_src,
-    hbool_t *deleted, const H5O_copy_t *cpy_info, void H5_ATTR_UNUSED *udata)
+                        hbool_t *deleted, const H5O_copy_t *cpy_info, void H5_ATTR_UNUSED *udata)
 {
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
@@ -380,13 +369,12 @@ H5O_ainfo_pre_copy_file(H5F_t H5_ATTR_UNUSED *file_src, const void H5_ATTR_UNUSE
     /* If we are not copying attributes into the destination file, indicate
      *  that this message should be deleted.
      */
-    if(cpy_info->copy_without_attr)
+    if (cpy_info->copy_without_attr)
         *deleted = TRUE;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5O_ainfo_pre_copy_file() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5O__ainfo_copy_file
  *
@@ -401,13 +389,12 @@ H5O_ainfo_pre_copy_file(H5F_t H5_ATTR_UNUSED *file_src, const void H5_ATTR_UNUSE
  *-------------------------------------------------------------------------
  */
 static void *
-H5O__ainfo_copy_file(H5F_t *file_src, void *mesg_src, H5F_t *file_dst,
-    hbool_t H5_ATTR_UNUSED *recompute_size, unsigned H5_ATTR_UNUSED *mesg_flags,
-    H5O_copy_t *cpy_info, void H5_ATTR_UNUSED *udata)
+H5O__ainfo_copy_file(H5F_t *file_src, void *mesg_src, H5F_t *file_dst, hbool_t H5_ATTR_UNUSED *recompute_size,
+                     unsigned H5_ATTR_UNUSED *mesg_flags, H5O_copy_t *cpy_info, void H5_ATTR_UNUSED *udata)
 {
     H5O_ainfo_t *ainfo_src = (H5O_ainfo_t *)mesg_src;
     H5O_ainfo_t *ainfo_dst = NULL;
-    void *ret_value = NULL;     /* Return value */
+    void        *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_STATIC
 
@@ -419,19 +406,19 @@ H5O__ainfo_copy_file(H5F_t *file_src, void *mesg_src, H5F_t *file_dst,
     HDassert(!cpy_info->copy_without_attr);
 
     /* Allocate space for the destination message */
-    if(NULL == (ainfo_dst = H5FL_MALLOC(H5O_ainfo_t)))
+    if (NULL == (ainfo_dst = H5FL_MALLOC(H5O_ainfo_t)))
         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
 
     /* Copy the top level of the information */
     *ainfo_dst = *ainfo_src;
 
-    if(H5F_addr_defined(ainfo_src->fheap_addr)) {
+    if (H5F_addr_defined(ainfo_src->fheap_addr)) {
         /* Prepare to copy dense attributes - actual copy in post_copy */
 
         /* Set copied metadata tag */
         H5_BEGIN_TAG(H5AC__COPIED_TAG);
 
-        if(H5A__dense_create(file_dst, ainfo_dst) < 0)
+        if (H5A__dense_create(file_dst, ainfo_dst) < 0)
             HGOTO_ERROR_TAG(H5E_OHDR, H5E_CANTINIT, NULL, "unable to create dense storage for attributes")
 
         /* Reset metadata tag */
@@ -443,13 +430,12 @@ H5O__ainfo_copy_file(H5F_t *file_src, void *mesg_src, H5F_t *file_dst,
 
 done:
     /* Release destination attribute information on failure */
-    if(!ret_value && ainfo_dst)
+    if (!ret_value && ainfo_dst)
         ainfo_dst = H5FL_FREE(H5O_ainfo_t, ainfo_dst);
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5O__ainfo_copy_file() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5O__ainfo_post_copy_file
  *
@@ -467,26 +453,25 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O__ainfo_post_copy_file(const H5O_loc_t *src_oloc, const void *mesg_src,
-    H5O_loc_t *dst_oloc, void *mesg_dst, unsigned H5_ATTR_UNUSED *mesg_flags,
-    H5O_copy_t *cpy_info)
+H5O__ainfo_post_copy_file(const H5O_loc_t *src_oloc, const void *mesg_src, H5O_loc_t *dst_oloc,
+                          void *mesg_dst, unsigned H5_ATTR_UNUSED *mesg_flags, H5O_copy_t *cpy_info)
 {
     const H5O_ainfo_t *ainfo_src = (const H5O_ainfo_t *)mesg_src;
-    herr_t ret_value = SUCCEED;   /* Return value */
+    herr_t             ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_STATIC
 
     HDassert(ainfo_src);
 
-    if(H5F_addr_defined(ainfo_src->fheap_addr))
-        if(H5A__dense_post_copy_file_all(src_oloc, ainfo_src, dst_oloc, (H5O_ainfo_t *)mesg_dst, cpy_info) < 0)
+    if (H5F_addr_defined(ainfo_src->fheap_addr))
+        if (H5A__dense_post_copy_file_all(src_oloc, ainfo_src, dst_oloc, (H5O_ainfo_t *)mesg_dst, cpy_info) <
+            0)
             HGOTO_ERROR(H5E_ATTR, H5E_CANTCOPY, FAIL, "can't copy attribute")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5O__ainfo_post_copy_file() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5O__ainfo_debug
  *
@@ -500,10 +485,9 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O__ainfo_debug(H5F_t H5_ATTR_UNUSED *f, const void *_mesg, FILE * stream,
-    int indent, int fwidth)
+H5O__ainfo_debug(H5F_t H5_ATTR_UNUSED *f, const void *_mesg, FILE *stream, int indent, int fwidth)
 {
-    const H5O_ainfo_t       *ainfo = (const H5O_ainfo_t *) _mesg;
+    const H5O_ainfo_t *ainfo = (const H5O_ainfo_t *)_mesg;
 
     FUNC_ENTER_STATIC_NOERR
 
@@ -514,22 +498,19 @@ H5O__ainfo_debug(H5F_t H5_ATTR_UNUSED *f, const void *_mesg, FILE * stream,
     HDassert(indent >= 0);
     HDassert(fwidth >= 0);
 
-    HDfprintf(stream, "%*s%-*s %Hu\n", indent, "", fwidth,
-	      "Number of attributes:", ainfo->nattrs);
-    HDfprintf(stream, "%*s%-*s %t\n", indent, "", fwidth,
-	      "Track creation order of attributes:", ainfo->track_corder);
-    HDfprintf(stream, "%*s%-*s %t\n", indent, "", fwidth,
-	      "Index creation order of attributes:", ainfo->index_corder);
+    HDfprintf(stream, "%*s%-*s %" PRIuHSIZE "\n", indent, "", fwidth, "Number of attributes:", ainfo->nattrs);
+    HDfprintf(stream, "%*s%-*s %s\n", indent, "", fwidth,
+              "Track creation order of attributes:", ainfo->track_corder ? "TRUE" : "FALSE");
+    HDfprintf(stream, "%*s%-*s %s\n", indent, "", fwidth,
+              "Index creation order of attributes:", ainfo->index_corder ? "TRUE" : "FALSE");
     HDfprintf(stream, "%*s%-*s %u\n", indent, "", fwidth,
-	      "Max. creation index value:", (unsigned)ainfo->max_crt_idx);
-    HDfprintf(stream, "%*s%-*s %a\n", indent, "", fwidth,
-	      "'Dense' attribute storage fractal heap address:", ainfo->fheap_addr);
-    HDfprintf(stream, "%*s%-*s %a\n", indent, "", fwidth,
-	      "'Dense' attribute storage name index v2 B-tree address:", ainfo->name_bt2_addr);
-    HDfprintf(stream, "%*s%-*s %a\n", indent, "", fwidth,
-	      "'Dense' attribute storage creation order index v2 B-tree address:", ainfo->corder_bt2_addr);
-
+              "Max. creation index value:", (unsigned)ainfo->max_crt_idx);
+    HDfprintf(stream, "%*s%-*s %" PRIuHADDR "\n", indent, "", fwidth,
+              "'Dense' attribute storage fractal heap address:", ainfo->fheap_addr);
+    HDfprintf(stream, "%*s%-*s %" PRIuHADDR "\n", indent, "", fwidth,
+              "'Dense' attribute storage name index v2 B-tree address:", ainfo->name_bt2_addr);
+    HDfprintf(stream, "%*s%-*s %" PRIuHADDR "\n", indent, "", fwidth,
+              "'Dense' attribute storage creation order index v2 B-tree address:", ainfo->corder_bt2_addr);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5O__ainfo_debug() */
-
