@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -36,11 +35,11 @@
 static void *H5O__stab_decode(H5F_t *f, H5O_t *open_oh, unsigned mesg_flags, unsigned *ioflags, size_t p_size,
                               const uint8_t *p);
 static herr_t H5O__stab_encode(H5F_t *f, hbool_t disable_shared, uint8_t *p, const void *_mesg);
-static void * H5O__stab_copy(const void *_mesg, void *_dest);
+static void  *H5O__stab_copy(const void *_mesg, void *_dest);
 static size_t H5O__stab_size(const H5F_t *f, hbool_t disable_shared, const void *_mesg);
 static herr_t H5O__stab_free(void *_mesg);
 static herr_t H5O__stab_delete(H5F_t *f, H5O_t *open_oh, void *_mesg);
-static void * H5O__stab_copy_file(H5F_t *file_src, void *native_src, H5F_t *file_dst, hbool_t *recompute_size,
+static void  *H5O__stab_copy_file(H5F_t *file_src, void *native_src, H5F_t *file_dst, hbool_t *recompute_size,
                                   unsigned *mesg_flags, H5O_copy_t *cpy_info, void *_udata);
 static herr_t H5O__stab_post_copy_file(const H5O_loc_t *src_oloc, const void *mesg_src, H5O_loc_t *dst_oloc,
                                        void *mesg_dst, unsigned *mesg_flags, H5O_copy_t *cpy_info);
@@ -51,7 +50,7 @@ const H5O_msg_class_t H5O_MSG_STAB[1] = {{
     H5O_STAB_ID,              /*message id number             */
     "stab",                   /*message name for debugging    */
     sizeof(H5O_stab_t),       /*native message size           */
-    0,                        /* messages are sharable?       */
+    0,                        /* messages are shareable?       */
     H5O__stab_decode,         /*decode message                */
     H5O__stab_encode,         /*encode message                */
     H5O__stab_copy,           /*copy the native value         */
@@ -93,7 +92,7 @@ H5O__stab_decode(H5F_t *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UNUSE
                  unsigned H5_ATTR_UNUSED *ioflags, size_t H5_ATTR_UNUSED p_size, const uint8_t *p)
 {
     H5O_stab_t *stab      = NULL;
-    void *      ret_value = NULL; /* Return value */
+    void       *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_STATIC
 
@@ -168,8 +167,8 @@ static void *
 H5O__stab_copy(const void *_mesg, void *_dest)
 {
     const H5O_stab_t *stab      = (const H5O_stab_t *)_mesg;
-    H5O_stab_t *      dest      = (H5O_stab_t *)_dest;
-    void *            ret_value = NULL; /* Return value */
+    H5O_stab_t       *dest      = (H5O_stab_t *)_dest;
+    void             *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_STATIC
 
@@ -291,11 +290,11 @@ H5O__stab_copy_file(H5F_t *file_src, void *native_src, H5F_t *file_dst,
                     hbool_t H5_ATTR_UNUSED *recompute_size, unsigned H5_ATTR_UNUSED *mesg_flags,
                     H5O_copy_t H5_ATTR_UNUSED *cpy_info, void *_udata)
 {
-    H5O_stab_t *        stab_src = (H5O_stab_t *)native_src;
-    H5O_stab_t *        stab_dst = NULL;
+    H5O_stab_t         *stab_src = (H5O_stab_t *)native_src;
+    H5O_stab_t         *stab_dst = NULL;
     H5G_copy_file_ud_t *udata    = (H5G_copy_file_ud_t *)_udata;
     size_t              size_hint;        /* Local heap initial size */
-    void *              ret_value = NULL; /* Return value */
+    void               *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_STATIC
 
@@ -354,7 +353,7 @@ H5O__stab_post_copy_file(const H5O_loc_t *src_oloc, const void *mesg_src, H5O_lo
                          unsigned H5_ATTR_UNUSED *mesg_flags, H5O_copy_t *cpy_info)
 {
     const H5O_stab_t *stab_src = (const H5O_stab_t *)mesg_src;
-    H5O_stab_t *      stab_dst = (H5O_stab_t *)mesg_dst;
+    H5O_stab_t       *stab_dst = (H5O_stab_t *)mesg_dst;
     H5G_bt_it_cpy_t   udata;               /* B-tree user data */
     herr_t            ret_value = SUCCEED; /* Return value */
 
