@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -17,8 +16,8 @@
  * conflicting requirement for the use of H5RC.
  */
 
-#ifndef _H5UCprivate_H
-#define _H5UCprivate_H
+#ifndef H5UCprivate_H
+#define H5UCprivate_H
 
 /**************************************/
 /* Public headers needed by this file */
@@ -41,24 +40,22 @@ typedef herr_t (*H5UC_free_func_t)(void *o);
 
 /* Typedef for reference counted objects */
 typedef struct H5UC_t {
-    void *o;            /* Object to be reference counted */
-    size_t n;           /* Reference count of number of pointers sharing object */
+    void            *o;         /* Object to be reference counted */
+    size_t           n;         /* Reference count of number of pointers sharing object */
     H5UC_free_func_t free_func; /* Function to free object */
 } H5UC_t;
 
 /**********/
 /* Macros */
 /**********/
-#define H5UC_INC(rc)            ((rc)->n++)
-#define H5UC_DEC(rc)            (H5UC_decr(rc))
-#define H5UC_GET_OBJ(rc)        ((rc)->o)
+#define H5UC_INC(rc)     ((rc)->n++)
+#define H5UC_DEC(rc)     (H5UC_decr(rc))
+#define H5UC_GET_OBJ(rc) ((rc)->o)
 
 /********************/
 /* Private routines */
 /********************/
 H5_DLL H5UC_t *H5UC_create(void *s, H5UC_free_func_t free_func);
-H5_DLL herr_t H5UC_decr(H5UC_t *rc);
-
-#endif /* _H5RSprivate_H */
-
+H5_DLL herr_t  H5UC_decr(H5UC_t *rc);
 
+#endif /* H5UCprivate_H */
