@@ -1,23 +1,22 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /***********************************************************
-*
-* Test program:     th5o
-*
-* Test public H5O functions for accessing
-*
-*************************************************************/
+ *
+ * Test program:     th5o
+ *
+ * Test public H5O functions for accessing
+ *
+ *************************************************************/
 
 #include "testhdf5.h"
 
@@ -30,7 +29,6 @@
 #define TEST6_DIM1 100
 #define TEST6_DIM2 100
 
-
 /****************************************************************
 **
 **  test_h5o_open(): Test H5Oopen function.
@@ -39,13 +37,13 @@
 static void
 test_h5o_open(void)
 {
-    hid_t       fid;                        /* HDF5 File ID      */
-    hid_t       grp, dset, dtype, dspace;   /* Object identifiers */
+    hid_t       fid;                      /* HDF5 File ID      */
+    hid_t       grp, dset, dtype, dspace; /* Object identifiers */
     hsize_t     dims[RANK];
-    H5I_type_t  id_type;                    /* Type of IDs returned from H5Oopen */
-    H5G_info_t  ginfo;                      /* Group info struct */
-    H5T_class_t type_class;                 /* Class of the datatype */
-    herr_t      ret;                        /* Value returned from API calls */
+    H5I_type_t  id_type;    /* Type of IDs returned from H5Oopen */
+    H5G_info_t  ginfo;      /* Group info struct */
+    H5T_class_t type_class; /* Class of the datatype */
+    herr_t      ret;        /* Value returned from API calls */
 
     /* Create a new HDF5 file */
     fid = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
@@ -69,7 +67,7 @@ test_h5o_open(void)
     /* Create the data space for the dataset. */
     dims[0] = DIM0;
     dims[1] = DIM1;
-    dspace = H5Screate_simple(RANK, dims, NULL);
+    dspace  = H5Screate_simple(RANK, dims, NULL);
     CHECK(dspace, FAIL, "H5Screate_simple");
 
     /* Create the dataset. */
@@ -119,28 +117,30 @@ test_h5o_open(void)
     CHECK(ret, FAIL, "H5Dclose");
 
     /* Trying to open objects with bogus names should fail gracefully */
-    H5E_BEGIN_TRY {
+    H5E_BEGIN_TRY
+    {
         grp = H5Oopen(fid, "bogus_group", H5P_DEFAULT);
         VERIFY(grp, FAIL, "H5Oopen");
         dtype = H5Oopen(fid, "group/bogus_datatype", H5P_DEFAULT);
         VERIFY(dtype, FAIL, "H5Oopen");
         dset = H5Oopen(fid, "/bogus_dataset", H5P_DEFAULT);
         VERIFY(dset, FAIL, "H5Oopen");
-    } H5E_END_TRY
+    }
+    H5E_END_TRY
 
     /* Close the file */
     ret = H5Fclose(fid);
     CHECK(ret, FAIL, "H5Fclose");
 
     /* Trying to open an object with a bogus file ID should fail */
-    H5E_BEGIN_TRY {
+    H5E_BEGIN_TRY
+    {
         dset = H5Oopen(fid, "dataset", H5P_DEFAULT);
         VERIFY(dset, FAIL, "H5Oopen");
-    } H5E_END_TRY
+    }
+    H5E_END_TRY
 } /* test_h5o_open() */
 
-
-
 /****************************************************************
 **
 **  test_h5o_close(): Test H5Oclose function.
@@ -149,10 +149,10 @@ test_h5o_open(void)
 static void
 test_h5o_close(void)
 {
-    hid_t       fid;                        /* HDF5 File ID      */
-    hid_t       grp, dset, dtype, dspace;   /* Object identifiers */
-    hsize_t     dims[RANK];
-    herr_t      ret;                        /* Value returned from API calls */
+    hid_t   fid;                      /* HDF5 File ID      */
+    hid_t   grp, dset, dtype, dspace; /* Object identifiers */
+    hsize_t dims[RANK];
+    herr_t  ret; /* Value returned from API calls */
 
     /* Create a new HDF5 file */
     fid = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
@@ -177,7 +177,7 @@ test_h5o_close(void)
     /* Create the data space for the dataset. */
     dims[0] = DIM0;
     dims[1] = DIM1;
-    dspace = H5Screate_simple(RANK, dims, NULL);
+    dspace  = H5Screate_simple(RANK, dims, NULL);
     CHECK(dspace, FAIL, "H5Screate_simple");
 
     /* Create the dataset. */
@@ -187,10 +187,12 @@ test_h5o_close(void)
     CHECK(ret, FAIL, "H5Oclose");
 
     /* Attempting to close the data space with H5Oclose should fail */
-    H5E_BEGIN_TRY {
-       ret = H5Oclose(dspace);
-       VERIFY(ret, FAIL, "H5Oclose");
-    } H5E_END_TRY
+    H5E_BEGIN_TRY
+    {
+        ret = H5Oclose(dspace);
+        VERIFY(ret, FAIL, "H5Oclose");
+    }
+    H5E_END_TRY
     /* Close the dataspace for real */
     ret = H5Sclose(dspace);
     CHECK(ret, FAIL, "H5Sclose");
@@ -230,7 +232,6 @@ test_h5o_close(void)
     CHECK(ret, FAIL, "H5Fclose");
 }
 
-
 /****************************************************************
 **
 **  test_h5o_open_by_addr(): Test H5Oopen_by_addr function.
@@ -239,17 +240,17 @@ test_h5o_close(void)
 static void
 test_h5o_open_by_addr(void)
 {
-    hid_t       fid;                        /* HDF5 File ID      */
-    hid_t       grp, dset, dtype, dspace;   /* Object identifiers */
-    H5L_info_t li;                      /* Buffer for H5Lget_info */
-    haddr_t grp_addr;                       /* Addresses for objects */
-    haddr_t dset_addr;
-    haddr_t dtype_addr;
+    hid_t       fid;                      /* HDF5 File ID      */
+    hid_t       grp, dset, dtype, dspace; /* Object identifiers */
+    H5L_info_t  li;                       /* Buffer for H5Lget_info */
+    haddr_t     grp_addr;                 /* Addresses for objects */
+    haddr_t     dset_addr;
+    haddr_t     dtype_addr;
     hsize_t     dims[RANK];
-    H5I_type_t  id_type;                    /* Type of IDs returned from H5Oopen */
-    H5G_info_t  ginfo;                      /* Group info struct */
-    H5T_class_t type_class;                 /* Class of the datatype */
-    herr_t      ret;                        /* Value returned from API calls */
+    H5I_type_t  id_type;    /* Type of IDs returned from H5Oopen */
+    H5G_info_t  ginfo;      /* Group info struct */
+    H5T_class_t type_class; /* Class of the datatype */
+    herr_t      ret;        /* Value returned from API calls */
 
     /* Create a new HDF5 file */
     fid = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
@@ -273,7 +274,7 @@ test_h5o_open_by_addr(void)
     /* Create the data space for the dataset. */
     dims[0] = DIM0;
     dims[1] = DIM1;
-    dspace = H5Screate_simple(RANK, dims, NULL);
+    dspace  = H5Screate_simple(RANK, dims, NULL);
     CHECK(dspace, FAIL, "H5Screate_simple");
 
     /* Create the dataset. */
@@ -288,10 +289,10 @@ test_h5o_open_by_addr(void)
     ret = H5Lget_info(fid, "group", &li, H5P_DEFAULT);
     CHECK(ret, FAIL, "H5Lget_info");
     grp_addr = li.u.address;
-    ret = H5Lget_info(fid, "group/datatype", &li, H5P_DEFAULT);
+    ret      = H5Lget_info(fid, "group/datatype", &li, H5P_DEFAULT);
     CHECK(ret, FAIL, "H5Lget_info");
     dtype_addr = li.u.address;
-    ret = H5Lget_info(fid, "dataset", &li, H5P_DEFAULT);
+    ret        = H5Lget_info(fid, "dataset", &li, H5P_DEFAULT);
     CHECK(ret, FAIL, "H5Lget_info");
     dset_addr = li.u.address;
 
@@ -336,38 +337,45 @@ test_h5o_open_by_addr(void)
     /* Try giving some bogus values to H5O_open_by_addr. */
     /* Try to open an object with a bad address */
     grp_addr += 20;
-    H5E_BEGIN_TRY{
-      grp = H5Oopen_by_addr(fid, grp_addr);
-    }H5E_END_TRY
+    H5E_BEGIN_TRY
+    {
+        grp = H5Oopen_by_addr(fid, grp_addr);
+    }
+    H5E_END_TRY
     VERIFY(grp, FAIL, "H5Oopen_by_addr");
 
     /* For instance, an objectno smaller than the end of the file's superblock should
      * trigger an error */
     grp_addr = 10;
-    H5E_BEGIN_TRY{
-      grp = H5Oopen_by_addr(fid, grp_addr);
-    }H5E_END_TRY
+    H5E_BEGIN_TRY
+    {
+        grp = H5Oopen_by_addr(fid, grp_addr);
+    }
+    H5E_END_TRY
     VERIFY(grp, FAIL, "H5Oopen_by_addr");
 
     /* Likewise, an objectno larger than the size of the file should fail */
     grp_addr = 0;
     grp_addr = 1000000000;
-    H5E_BEGIN_TRY{
-      grp = H5Oopen_by_addr(fid, grp_addr);
-    }H5E_END_TRY
+    H5E_BEGIN_TRY
+    {
+        grp = H5Oopen_by_addr(fid, grp_addr);
+    }
+    H5E_END_TRY
     VERIFY(grp, FAIL, "H5Oopen_by_addr");
 
     ret = H5Fclose(fid);
     CHECK(ret, FAIL, "H5Fclose");
 
     /* Also, trying to open an object without a valid location should fail */
-    H5E_BEGIN_TRY{
-      dtype = H5Oopen_by_addr(fid, dtype_addr);
-    }H5E_END_TRY
+    H5E_BEGIN_TRY
+    {
+        dtype = H5Oopen_by_addr(fid, dtype_addr);
+    }
+    H5E_END_TRY
     VERIFY(dtype, FAIL, "H5Oopen_by_addr");
 } /* test_h5o_open_by_addr() */
 
-
 /****************************************************************
 **
 **  test_h5o_refcount(): Test H5O refcounting functions.
@@ -376,11 +384,11 @@ test_h5o_open_by_addr(void)
 static void
 test_h5o_refcount(void)
 {
-    hid_t       fid;                        /* HDF5 File ID      */
-    hid_t       grp, dset, dtype, dspace;   /* Object identifiers */
-    H5O_info_t  oinfo;                      /* Object info struct */
-    hsize_t     dims[RANK];
-    herr_t      ret;                        /* Value returned from API calls */
+    hid_t      fid;                      /* HDF5 File ID      */
+    hid_t      grp, dset, dtype, dspace; /* Object identifiers */
+    H5O_info_t oinfo;                    /* Object info struct */
+    hsize_t    dims[RANK];
+    herr_t     ret; /* Value returned from API calls */
 
     /* Create a new HDF5 file */
     fid = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
@@ -400,7 +408,7 @@ test_h5o_refcount(void)
     /* Create the data space for the dataset. */
     dims[0] = DIM0;
     dims[1] = DIM1;
-    dspace = H5Screate_simple(RANK, dims, NULL);
+    dspace  = H5Screate_simple(RANK, dims, NULL);
     CHECK(dspace, FAIL, "H5Screate_simple");
 
     /* Create the dataset. */
@@ -457,7 +465,7 @@ test_h5o_refcount(void)
     CHECK(ret, FAIL, "H5Oget_info_by_name");
     VERIFY(oinfo.rc, 1, "reference count in H5Oget_info_by_name");
 
-    /* Increment the reference counts and then close the file to make sure the increment is permanant */
+    /* Increment the reference counts and then close the file to make sure the increment is permanent */
     ret = H5Oincr_refcount(grp);
     CHECK(ret, FAIL, "H5Oincr_refcount");
     ret = H5Oincr_refcount(dtype);
@@ -542,7 +550,8 @@ test_h5o_refcount(void)
     CHECK(ret, FAIL, "H5Dclose");
 
     /* Make sure that bogus IDs return errors properly */
-    H5E_BEGIN_TRY {
+    H5E_BEGIN_TRY
+    {
         ret = H5Oincr_refcount(grp);
         VERIFY(ret, FAIL, "H5Oincr_refcount");
         ret = H5Oincr_refcount(dtype);
@@ -555,14 +564,14 @@ test_h5o_refcount(void)
         VERIFY(ret, FAIL, "H5Odecr_refcount");
         ret = H5Odecr_refcount(dset);
         VERIFY(ret, FAIL, "H5Odecr_refcount");
-    } H5E_END_TRY
+    }
+    H5E_END_TRY
 
     /* Close the file */
     ret = H5Fclose(fid);
     CHECK(ret, FAIL, "H5Fclose");
 } /* test_h5o_refcount() */
 
-
 /****************************************************************
 **
 **  test_h5o_plist(): Test object creation properties
@@ -571,13 +580,13 @@ test_h5o_refcount(void)
 static void
 test_h5o_plist(void)
 {
-    hid_t       fid;                        /* HDF5 File ID      */
-    hid_t       grp, dset, dtype, dspace;   /* Object identifiers */
-    hid_t       fapl;                       /* File access property list */
-    hid_t       gcpl, dcpl, tcpl;           /* Object creation properties */
-    unsigned    def_max_compact, def_min_dense; /* Default phase change parameters */
-    unsigned    max_compact, min_dense;         /* Actual phase change parameters */
-    herr_t      ret;                        /* Value returned from API calls */
+    hid_t    fid;                            /* HDF5 File ID      */
+    hid_t    grp, dset, dtype, dspace;       /* Object identifiers */
+    hid_t    fapl;                           /* File access property list */
+    hid_t    gcpl, dcpl, tcpl;               /* Object creation properties */
+    unsigned def_max_compact, def_min_dense; /* Default phase change parameters */
+    unsigned max_compact, min_dense;         /* Actual phase change parameters */
+    herr_t   ret;                            /* Value returned from API calls */
 
     /* Make a FAPL that uses the "use the latest version of the format" flag */
     fapl = H5Pcreate(H5P_FILE_ACCESS);
@@ -756,7 +765,6 @@ test_h5o_plist(void)
     CHECK(ret, FAIL, "H5Pclose");
 } /* test_h5o_plist() */
 
-
 /****************************************************************
 **
 **  test_h5o_link(): Test creating link to object
@@ -765,20 +773,20 @@ test_h5o_plist(void)
 static void
 test_h5o_link(void)
 {
-    hid_t file_id=-1;
-    hid_t group_id=-1;
-    hid_t space_id=-1;
-    hid_t dset_id=-1;
-    hid_t type_id=-1;
-    hid_t fapl_id=-1;
-    hid_t lcpl_id=-1;
-    hsize_t dims[2] = {TEST6_DIM1, TEST6_DIM2};
-    htri_t committed;           /* Whether the named datatype is committed */
+    hid_t        file_id  = -1;
+    hid_t        group_id = -1;
+    hid_t        space_id = -1;
+    hid_t        dset_id  = -1;
+    hid_t        type_id  = -1;
+    hid_t        fapl_id  = -1;
+    hid_t        lcpl_id  = -1;
+    hsize_t      dims[2]  = {TEST6_DIM1, TEST6_DIM2};
+    htri_t       committed; /* Whether the named datatype is committed */
     H5F_libver_t low, high; /* File format bounds */
-    int *wdata;
-    int *rdata;
-    int i, n;
-    herr_t ret;                 /* Value returned from API calls */
+    int         *wdata;
+    int         *rdata;
+    int          i, n;
+    herr_t       ret; /* Value returned from API calls */
 
     /* Allocate memory buffers */
     /* (These are treated as 2-D buffers) */
@@ -788,11 +796,11 @@ test_h5o_link(void)
     CHECK_PTR(rdata, "HDmalloc");
 
     /* Initialize the raw data */
-    for(i = n = 0; i < (TEST6_DIM1 * TEST6_DIM2); i++)
-      wdata[i] = n++;
+    for (i = n = 0; i < (TEST6_DIM1 * TEST6_DIM2); i++)
+        wdata[i] = n++;
 
     /* Create the dataspace */
-    space_id = H5Screate_simple(2 ,dims, NULL);
+    space_id = H5Screate_simple(2, dims, NULL);
     CHECK(space_id, FAIL, "H5Screate_simple");
 
     /* Create LCPL with intermediate group creation flag set */
@@ -806,13 +814,15 @@ test_h5o_link(void)
     CHECK(fapl_id, FAIL, "H5Pcreate");
 
     /* Loop through all the combinations of low/high library format bounds */
-    for(low = H5F_LIBVER_EARLIEST; low < H5F_LIBVER_NBOUNDS; low++) {
-        for(high = H5F_LIBVER_EARLIEST; high < H5F_LIBVER_NBOUNDS; high++) {
+    for (low = H5F_LIBVER_EARLIEST; low < H5F_LIBVER_NBOUNDS; low++) {
+        for (high = H5F_LIBVER_EARLIEST; high < H5F_LIBVER_NBOUNDS; high++) {
 
             /* Set version bounds */
-            H5E_BEGIN_TRY {
+            H5E_BEGIN_TRY
+            {
                 ret = H5Pset_libver_bounds(fapl_id, low, high);
-            } H5E_END_TRY;
+            }
+            H5E_END_TRY;
 
             if (ret < 0) /* Invalid low/high combinations */
                 continue;
@@ -848,7 +858,7 @@ test_h5o_link(void)
             CHECK(ret, FAIL, "H5Dread");
 
             /* Verify the data */
-            for(i = 0; i < (TEST6_DIM1 * TEST6_DIM2); i++)
+            for (i = 0; i < (TEST6_DIM1 * TEST6_DIM2); i++)
                 VERIFY(wdata[i], rdata[i], "H5Dread");
 
             /* Create a group with no name*/
@@ -886,7 +896,7 @@ test_h5o_link(void)
             /* Read data from dataset */
             ret = H5Dread(dset_id, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, rdata);
             CHECK(ret, FAIL, "H5Dread");
-            for(i = 0; i < (TEST6_DIM1 * TEST6_DIM2); i++)
+            for (i = 0; i < (TEST6_DIM1 * TEST6_DIM2); i++)
                 VERIFY(wdata[i], rdata[i], "H5Dread");
 
             /* Close open IDs */
@@ -897,7 +907,7 @@ test_h5o_link(void)
             ret = H5Fclose(file_id);
             CHECK(ret, FAIL, "H5Fclose");
         } /* for high */
-    } /* for low */
+    }     /* for low */
 
     /* Close remaining IDs */
     ret = H5Sclose(space_id);
@@ -910,7 +920,6 @@ test_h5o_link(void)
     HDfree(rdata);
 } /* end test_h5o_link() */
 
-
 /****************************************************************
 **
 **  test_h5o_comment(): Test H5Oset(get)_comment functions.
@@ -919,20 +928,20 @@ test_h5o_link(void)
 static void
 test_h5o_comment(void)
 {
-    hid_t       fid;                        /* HDF5 File ID      */
-    hid_t       grp, dset, dtype, dspace;   /* Object identifiers */
+    hid_t       fid;                      /* HDF5 File ID      */
+    hid_t       grp, dset, dtype, dspace; /* Object identifiers */
     hid_t       attr_space, attr_id;
     hsize_t     dims[RANK];
-    hsize_t     attr_dims = 1;
-    int         attr_value = 5;
-    const char  *file_comment = "file comment";
-    const char  *grp_comment = "group comment";
-    const char  *dset_comment = "dataset comment";
-    const char  *dtype_comment = "datatype comment";
+    hsize_t     attr_dims     = 1;
+    int         attr_value    = 5;
+    const char *file_comment  = "file comment";
+    const char *grp_comment   = "group comment";
+    const char *dset_comment  = "dataset comment";
+    const char *dtype_comment = "datatype comment";
     char        check_comment[64];
     ssize_t     comment_len = 0;
     ssize_t     len;
-    herr_t      ret;                        /* Value returned from API calls */
+    herr_t      ret; /* Value returned from API calls */
     int         ret_value;
 
     /* Create a new HDF5 file */
@@ -985,7 +994,7 @@ test_h5o_comment(void)
     /* Create the data space for the dataset. */
     dims[0] = DIM0;
     dims[1] = DIM1;
-    dspace = H5Screate_simple(RANK, dims, NULL);
+    dspace  = H5Screate_simple(RANK, dims, NULL);
     CHECK(dspace, FAIL, "H5Screate_simple");
 
     /* Create the dataset. */
@@ -997,9 +1006,11 @@ test_h5o_comment(void)
     CHECK(ret, FAIL, "H5Oset_comment");
 
     /* Putting a comment on the dataspace.  It's supposed to fail. */
-    H5E_BEGIN_TRY {
+    H5E_BEGIN_TRY
+    {
         ret = H5Oset_comment(dspace, "dataspace comment");
-    } H5E_END_TRY;
+    }
+    H5E_END_TRY;
     VERIFY(ret, FAIL, "H5Oset_comment");
 
     /* Close the file */
@@ -1010,7 +1021,6 @@ test_h5o_comment(void)
     ret = H5Fclose(fid);
     CHECK(ret, FAIL, "H5Fclose");
 
-
     /* Now make sure that the comments are correct all 4 types of objects */
     /* Open file */
     fid = H5Fopen(TEST_FILENAME, H5F_ACC_RDONLY, H5P_DEFAULT);
@@ -1020,7 +1030,7 @@ test_h5o_comment(void)
     comment_len = H5Oget_comment(fid, NULL, (size_t)0);
     CHECK(comment_len, FAIL, "H5Oget_comment");
 
-    len = H5Oget_comment(fid, check_comment, (size_t)comment_len+1);
+    len = H5Oget_comment(fid, check_comment, (size_t)comment_len + 1);
     CHECK(len, FAIL, "H5Oget_comment");
 
     ret_value = HDstrcmp(file_comment, check_comment);
@@ -1034,7 +1044,7 @@ test_h5o_comment(void)
     comment_len = H5Oget_comment(grp, NULL, (size_t)0);
     CHECK(comment_len, FAIL, "H5Oget_comment");
 
-    len = H5Oget_comment(grp, check_comment, (size_t)comment_len+1);
+    len = H5Oget_comment(grp, check_comment, (size_t)comment_len + 1);
     CHECK(len, FAIL, "H5Oget_comment");
 
     ret_value = HDstrcmp(grp_comment, check_comment);
@@ -1048,7 +1058,7 @@ test_h5o_comment(void)
     comment_len = H5Oget_comment(dtype, NULL, (size_t)0);
     CHECK(comment_len, FAIL, "H5Oget_comment");
 
-    len = H5Oget_comment(dtype, check_comment, (size_t)comment_len+1);
+    len = H5Oget_comment(dtype, check_comment, (size_t)comment_len + 1);
     CHECK(len, FAIL, "H5Oget_comment");
 
     ret_value = HDstrcmp(dtype_comment, check_comment);
@@ -1062,13 +1072,12 @@ test_h5o_comment(void)
     comment_len = H5Oget_comment(dset, NULL, (size_t)0);
     CHECK(comment_len, FAIL, "H5Oget_comment");
 
-    len = H5Oget_comment(dset, check_comment, (size_t)comment_len+1);
+    len = H5Oget_comment(dset, check_comment, (size_t)comment_len + 1);
     CHECK(ret, len, "H5Oget_comment");
 
     ret_value = HDstrcmp(dset_comment, check_comment);
     VERIFY(ret_value, 0, "H5Oget_comment");
 
-
     /* Close the IDs */
     ret = H5Gclose(grp);
     CHECK(ret, FAIL, "H5Gclose");
@@ -1083,7 +1092,6 @@ test_h5o_comment(void)
 
 } /* test_h5o_comment() */
 
-
 /****************************************************************
 **
 **  test_h5o_comment_by_name(): Test H5Oset(get)_comment_by_name functions.
@@ -1092,20 +1100,20 @@ test_h5o_comment(void)
 static void
 test_h5o_comment_by_name(void)
 {
-    hid_t       fid;                        /* HDF5 File ID      */
-    hid_t       grp, dset, dtype, dspace;   /* Object identifiers */
+    hid_t       fid;                      /* HDF5 File ID      */
+    hid_t       grp, dset, dtype, dspace; /* Object identifiers */
     hid_t       attr_space, attr_id;
     hsize_t     dims[RANK];
-    hsize_t     attr_dims = 1;
-    int         attr_value = 5;
-    const char  *file_comment = "file comment by name";
-    const char  *grp_comment = "group comment by name";
-    const char  *dset_comment = "dataset comment by name";
-    const char  *dtype_comment = "datatype comment by name";
+    hsize_t     attr_dims     = 1;
+    int         attr_value    = 5;
+    const char *file_comment  = "file comment by name";
+    const char *grp_comment   = "group comment by name";
+    const char *dset_comment  = "dataset comment by name";
+    const char *dtype_comment = "datatype comment by name";
     char        check_comment[64];
     ssize_t     comment_len = 0;
     ssize_t     len;
-    herr_t      ret;                        /* Value returned from API calls */
+    herr_t      ret; /* Value returned from API calls */
     int         ret_value;
 
     /* Create a new HDF5 file */
@@ -1158,7 +1166,7 @@ test_h5o_comment_by_name(void)
     /* Create the data space for the dataset. */
     dims[0] = DIM0;
     dims[1] = DIM1;
-    dspace = H5Screate_simple(RANK, dims, NULL);
+    dspace  = H5Screate_simple(RANK, dims, NULL);
     CHECK(dspace, FAIL, "H5Screate_simple");
 
     /* Create the dataset. */
@@ -1170,9 +1178,11 @@ test_h5o_comment_by_name(void)
     CHECK(ret, FAIL, "H5Oset_comment_by_name");
 
     /* Putting a comment on the dataspace.  It's supposed to fail. */
-    H5E_BEGIN_TRY {
+    H5E_BEGIN_TRY
+    {
         ret = H5Oset_comment_by_name(dspace, ".", "dataspace comment", H5P_DEFAULT);
-    } H5E_END_TRY;
+    }
+    H5E_END_TRY;
     VERIFY(ret, FAIL, "H5Oset_comment");
 
     /* Close the file */
@@ -1192,7 +1202,7 @@ test_h5o_comment_by_name(void)
     comment_len = H5Oget_comment_by_name(fid, ".", NULL, (size_t)0, H5P_DEFAULT);
     CHECK(comment_len, FAIL, "H5Oget_comment_by_name");
 
-    len = H5Oget_comment_by_name(fid, ".", check_comment, (size_t)comment_len+1, H5P_DEFAULT);
+    len = H5Oget_comment_by_name(fid, ".", check_comment, (size_t)comment_len + 1, H5P_DEFAULT);
     CHECK(len, FAIL, "H5Oget_comment_by_name");
 
     ret_value = HDstrcmp(file_comment, check_comment);
@@ -1206,7 +1216,7 @@ test_h5o_comment_by_name(void)
     comment_len = H5Oget_comment_by_name(fid, "group", NULL, (size_t)0, H5P_DEFAULT);
     CHECK(comment_len, FAIL, "H5Oget_comment_by_name");
 
-    len = H5Oget_comment_by_name(fid, "group", check_comment, (size_t)comment_len+1, H5P_DEFAULT);
+    len = H5Oget_comment_by_name(fid, "group", check_comment, (size_t)comment_len + 1, H5P_DEFAULT);
     CHECK(len, FAIL, "H5Oget_comment_by_name");
 
     ret_value = HDstrcmp(grp_comment, check_comment);
@@ -1216,7 +1226,7 @@ test_h5o_comment_by_name(void)
     comment_len = H5Oget_comment_by_name(grp, "datatype", NULL, (size_t)0, H5P_DEFAULT);
     CHECK(comment_len, FAIL, "H5Oget_comment_by_name");
 
-    len = H5Oget_comment_by_name(grp, "datatype", check_comment, (size_t)comment_len+1, H5P_DEFAULT);
+    len = H5Oget_comment_by_name(grp, "datatype", check_comment, (size_t)comment_len + 1, H5P_DEFAULT);
     CHECK(len, FAIL, "H5Oget_comment");
 
     ret_value = HDstrcmp(dtype_comment, check_comment);
@@ -1226,7 +1236,7 @@ test_h5o_comment_by_name(void)
     comment_len = H5Oget_comment_by_name(fid, "dataset", NULL, (size_t)0, H5P_DEFAULT);
     CHECK(comment_len, FAIL, "H5Oget_comment_by_name");
 
-    len = H5Oget_comment_by_name(fid, "dataset", check_comment, (size_t)comment_len+1, H5P_DEFAULT);
+    len = H5Oget_comment_by_name(fid, "dataset", check_comment, (size_t)comment_len + 1, H5P_DEFAULT);
     CHECK(len, FAIL, "H5Oget_comment_by_name");
 
     ret_value = HDstrcmp(dset_comment, check_comment);
@@ -1242,7 +1252,6 @@ test_h5o_comment_by_name(void)
 
 } /* test_h5o_comment_by_name() */
 
-
 /****************************************************************
 **
 **  test_h5o_getinfo_same_file():  Test that querying the object info for
@@ -1252,10 +1261,10 @@ test_h5o_comment_by_name(void)
 static void
 test_h5o_getinfo_same_file(void)
 {
-    hid_t       fid1, fid2;             /* HDF5 File ID */
-    hid_t       gid1, gid2;             /* Group IDs */
-    H5O_info_t  oinfo1, oinfo2;         /* Object info structs */
-    herr_t      ret;                    /* Value returned from API calls */
+    hid_t      fid1, fid2;     /* HDF5 File ID */
+    hid_t      gid1, gid2;     /* Group IDs */
+    H5O_info_t oinfo1, oinfo2; /* Object info structs */
+    herr_t     ret;            /* Value returned from API calls */
 
     /* Create a new HDF5 file */
     fid1 = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
@@ -1299,7 +1308,6 @@ test_h5o_getinfo_same_file(void)
     ret = H5Fclose(fid1);
     CHECK(ret, FAIL, "H5Fclose");
 
-
     /* Open file twice */
     fid1 = H5Fopen(TEST_FILENAME, H5F_ACC_RDWR, H5P_DEFAULT);
     CHECK(fid1, FAIL, "H5Fopen");
@@ -1360,29 +1368,31 @@ test_h5o_getinfo_same_file(void)
 **
 ****************************************************************/
 static int
-visit_obj_cb(hid_t group_id, const char *name, const H5O_info_t *oinfo1,
-    void H5_ATTR_UNUSED *_op_data)
+visit_obj_cb(hid_t group_id, const char *name, const H5O_info_t *oinfo1, void H5_ATTR_UNUSED *_op_data)
 {
-    H5O_info_t oinfo2;  /* Object info structs */
+    H5O_info_t oinfo2; /* Object info structs */
 
     /* Verify the object info for "group1", "group2" and the root group */
-    if(!(HDstrcmp(name, "group1"))) {
+    if (!(HDstrcmp(name, "group1"))) {
         H5Oget_info_by_name2(group_id, name, &oinfo2, H5O_INFO_NUM_ATTRS, H5P_DEFAULT);
         VERIFY(oinfo1->num_attrs, oinfo2.num_attrs, "obj info from H5Ovisit");
-    } else if(!(HDstrcmp(name, "group2"))) {
+    }
+    else if (!(HDstrcmp(name, "group2"))) {
         H5Oget_info_by_name2(group_id, name, &oinfo2, H5O_INFO_HDR, H5P_DEFAULT);
         VERIFY(oinfo1->hdr.nmesgs, oinfo2.hdr.nmesgs, "obj info from H5Ovisit/H5Oget_info2");
         VERIFY(oinfo1->hdr.nchunks, oinfo2.hdr.nchunks, "obj info from H5Ovisit/H5Oget_info2");
-    } else if(!(HDstrcmp(name, "."))) {
+    }
+    else if (!(HDstrcmp(name, "."))) {
         H5Oget_info_by_name2(group_id, name, &oinfo2, H5O_INFO_META_SIZE, H5P_DEFAULT);
-        VERIFY(oinfo1->meta_size.obj.index_size, oinfo2.meta_size.obj.index_size, "obj info from H5Ovisit/H5Oget_info2");
-        VERIFY(oinfo1->meta_size.obj.heap_size, oinfo2.meta_size.obj.heap_size, "obj info from H5Ovisit/H5Oget_info2");
+        VERIFY(oinfo1->meta_size.obj.index_size, oinfo2.meta_size.obj.index_size,
+               "obj info from H5Ovisit/H5Oget_info2");
+        VERIFY(oinfo1->meta_size.obj.heap_size, oinfo2.meta_size.obj.heap_size,
+               "obj info from H5Ovisit/H5Oget_info2");
     }
 
-    return(H5_ITER_CONT);
+    return (H5_ITER_CONT);
 } /* end visit_obj_cb() */
 
-
 /****************************************************************
 **
 **  test_h5o_getinfo_visit():
@@ -1395,14 +1405,14 @@ visit_obj_cb(hid_t group_id, const char *name, const H5O_info_t *oinfo1,
 static void
 test_h5o_getinfo_visit(void)
 {
-    hid_t fid = -1;             /* HDF5 File ID */
-    hid_t gid1 = -1, gid2 = -1; /* Group IDs */
-    hid_t sid = -1;             /* Dataspace ID */
-    hid_t aid = -1;             /* Attribute ID */
-    H5O_info_t oinfo1, oinfo2;  /* Object info structs */
-    char attrname[25];          /* Attribute name */
-    int j;                      /* Local index variable */
-    herr_t ret;                 /* Value returned from API calls */
+    hid_t      fid  = -1;            /* HDF5 File ID */
+    hid_t      gid1 = -1, gid2 = -1; /* Group IDs */
+    hid_t      sid = -1;             /* Dataspace ID */
+    hid_t      aid = -1;             /* Attribute ID */
+    H5O_info_t oinfo1, oinfo2;       /* Object info structs */
+    char       attrname[25];         /* Attribute name */
+    int        j;                    /* Local index variable */
+    herr_t     ret;                  /* Value returned from API calls */
 
     /* Create an HDF5 file */
     fid = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
@@ -1417,7 +1427,7 @@ test_h5o_getinfo_visit(void)
     CHECK(sid, FAIL, "H5Screate");
 
     /* Attach 10 attributes to "group1" */
-    for(j = 0; j <10; j++) {
+    for (j = 0; j < 10; j++) {
         /* Create the attribute name */
         HDsprintf(attrname, "attr%u", j);
         /* Create the attribute */
@@ -1439,7 +1449,7 @@ test_h5o_getinfo_visit(void)
     /* Query the object info for "group1" via H5Oget_info and H5Oget_info2 */
     ret = H5Oget_info(gid1, &oinfo1);
     CHECK(ret, FAIL, "H5Oget_info");
-    ret = H5Oget_info2(gid1, &oinfo2, H5O_INFO_BASIC|H5O_INFO_NUM_ATTRS);
+    ret = H5Oget_info2(gid1, &oinfo2, H5O_INFO_BASIC | H5O_INFO_NUM_ATTRS);
     CHECK(ret, FAIL, "H5Oget_info");
 
     /* Verify the object info for "group1" is correct */
@@ -1453,14 +1463,16 @@ test_h5o_getinfo_visit(void)
     /* Query the object info for "group2" via H5Oget_info_by_name and H5Oget_info_by_name2 */
     ret = H5Oget_info_by_name(fid, "group2", &oinfo1, H5P_DEFAULT);
     CHECK(ret, FAIL, "H5Oget_info_by_name");
-    ret = H5Oget_info_by_name2(fid, "group2", &oinfo2, H5O_INFO_HDR|H5O_INFO_META_SIZE, H5P_DEFAULT);
+    ret = H5Oget_info_by_name2(fid, "group2", &oinfo2, H5O_INFO_HDR | H5O_INFO_META_SIZE, H5P_DEFAULT);
     CHECK(ret, FAIL, "H5Oget_info_by_name");
 
     /* Verify the object info for "group2" is correct */
     VERIFY(oinfo1.hdr.nmesgs, oinfo2.hdr.nmesgs, "obj info from H5Oget_info_by_name/2");
     VERIFY(oinfo1.hdr.nchunks, oinfo2.hdr.nchunks, "obj info from H5Oget_info_by_name/2");
-    VERIFY(oinfo1.meta_size.obj.index_size, oinfo2.meta_size.obj.index_size, "obj info from H5Oget_info_by_name/2");
-    VERIFY(oinfo1.meta_size.obj.heap_size, oinfo2.meta_size.obj.heap_size, "obj info from H5Oget_info_by_name/2");
+    VERIFY(oinfo1.meta_size.obj.index_size, oinfo2.meta_size.obj.index_size,
+           "obj info from H5Oget_info_by_name/2");
+    VERIFY(oinfo1.meta_size.obj.heap_size, oinfo2.meta_size.obj.heap_size,
+           "obj info from H5Oget_info_by_name/2");
 
     /* Close everything */
     ret = H5Gclose(gid1);
@@ -1479,7 +1491,6 @@ test_h5o_getinfo_visit(void)
 
 #endif /* H5_NO_DEPRECATED_SYMBOLS */
 
-
 /****************************************************************
 **
 **  test_h5o(): Main H5O (generic object) testing routine.
@@ -1501,11 +1512,10 @@ test_h5o(void)
     test_h5o_comment_by_name();   /* Test routines for comment by name */
     test_h5o_getinfo_same_file(); /* Test info for objects in the same file */
 #ifndef H5_NO_DEPRECATED_SYMBOLS
-    test_h5o_getinfo_visit();     /* Test object info for H5Oget_info/2 and H5Ovisit */
-#endif
+    test_h5o_getinfo_visit(); /* Test object info for H5Oget_info/2 and H5Ovisit */
+#endif                        /* H5_NO_DEPRECATED_SYMBOLS */
 } /* test_h5o() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    cleanup_h5o
  *
@@ -1523,4 +1533,3 @@ cleanup_h5o(void)
 {
     remove(TEST_FILENAME);
 }
-
