@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -32,9 +31,8 @@
 /* ANY new test needs to have a prototype in ttsafe.h */
 #include "ttsafe.h"
 
-
 #define MAX_NUM_NAME 1000
-#define NAME_OFFSET 6         /* offset for "name<num>" */
+#define NAME_OFFSET  6 /* offset for "name<num>" */
 
 /* pre-condition: num must be a non-negative number */
 H5_ATTR_PURE static unsigned
@@ -42,10 +40,10 @@ num_digits(int num)
 {
     unsigned u;
 
-    if(num == 0)
+    if (num == 0)
         return 1;
 
-    for(u = 0; num > 0; u++)
+    for (u = 0; num > 0; u++)
         num = num / 10;
 
     return u;
@@ -59,43 +57,43 @@ tts_is_threadsafe(void)
     hbool_t should_be;
 
 #ifdef H5_HAVE_THREADSAFE
-    is_ts = FALSE;
+    is_ts     = FALSE;
     should_be = TRUE;
-#else /* H5_HAVE_THREADSAFE */
-    is_ts = TRUE;
+#else  /* H5_HAVE_THREADSAFE */
+    is_ts     = TRUE;
     should_be = FALSE;
 #endif /* H5_HAVE_THREADSAFE */
 
-    if(H5is_library_threadsafe(&is_ts) != SUCCEED)
-            TestErrPrintf("H5_is_library_threadsafe() call failed - test failed\n");
+    if (H5is_library_threadsafe(&is_ts) != SUCCEED)
+        TestErrPrintf("H5_is_library_threadsafe() call failed - test failed\n");
 
-    if(is_ts != should_be)
-            TestErrPrintf("Thread-safety value incorrect - test failed\n");
-
-    return;
+    if (is_ts != should_be)
+        TestErrPrintf("Thread-safety value incorrect - test failed\n");
 }
 
 /* Routine to generate attribute names for numeric values */
-char *gen_name(int value)
+char *
+gen_name(int value)
 {
-    char *temp;
+    char    *temp;
     unsigned length;
-    int i;
+    int      i;
 
-    length = num_digits(MAX_NUM_NAME - 1);
-    temp = (char *)HDmalloc(NAME_OFFSET + length + 1);
-    temp = HDstrcpy(temp, "attrib");
+    length                     = num_digits(MAX_NUM_NAME - 1);
+    temp                       = (char *)HDmalloc(NAME_OFFSET + length + 1);
+    temp                       = HDstrcpy(temp, "attrib");
     temp[NAME_OFFSET + length] = '\0';
 
     for (i = (int)(length - 1); i >= 0; i--) {
         temp[NAME_OFFSET + i] = (char)((int)'0' + value % 10);
-        value = value / 10;
+        value                 = value / 10;
     }
 
     return temp;
 }
 
-int main(int argc, char *argv[])
+int
+main(int argc, char *argv[])
 {
 
     /* Initialize testing framework */
@@ -123,7 +121,7 @@ int main(int argc, char *argv[])
     TestInfo(argv[0]);
 
     /* Parse command line arguments */
-    TestParseCmdLine(argc,argv);
+    TestParseCmdLine(argc, argv);
 
     /* Perform requested testing */
     PerformTests();
@@ -133,7 +131,7 @@ int main(int argc, char *argv[])
         TestSummary();
 
     /* Clean up test files, if allowed */
-    if (GetTestCleanup() && !getenv("HDF5_NOCLEANUP"))
+    if (GetTestCleanup() && !HDgetenv("HDF5_NOCLEANUP"))
         TestCleanup();
 
     /* Release test infrastructure */
@@ -142,4 +140,3 @@ int main(int argc, char *argv[])
     return GetTestNumErrs();
 
 } /* end main() */
-
