@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -17,7 +16,6 @@
 #include "h5tools.h"
 #include "h5tools_utils.h"
 
-
 /*-------------------------------------------------------------------------
  * Function: main
  *
@@ -34,7 +32,7 @@
  *
  * Modifications: July 2004
  *  Introduced the four modes:
- *   Normal mode: print the number of differences found and where they occured
+ *   Normal mode: print the number of differences found and where they occurred
  *   Report mode: print the above plus the differences
  *   Verbose mode: print the above plus a list of objects and warnings
  *   Quiet mode: do not print output
@@ -65,17 +63,17 @@
  *-------------------------------------------------------------------------
  */
 
-
-int main(int argc, const char *argv[])
+int
+main(int argc, char *argv[])
 {
-    int        ret;
-    int        i;
-    const char *fname1 = NULL;
-    const char *fname2 = NULL;
-    const char *objname1  = NULL;
-    const char *objname2  = NULL;
-    hsize_t    nfound=0;
-    diff_opt_t opts;
+    int         ret;
+    int         i;
+    const char *fname1   = NULL;
+    const char *fname2   = NULL;
+    const char *objname1 = NULL;
+    const char *objname2 = NULL;
+    hsize_t     nfound   = 0;
+    diff_opt_t  opts;
 
     h5tools_setprogname(PROGRAMNAME);
     h5tools_setstatus(EXIT_SUCCESS);
@@ -84,28 +82,28 @@ int main(int argc, const char *argv[])
     h5tools_init();
 
     /*-------------------------------------------------------------------------
-    * process the command-line
-    *-------------------------------------------------------------------------
-    */
-    parse_command_line(argc, argv, &fname1, &fname2, &objname1, &objname2, &opts);
+     * process the command-line
+     *-------------------------------------------------------------------------
+     */
+    parse_command_line(argc, (const char *const *)argv, &fname1, &fname2, &objname1, &objname2, &opts);
 
     /* enable error reporting if command line option */
     h5tools_error_report();
 
     /*-------------------------------------------------------------------------
-    * do the diff
-    *-------------------------------------------------------------------------
-    */
+     * do the diff
+     *-------------------------------------------------------------------------
+     */
 
     nfound = h5diff(fname1, fname2, objname1, objname2, &opts);
 
     print_info(&opts);
 
-   /*-------------------------------------------------------------------------
-    * exit code
-    *   1 if differences, 0 if no differences, 2 if error
-    *-------------------------------------------------------------------------
-    */
+    /*-------------------------------------------------------------------------
+     * exit code
+     *   1 if differences, 0 if no differences, 2 if error
+     *-------------------------------------------------------------------------
+     */
 
     ret = (nfound == 0 ? 0 : 1);
 
@@ -120,17 +118,17 @@ int main(int argc, const char *argv[])
     /* free any buffers */
     for (i = 0; i < 2; i++) {
         if (opts.sset[i]) {
-            if(opts.sset[i]->start.data)
+            if (opts.sset[i]->start.data)
                 HDfree(opts.sset[i]->start.data);
-            if(opts.sset[i]->stride.data)
+            if (opts.sset[i]->stride.data)
                 HDfree(opts.sset[i]->stride.data);
-            if(opts.sset[i]->count.data)
+            if (opts.sset[i]->count.data)
                 HDfree(opts.sset[i]->count.data);
-            if(opts.sset[i]->block.data)
+            if (opts.sset[i]->block.data)
                 HDfree(opts.sset[i]->block.data);
 
             HDfree(opts.sset[i]);
-            opts.sset[i]=NULL;
+            opts.sset[i] = NULL;
         }
     }
 
@@ -160,4 +158,3 @@ h5diff_exit(int status)
 
     HDexit(status);
 }
-
