@@ -88,8 +88,8 @@ struct mirror_session {
     int                      sockfd;
     uint32_t                 token;
     uint32_t                 xmit_count;
-    H5FD_t *                 file;
-    loginfo_t *              loginfo;
+    H5FD_t                  *file;
+    loginfo_t               *loginfo;
     H5FD_mirror_xmit_reply_t reply;
 };
 
@@ -127,7 +127,7 @@ struct sock_comm {
     uint32_t            magic;
     int                 recd_die;
     H5FD_mirror_xmit_t *xmit_recd;
-    char *              raw;
+    char               *raw;
     size_t              raw_size;
 };
 
@@ -151,7 +151,7 @@ struct sock_comm {
  */
 struct mirror_writer_opts {
     uint32_t magic;
-    char *   logpath;
+    char    *logpath;
 };
 
 static void mybzero(void *dest, size_t size);
@@ -171,7 +171,7 @@ static void
 mybzero(void *dest, size_t size)
 {
     size_t i = 0;
-    char * s = NULL;
+    char  *s = NULL;
     HDassert(dest);
     s = (char *)dest;
     for (i = 0; i < size; i++) {
@@ -289,9 +289,9 @@ session_stop(struct mirror_session *session)
 static struct mirror_session *
 session_start(int socketfd, const H5FD_mirror_xmit_open_t *xmit_open)
 {
-    struct mirror_session *   session = NULL;
+    struct mirror_session    *session = NULL;
     struct mirror_writer_opts opts;
-#if 0 /* TODO: behaviro option */
+#if 0 /* TODO: behavior option */
     char logpath[H5FD_MIRROR_XMIT_FILEPATH_MAX] = "";
 #endif
 
@@ -731,7 +731,7 @@ do_write(struct mirror_session *session, const unsigned char *xmit_buf)
     haddr_t                  addr              = 0;
     haddr_t                  sum_bytes_written = 0;
     H5FD_mem_t               type              = 0;
-    char *                   buf               = NULL;
+    char                    *buf               = NULL;
     ssize_t                  nbytes_in_packet  = 0;
     H5FD_mirror_xmit_write_t xmit_write;
 
@@ -788,8 +788,7 @@ do_write(struct mirror_session *session, const unsigned char *xmit_buf)
      */
     sum_bytes_written = 0;
     do {
-        nbytes_in_packet = HDread(session->sockfd, buf, H5FD_MIRROR_DATA_BUFFER_MAX);
-        if (-1 == nbytes_in_packet) {
+        if ((nbytes_in_packet = HDread(session->sockfd, buf, H5FD_MIRROR_DATA_BUFFER_MAX)) < 0) {
             mirror_log(session->loginfo, V_ERR, "can't read into databuffer");
             reply_error(session, "can't read data buffer");
             return -1;
@@ -798,7 +797,7 @@ do_write(struct mirror_session *session, const unsigned char *xmit_buf)
         mirror_log(session->loginfo, V_INFO, "received %zd bytes", nbytes_in_packet);
         if (HEXDUMP_WRITEDATA) {
             mirror_log(session->loginfo, V_ALL, "DATA:\n```");
-            mirror_log_bytes(session->loginfo, V_ALL, nbytes_in_packet, (const unsigned char *)buf);
+            mirror_log_bytes(session->loginfo, V_ALL, (size_t)nbytes_in_packet, (const unsigned char *)buf);
             mirror_log(session->loginfo, V_ALL, "```");
         }
 
@@ -859,8 +858,7 @@ receive_communique(struct mirror_session *session, struct sock_comm *comm)
 
     mirror_log(session->loginfo, V_INFO, "ready to receive"); /* TODO */
 
-    read_ret = HDread(session->sockfd, comm->raw, H5FD_MIRROR_XMIT_BUFFER_MAX);
-    if (-1 == read_ret) {
+    if ((read_ret = HDread(session->sockfd, comm->raw, H5FD_MIRROR_XMIT_BUFFER_MAX)) < 0) {
         mirror_log(session->loginfo, V_ERR, "read:%zd", read_ret);
         goto error;
     }
@@ -931,25 +929,33 @@ static int
 process_instructions(struct mirror_session *session)
 {
     struct sock_comm   comm;
-    char               xmit_buf[H5FD_MIRROR_XMIT_BUFFER_MAX]; /* raw bytes */
-    H5FD_mirror_xmit_t xmit_recd;                             /* for decoded xmit header */
+    char              *xmit_buf = NULL; /* raw bytes */
+    size_t             buf_size;
+    H5FD_mirror_xmit_t xmit_recd; /* for decoded xmit header */
 
     HDassert(session && (session->magic == MW_SESSION_MAGIC));
 
     mirror_log(session->loginfo, V_INFO, "process_instructions()");
 
+    buf_size = H5FD_MIRROR_XMIT_BUFFER_MAX * sizeof(char);
+
+    if (NULL == (xmit_buf = HDmalloc(buf_size))) {
+        mirror_log(session->loginfo, V_ERR, "out of memory");
+        goto error;
+    }
+
     comm.magic     = MW_SOCK_COMM_MAGIC;
     comm.recd_die  = 0; /* Flag for program to terminate */
     comm.xmit_recd = &xmit_recd;
     comm.raw       = xmit_buf;
-    comm.raw_size  = sizeof(xmit_buf);
+    comm.raw_size  = buf_size;
 
     while (1) { /* sill-listening infinite loop */
 
         /* Use convenience structure for raw/decoded info in/out */
         if (receive_communique(session, &comm) < 0) {
             mirror_log(session->loginfo, V_ERR, "problem reading socket");
-            return -1;
+            goto error;
         }
 
         if (comm.recd_die) {
@@ -959,42 +965,42 @@ process_instructions(struct mirror_session *session)
         switch (xmit_recd.op) {
             case H5FD_MIRROR_OP_CLOSE:
                 if (do_close(session) < 0) {
-                    return -1;
+                    goto error;
                 }
                 goto done;
             case H5FD_MIRROR_OP_LOCK:
                 if (do_lock(session, (const unsigned char *)xmit_buf) < 0) {
-                    return -1;
+                    goto error;
                 }
                 break;
             case H5FD_MIRROR_OP_OPEN:
                 mirror_log(session->loginfo, V_ERR, "OPEN xmit during session");
                 reply_error(session, "illegal OPEN xmit during session");
-                return -1;
+                goto error;
             case H5FD_MIRROR_OP_SET_EOA:
                 if (do_set_eoa(session, (const unsigned char *)xmit_buf) < 0) {
-                    return -1;
+                    goto error;
                 }
                 break;
             case H5FD_MIRROR_OP_TRUNCATE:
                 if (do_truncate(session) < 0) {
-                    return -1;
+                    goto error;
                 }
                 break;
             case H5FD_MIRROR_OP_UNLOCK:
                 if (do_unlock(session) < 0) {
-                    return -1;
+                    goto error;
                 }
                 break;
             case H5FD_MIRROR_OP_WRITE:
                 if (do_write(session, (const unsigned char *)xmit_buf) < 0) {
-                    return -1;
+                    goto error;
                 }
                 break;
             default:
                 mirror_log(session->loginfo, V_ERR, "unrecognized transmission");
                 reply_error(session, "unrecognized transmission");
-                return -1;
+                goto error;
         } /* end switch (xmit_recd.op) */
 
     } /* end while still listening */
@@ -1002,7 +1008,12 @@ process_instructions(struct mirror_session *session)
 done:
     comm.magic      = 0; /* invalidate structure, on principle */
     xmit_recd.magic = 0; /* invalidate structure, on principle */
+    HDfree(xmit_buf);
     return 0;
+
+error:
+    HDfree(xmit_buf);
+    return -1;
 } /* end process_instructions() */
 
 /* ---------------------------------------------------------------------------
